@@ -18,8 +18,8 @@
    If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef KDEV_BREAKPOINT_H
-#define KDEV_BREAKPOINT_H
+#ifndef KDEVPLATFORM_BREAKPOINT_H
+#define KDEVPLATFORM_BREAKPOINT_H
 
 #include <QtCore/QSet>
 #include <KDE/KUrl>
@@ -49,13 +49,19 @@ public:
         PendingState,
         CleanState
     };
+    ///Custom roles for retrieving data from breakpoint model.
+    enum BreakpointRole{
+        LocationRole = Qt::UserRole + 1 ///< Retrieves breakpoint's full path unlike Qt::DisplayRole. Note: it's only appliable to LocationColumn.
+    };
 
     Breakpoint(BreakpointModel *model, BreakpointKind kind);
     Breakpoint(BreakpointModel *model, const KConfigGroup& config);
 
+    ///Note: EnableColumn has 3, not 2(true and false) values: Qt::Unchecked, Qt:PartiallyChecked and Qt::Checked
     bool setData(int index, const QVariant& value);
     void setDeleted();
 
+    ///Note: to retrieve the full path use LocationRole, Qt::DisplayRole return only a file's name
     QVariant data(int column, int role) const;
 
     void save(KConfigGroup& config);
