@@ -33,7 +33,11 @@
 namespace KDevelop {
 
 FrameStackModel::FrameStackModel(IDebugSession *session)
-: IFrameStackModel(session), m_currentThread(-1), m_currentFrame(-1)
+    : IFrameStackModel(session)
+    , m_currentThread(-1)
+    , m_currentFrame(-1)
+    , m_subsequentFrameFetchOperations(0)
+    , m_updateCurrentFrameOnNextFetch(false)
 {
     connect(session, SIGNAL(stateChanged(KDevelop::IDebugSession::DebuggerState)), SLOT(stateChanged(KDevelop::IDebugSession::DebuggerState)));
 }
@@ -88,6 +92,24 @@ void FrameStackModel::setFrames(int threadNumber, QList<FrameItem> frames)
         endInsertRows();
     }
 
+    //if first frame doesn't contain debug ifnormation (no line numbers) set
+    //currentFrame to the first frame with debug information
+    if (m_currentThread == threadNumber && m_updateCurrentFrameOnNextFetch) {
+        m_currentFrame = 0;
+        foreach (const FrameItem &frame, frames) {
+            if (!frame.file.isEmpty() && frame.line != -1) {
+                if (session()->currentUrl() != frame.file || session()->currentLine() != frame.line) {
+                    session()->setCurrentPosition(frame.file, frame.line, QString());
+                }
+                m_currentFrame = frame.nr;
+                break;
+            }
+        }
+        m_updateCurrentFrameOnNextFetch = false;
+    }
+
+    session()->raiseEvent(IDebugSession::thread_or_frame_changed);
+
     // FIXME: Ugly hack. Apparently, when rows are added, the selection
     // in the view is cleared. Emit this so that some frame is still
     // selected.
@@ -148,7 +170,7 @@ QVariant FrameStackModel::data(const QModelIndex& index, int role) const
                 QString ret = ICore::self()->projectController()
                     ->prettyFileName(frame.file, IProjectController::FormatPlain);
                 if (frame.line != -1) {
-                    ret += ":" + QString::number(frame.line + 1);
+                    ret += ':' + QString::number(frame.line + 1);
                 }
                 return ret;
             } else if (role == Qt::DecorationRole) {
@@ -222,6 +244,8 @@ void FrameStackModel::setCurrentThread(int threadNumber)
         // then to thread 2 and then to thread 3, we'll request frames
         // for thread 3 again, even if the program was not run in between
         // and therefore frames could not have changed.
+        m_currentFrame = 0; //set before fetchFrames else --frame argument would be wrong
+        m_updateCurrentFrameOnNextFetch = true;
         fetchFrames(threadNumber, 0, 20);
     }
     if (threadNumber != m_currentThread) {
@@ -285,6 +309,7 @@ void FrameStackModel::setCurrentFrame(int frame)
 
 void FrameStackModel::update()
 {
+    m_subsequentFrameFetchOperations = 0;
     fetchThreads();
     if (m_currentThread != -1) {
         fetchFrames(m_currentThread, 0, 20);
@@ -307,7 +332,8 @@ void FrameStackModel::handleEvent(IDebugSession::event_t event)
 void FrameStackModel::stateChanged(IDebugSession::DebuggerState state)
 {
     if (state == IDebugSession::PausedState) {
-        setCurrentFrame(0);
+        setCurrentFrame(-1);
+        m_updateCurrentFrameOnNextFetch = true;
     } else if (state == IDebugSession::EndedState || state == IDebugSession::NotStartedState) {
         setThreads(QList<FrameStackModel::ThreadItem>());
     }
@@ -316,12 +342,14 @@ void FrameStackModel::stateChanged(IDebugSession::DebuggerState state)
 // FIXME: it should be possible to fetch more frames for
 // an arbitrary thread, without making it current.
 void FrameStackModel::fetchMoreFrames()
-{    
+{
+    m_subsequentFrameFetchOperations += 1;
+    const int fetch = 20 * m_subsequentFrameFetchOperations * m_subsequentFrameFetchOperations;
     if (m_currentThread != -1 && m_hasMoreFrames[m_currentThread]) {
         setHasMoreFrames(m_currentThread, false);
         fetchFrames(m_currentThread,
                     m_frames[m_currentThread].count(),
-                    m_frames[m_currentThread].count()-1+20);
+                    m_frames[m_currentThread].count()-1+fetch);
     }
 }
 
