@@ -21,8 +21,8 @@ along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
-#ifndef IPLUGINCONTROLLER_H
-#define IPLUGINCONTROLLER_H
+#ifndef KDEVPLATFORM_IPLUGINCONTROLLER_H
+#define KDEVPLATFORM_IPLUGINCONTROLLER_H
 
 #include <QtCore/QObject>
 #include <QtCore/QList>
@@ -186,7 +186,7 @@ public:
 Q_SIGNALS:
     void loadingPlugin( const QString& );
     void pluginLoaded( KDevelop::IPlugin* );
-
+    void unloadingPlugin( KDevelop::IPlugin* );
     /**
      * This signal is emitted whenever a plugin is unloaded.
      * @note: that you shouldn't use the pointer anymore
