@@ -57,9 +57,61 @@
 #include <qcoreapplication.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/isession.h>
+#include <interfaces/iprojectcontroller.h>
 
 const bool separateThreadForHighPriority = true;
 
+/**
+ * Elides string in @p path, e.g. "VEEERY/LONG/PATH" -> ".../LONG/PATH"
+ * - probably much faster than QFontMetrics::elidedText()
+ * - we dont need a widget context
+ * - takes path separators into account
+ *
+ * @p width Maximum number of characters
+ *
+ * TODO: Move to kdevutil?
+ */
+static QString elidedPathLeft(const QString& path, int width)
+{
+    static const QChar separator = QDir::separator();
+    static const QString placeholder = "...";
+
+    if (path.size() <= width) {
+        return path;
+    }
+
+    int start = (path.size() - width) + placeholder.size();
+    int pos = path.indexOf(separator, start);
+    if (pos == -1) {
+        pos = start; // no separator => just cut off the path at the beginning
+    }
+    Q_ASSERT(path.size() - pos >= 0 && path.size() - pos <= width);
+
+    QStringRef elidedText = path.rightRef(path.size() - pos);
+    QString result = placeholder;
+    result.append(elidedText);
+    return result;
+}
+
+namespace {
+/**
+ * @return true if @p url is non-empty, valid and has a clean path, false otherwise.
+ */
+inline bool isValidURL(const KDevelop::IndexedString& url)
+{
+    if (url.isEmpty()) {
+        return false;
+    }
+    KUrl original = url.toUrl();
+    if (!original.isValid()) {
+        return false;
+    }
+    KUrl cleaned = original;
+    cleaned.cleanPath();
+    return original == cleaned;
+}
+}
+
 namespace KDevelop
 {
 
@@ -96,10 +148,9 @@ public:
         m_weaver.finish();
 
         // Release dequeued jobs
-        QHashIterator<KUrl, ParseJob*> it = m_parseJobs;
+        QHashIterator<IndexedString, ParseJob*> it = m_parseJobs;
         while (it.hasNext()) {
             it.next();
-            it.value()->setBackgroundParser(0);
             delete it.value();
         }
     }
@@ -113,13 +164,24 @@ public:
         // by the user.
         QList<ParseJob*> jobs;
 
-        for (QMap<int, QSet<KUrl> >::Iterator it1 = m_documentsForPriority.begin();
+        // Before starting a new job, first wait for all higher-priority ones to finish.
+        // That way, parse job priorities can be used for dependency handling.
+        int bestRunningPriority = BackgroundParser::WorstPriority;
+        foreach (const ParseJob* job, m_parseJobs) {
+            if (job->respectsSequentialProcessing() && job->parsePriority() < bestRunningPriority) {
+                bestRunningPriority = job->parsePriority();
+            }
+        }
+
+        bool done = false;
+        for (QMap<int, QSet<IndexedString> >::Iterator it1 = m_documentsForPriority.begin();
              it1 != m_documentsForPriority.end(); ++it1 )
         {
+
             if(it1.key() > m_neededPriority)
                 break; //The priority is not good enough to be processed right now
 
-            for(QSet<KUrl>::Iterator it = it1.value().begin(); it != it1.value().end();) {
+            for(QSet<IndexedString>::Iterator it = it1.value().begin(); it != it1.value().end();) {
                 //Only create parse-jobs for up to thread-count * 2 documents, so we don't fill the memory unnecessarily
                 if(m_parseJobs.count() >= m_threads+1 || (m_parseJobs.count() >= m_threads && !separateThreadForHighPriority) )
                     break;
@@ -134,19 +196,39 @@ public:
                     continue;
                 }
 
-                kDebug(9505) << "creating parse-job" << *it << "new count of active parse-jobs:" << m_parseJobs.count() + 1;
                 Q_ASSERT(m_documents.contains(*it));
                 const DocumentParsePlan& parsePlan = m_documents[*it];
-                ParseJob* job = createParseJob(*it, parsePlan.features(), parsePlan.notifyWhenReady());
+                // If the current job requires sequential processing, but not all jobs with a better priority have been
+                // completed yet, it will not be created now.
+                if (    parsePlan.sequentialProcessingFlags() & ParseJob::RequiresSequentialProcessing
+                     && parsePlan.priority() > bestRunningPriority )
+                {
+                    ++it;
+                    continue;
+                }
+
+                kDebug(9505) << "creating parse-job" << it->toUrl() << "new count of active parse-jobs:" << m_parseJobs.count() + 1;
+                const QString elidedPathString = elidedPathLeft(it->toUrl().toLocalFile(), 70);
+                emit m_parser->showMessage(m_parser, i18n("Parsing: %1", elidedPathString));
+
+                ParseJob* job = createParseJob(*it, parsePlan.features(), parsePlan.notifyWhenReady(), parsePlan.priority());
 
                 if(m_parseJobs.count() == m_threads+1 && !specialParseJob)
                     specialParseJob = job; //This parse-job is allocated into the reserved thread
 
-                if(job)
+                if(job) {
+                    job->setSequentialProcessingFlags(parsePlan.sequentialProcessingFlags());
                     jobs.append(job);
+                    // update the currently best processed priority, if the created job respects sequential processing
+                    if (   parsePlan.sequentialProcessingFlags() & ParseJob::RespectsSequentialProcessing
+                        && parsePlan.priority() < bestRunningPriority)
+                    {
+                        bestRunningPriority = parsePlan.priority();
+                    }
+                }
 
                 // Remove all mentions of this document.
-                foreach(DocumentParseTarget target, parsePlan.targets) {
+                foreach(const DocumentParseTarget& target, parsePlan.targets) {
                     if (target.priority != it1.key()) {
                         m_documentsForPriority[target.priority].remove(*it);
                     }
@@ -154,16 +236,18 @@ public:
                 m_documents.remove(*it);
                 it = it1.value().erase(it);
                 --m_maxParseJobs; //We have added one when putting the document into m_documents
-                
+
                 if(!m_documents.isEmpty())
                 {
                     // Only try creating one parse-job at a time, else we might iterate through thousands of files
                     // without finding a language-support, and block the UI for a long time.
                     // If there are more documents to parse, instantly re-try.
                     QMetaObject::invokeMethod(m_parser, "parseDocuments", Qt::QueuedConnection);
+                    done = true;
                     break;
                 }
             }
+            if ( done ) break;
         }
 
         // Ok, enqueueing is fine because m_parseJobs contains all of the jobs now
@@ -181,12 +265,14 @@ public:
         }
     }
 
-    ParseJob* createParseJob(const KUrl& url, TopDUContext::Features features, QList<QWeakPointer<QObject> > notifyWhenReady)
+    ParseJob* createParseJob(const IndexedString& url, TopDUContext::Features features, const QList<QWeakPointer<QObject> >& notifyWhenReady, int priority = 0)
     {
-        QList<ILanguage*> languages = m_languageController->languagesForUrl(url);
+        ///FIXME: use IndexedString in the other APIs as well! Esp. for createParseJob!
+        KUrl kUrl = url.toUrl();
+        QList<ILanguage*> languages = m_languageController->languagesForUrl(kUrl);
         foreach (ILanguage* language, languages) {
             if(!language) {
-                kWarning() << "got zero language for" << url;
+                kWarning() << "got zero language for" << kUrl;
                 continue;
             }
             if(!language->languageSupport()) {
@@ -198,17 +284,16 @@ public:
                 continue; // Language part did not produce a valid ParseJob.
             }
 
+            job->setParsePriority(priority);
             job->setMinimumFeatures(features);
-            job->setBackgroundParser(m_parser);
             job->setNotifyWhenReady(notifyWhenReady);
-            job->setTracker(m_parser->trackerForUrl(IndexedString(url)));
 
             QObject::connect(job, SIGNAL(done(ThreadWeaver::Job*)),
                                 m_parser, SLOT(parseComplete(ThreadWeaver::Job*)));
             QObject::connect(job, SIGNAL(failed(ThreadWeaver::Job*)),
                                 m_parser, SLOT(parseComplete(ThreadWeaver::Job*)));
-            QObject::connect(job, SIGNAL(progress(KDevelop::ParseJob*, float, QString)),
-                                m_parser, SLOT(parseProgress(KDevelop::ParseJob*, float, QString)), Qt::QueuedConnection);
+            QObject::connect(job, SIGNAL(progress(KDevelop::ParseJob*,float,QString)),
+                                m_parser, SLOT(parseProgress(KDevelop::ParseJob*,float,QString)), Qt::QueuedConnection);
 
             m_parseJobs.insert(url, job);
 
@@ -219,15 +304,15 @@ public:
         }
 
         if(languages.isEmpty())
-            kDebug() << "found no languages for url" << url;
+            kDebug() << "found no languages for url" << kUrl;
         else
-            kDebug() << "could not create parse-job for url" << url;
+            kDebug() << "could not create parse-job for url" << kUrl;
 
         //Notify that we failed
         typedef QWeakPointer<QObject> Notify;
         foreach(const Notify& n, notifyWhenReady)
             if(n)
-                QMetaObject::invokeMethod(n.data(), "updateReady", Qt::QueuedConnection, Q_ARG(KDevelop::IndexedString, IndexedString(url)), Q_ARG(KDevelop::ReferencedTopDUContext, ReferencedTopDUContext()));
+                QMetaObject::invokeMethod(n.data(), "updateReady", Qt::QueuedConnection, Q_ARG(KDevelop::IndexedString, url), Q_ARG(KDevelop::ReferencedTopDUContext, ReferencedTopDUContext()));
 
         return 0;
     }
@@ -293,35 +378,48 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
     QTimer m_timer;
     int m_delay;
     int m_threads;
-    
+
     bool m_shuttingDown;
     
     struct DocumentParseTarget {
         QWeakPointer<QObject> notifyWhenReady;
         int priority;
         TopDUContext::Features features;
+        ParseJob::SequentialProcessingFlags sequentialProcessingFlags;
         bool operator==(const DocumentParseTarget& rhs) const {
             return notifyWhenReady == rhs.notifyWhenReady && priority == rhs.priority && features == rhs.features;
         }
     };
 
     struct DocumentParsePlan {
-        QList<DocumentParseTarget> targets;
+        QSet<DocumentParseTarget> targets;
+
+        ParseJob::SequentialProcessingFlags sequentialProcessingFlags() const {
+            //Pick the strictest possible flags
+            ParseJob::SequentialProcessingFlags ret = ParseJob::IgnoresSequentialProcessing;
+            foreach(const DocumentParseTarget &target, targets) {
+                ret |= target.sequentialProcessingFlags;
+            }
+            return ret;
+        }
 
         int priority() const {
             //Pick the best priority
             int ret = BackgroundParser::WorstPriority;
-            foreach(const DocumentParseTarget &target, targets)
-                if(target.priority < ret)
+            foreach(const DocumentParseTarget &target, targets) {
+                if(target.priority < ret) {
                     ret = target.priority;
+                }
+            }
             return ret;
         }
 
         TopDUContext::Features features() const {
             //Pick the best features
             TopDUContext::Features ret = (TopDUContext::Features)0;
-            foreach(const DocumentParseTarget &target, targets)
+            foreach(const DocumentParseTarget &target, targets) {
                 ret = (TopDUContext::Features) (ret | target.features);
+            }
             return ret;
         }
 
@@ -336,15 +434,17 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
         }
     };
     // A list of documents that are planned to be parsed, and their priority
-    QMap<KUrl, DocumentParsePlan > m_documents;
+    QHash<IndexedString, DocumentParsePlan > m_documents;
     // The documents ordered by priority
-    QMap<int, QSet<KUrl> > m_documentsForPriority;
+    QMap<int, QSet<IndexedString> > m_documentsForPriority;
     // Currently running parse jobs
-    QHash<KUrl, ParseJob*> m_parseJobs;
+    QHash<IndexedString, ParseJob*> m_parseJobs;
     // A change tracker for each managed document
     QHash<IndexedString, DocumentChangeTracker*> m_managed;
     // The url for each managed document. Those may temporarily differ from the real url.
     QHash<KTextEditor::Document*, IndexedString> m_managedTextDocumentUrls;
+    // Projects currently in progress of loading
+    QSet<IProject*> m_loadingProjects;
 
     ThreadWeaver::Weaver m_weaver;
     ParserDependencyPolicy m_dependencyPolicy;
@@ -353,10 +453,15 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 
     int m_maxParseJobs;
     int m_doneParseJobs;
-    QMap<KDevelop::ParseJob*, float> m_jobProgress;
+    QHash<KDevelop::ParseJob*, float> m_jobProgress;
     int m_neededPriority; //The minimum priority needed for processed jobs
 };
 
+inline uint qHash(const BackgroundParserPrivate::DocumentParseTarget& target) {
+    return target.features * 7 + target.priority * 13 + target.sequentialProcessingFlags * 17 
+                               + reinterpret_cast<size_t>(target.notifyWhenReady.data());
+};
+
 BackgroundParser::BackgroundParser(ILanguageController *languageController)
     : QObject(languageController), d(new BackgroundParserPrivate(this, languageController))
 {
@@ -364,7 +469,21 @@ BackgroundParser::BackgroundParser(ILanguageController *languageController)
     connect(ICore::self()->documentController(), SIGNAL(documentLoaded(KDevelop::IDocument*)), this, SLOT(documentLoaded(KDevelop::IDocument*)));
     connect(ICore::self()->documentController(), SIGNAL(documentUrlChanged(KDevelop::IDocument*)), this, SLOT(documentUrlChanged(KDevelop::IDocument*)));
     connect(ICore::self()->documentController(), SIGNAL(documentClosed(KDevelop::IDocument*)), this, SLOT(documentClosed(KDevelop::IDocument*)));
-    connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), this, SLOT(aboutToQuit()));
+    connect(ICore::self(), SIGNAL(aboutToShutdown()), this, SLOT(aboutToQuit()));
+
+    bool connected = QObject::connect(ICore::self()->projectController(),
+                                      SIGNAL(projectAboutToBeOpened(KDevelop::IProject*)),
+                                      this, SLOT(projectAboutToBeOpened(KDevelop::IProject*)));
+    Q_ASSERT(connected);
+    connected = QObject::connect(ICore::self()->projectController(),
+                                 SIGNAL(projectOpened(KDevelop::IProject*)),
+                                 this, SLOT(projectOpened(KDevelop::IProject*)));
+    Q_ASSERT(connected);
+    connected = QObject::connect(ICore::self()->projectController(),
+                                 SIGNAL(projectOpeningAborted(KDevelop::IProject*)),
+                                 this, SLOT(projectOpeningAborted(KDevelop::IProject*)));
+    Q_ASSERT(connected);
+    Q_UNUSED(connected);
 }
 
 void BackgroundParser::aboutToQuit()
@@ -386,7 +505,7 @@ void BackgroundParser::clear(QObject* parent)
 {
     QMutexLocker lock(&d->m_mutex);
 
-    QHashIterator<KUrl, ParseJob*> it = d->m_parseJobs;
+    QHashIterator<IndexedString, ParseJob*> it = d->m_parseJobs;
     while (it.hasNext()) {
         it.next();
         if (it.value()->parent() == parent) {
@@ -409,59 +528,53 @@ void BackgroundParser::parseProgress(KDevelop::ParseJob* job, float value, QStri
 
 void BackgroundParser::revertAllRequests(QObject* notifyWhenReady)
 {
-    QWeakPointer<QObject> p(notifyWhenReady);
-
     QMutexLocker lock(&d->m_mutex);
-    for(QMap<KUrl, BackgroundParserPrivate::DocumentParsePlan >::iterator it = d->m_documents.begin(); it != d->m_documents.end(); ) {
+    for(QHash<IndexedString, BackgroundParserPrivate::DocumentParsePlan >::iterator it = d->m_documents.begin(); it != d->m_documents.end(); ) {
 
         d->m_documentsForPriority[it.value().priority()].remove(it.key());
 
-        int index = -1;
-        for(int a = 0; a < (*it).targets.size(); ++a)
-            if((*it).targets[a].notifyWhenReady.data() == notifyWhenReady)
-                index = a;
-
-        if(index != -1) {
-            (*it).targets.removeAt(index);
-            if((*it).targets.isEmpty()) {
-                it = d->m_documents.erase(it);
-                --d->m_maxParseJobs;
-
-                continue;
+        foreach ( const BackgroundParserPrivate::DocumentParseTarget& target, (*it).targets ) {
+            if ( target.notifyWhenReady.data() == notifyWhenReady ) {
+                (*it).targets.remove(target);
             }
         }
 
+        if((*it).targets.isEmpty()) {
+            it = d->m_documents.erase(it);
+            --d->m_maxParseJobs;
+
+            continue;
+        }
+
         d->m_documentsForPriority[it.value().priority()].insert(it.key());
         ++it;
     }
 }
 
-void BackgroundParser::addDocument(const KUrl& url, TopDUContext::Features features, int priority, QObject* notifyWhenReady)
+void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Features features, int priority, QObject* notifyWhenReady, ParseJob::SequentialProcessingFlags flags)
 {
-//     kDebug(9505) << "BackgroundParser::addDocument" << url.prettyUrl();
-    KUrl cleanedUrl = url;
-    cleanedUrl.cleanPath();
+//     kDebug(9505) << "BackgroundParser::addDocument" << url.toUrl();
+    Q_ASSERT(isValidURL(url));
     QMutexLocker lock(&d->m_mutex);
     {
-        Q_ASSERT(cleanedUrl.isValid());
-
         BackgroundParserPrivate::DocumentParseTarget target;
         target.priority = priority;
         target.features = features;
+        target.sequentialProcessingFlags = flags;
         target.notifyWhenReady = QWeakPointer<QObject>(notifyWhenReady);
 
-        QMap<KUrl, BackgroundParserPrivate::DocumentParsePlan>::iterator it = d->m_documents.find(cleanedUrl);
+        QHash<IndexedString, BackgroundParserPrivate::DocumentParsePlan>::iterator it = d->m_documents.find(url);
 
         if (it != d->m_documents.end()) {
             //Update the stored plan
 
-            d->m_documentsForPriority[it.value().priority()].remove(cleanedUrl);
+            d->m_documentsForPriority[it.value().priority()].remove(url);
             it.value().targets << target;
-            d->m_documentsForPriority[it.value().priority()].insert(cleanedUrl);
+            d->m_documentsForPriority[it.value().priority()].insert(url);
         }else{
 //             kDebug(9505) << "BackgroundParser::addDocument: queuing" << cleanedUrl;
-            d->m_documents[cleanedUrl].targets << target;
-            d->m_documentsForPriority[d->m_documents[cleanedUrl].priority()].insert(cleanedUrl);
+            d->m_documents[url].targets << target;
+            d->m_documentsForPriority[d->m_documents[url].priority()].insert(url);
             ++d->m_maxParseJobs; //So the progress-bar waits for this document
         }
 
@@ -469,25 +582,21 @@ void BackgroundParser::addDocument(const KUrl& url, TopDUContext::Features featu
     }
 }
 
-void BackgroundParser::addDocumentList(const KUrl::List &urls, TopDUContext::Features features, int priority)
+void BackgroundParser::removeDocument(const IndexedString& url, QObject* notifyWhenReady)
 {
-    foreach (const KUrl &url, urls)
-        addDocument(url, features, priority);
-}
+    Q_ASSERT(isValidURL(url));
 
-void BackgroundParser::removeDocument(const KUrl &url, QObject* notifyWhenReady)
-{
     QMutexLocker lock(&d->m_mutex);
 
-    Q_ASSERT(url.isValid());
-
     if(d->m_documents.contains(url)) {
-        
+
         d->m_documentsForPriority[d->m_documents[url].priority()].remove(url);
-        
-        foreach(BackgroundParserPrivate::DocumentParseTarget target, d->m_documents[url].targets)
-            if(target.notifyWhenReady.data() == notifyWhenReady)
-                d->m_documents[url].targets.removeAll(target);
+
+        foreach(const BackgroundParserPrivate::DocumentParseTarget& target, d->m_documents[url].targets) {
+            if(target.notifyWhenReady.data() == notifyWhenReady) {
+                d->m_documents[url].targets.remove(target);
+            }
+        }
 
         if(d->m_documents[url].targets.isEmpty()) {
             d->m_documents.remove(url);
@@ -501,6 +610,10 @@ void BackgroundParser::removeDocument(const KUrl &url, QObject* notifyWhenReady)
 
 void BackgroundParser::parseDocuments()
 {
+    if (!d->m_loadingProjects.empty()) {
+        startTimer();
+        return;
+    }
     QMutexLocker lock(&d->m_mutex);
 
     d->parseDocumentsInternal();
@@ -515,13 +628,11 @@ void BackgroundParser::parseComplete(ThreadWeaver::Job* job)
         {
             {
                 QMutexLocker lock(&d->m_mutex);
-    
-                d->m_parseJobs.remove(parseJob->document().str());
-    
+
+                d->m_parseJobs.remove(parseJob->document());
+
                 d->m_jobProgress.remove(parseJob);
-    
-                parseJob->setBackgroundParser(0);
-    
+
                 ++d->m_doneParseJobs;
                 updateProgressBar();
             }
@@ -544,7 +655,16 @@ void BackgroundParser::enableProcessing()
     setNeededPriority(WorstPriority);
 }
 
-bool BackgroundParser::isQueued(KUrl url) const {
+int BackgroundParser::priorityForDocument(const IndexedString& url) const
+{
+    Q_ASSERT(isValidURL(url));
+    QMutexLocker lock(&d->m_mutex);
+    return d->m_documents[url].priority();
+}
+
+bool BackgroundParser::isQueued(const IndexedString& url) const
+{
+    Q_ASSERT(isValidURL(url));
     QMutexLocker lock(&d->m_mutex);
     return d->m_documents.contains(url);
 }
@@ -586,7 +706,7 @@ void BackgroundParser::updateProgressBar()
         d->m_maxParseJobs = 0;
     } else {
         float additionalProgress = 0;
-        for(QMap<KDevelop::ParseJob*, float>::const_iterator it = d->m_jobProgress.constBegin(); it != d->m_jobProgress.constEnd(); ++it)
+        for(QHash<KDevelop::ParseJob*, float>::const_iterator it = d->m_jobProgress.constBegin(); it != d->m_jobProgress.constEnd(); ++it)
             additionalProgress += *it;
 
         emit showProgress(this, 0, d->m_maxParseJobs*1000, (additionalProgress + d->m_doneParseJobs)*1000);
@@ -598,15 +718,12 @@ ParserDependencyPolicy* BackgroundParser::dependencyPolicy() const
     return &d->m_dependencyPolicy;
 }
 
-ParseJob* BackgroundParser::parseJobForDocument(const KUrl& document) const
+ParseJob* BackgroundParser::parseJobForDocument(const IndexedString& document) const
 {
+    Q_ASSERT(isValidURL(document));
+
     QMutexLocker lock(&d->m_mutex);
-
-    if (d->m_parseJobs.contains(document)) {
-        return d->m_parseJobs[document];
-    }
-
-    return 0;
+    return d->m_parseJobs.value(document, 0);
 }
 
 void BackgroundParser::setThreadCount(int threadCount)
@@ -617,6 +734,11 @@ void BackgroundParser::setThreadCount(int threadCount)
     }
 }
 
+int BackgroundParser::threadCount() const
+{
+    return d->m_threads;
+}
+
 void BackgroundParser::setDelay(int miliseconds)
 {
     if (d->m_delay != miliseconds) {
@@ -634,31 +756,33 @@ QList< IndexedString > BackgroundParser::managedDocuments()
 
 DocumentChangeTracker* BackgroundParser::trackerForUrl(const KDevelop::IndexedString& url) const
 {
-    QMutexLocker l(&d->m_mutex);
-    
-    QHash< IndexedString, DocumentChangeTracker* >::iterator it = d->m_managed.find(url);
-    if(it != d->m_managed.end())
-        return *it;
-    else
+    if (url.isEmpty()) {
+        // this happens e.g. when setting the final location of a problem that is not
+        // yet associated with a top ctx.
         return 0;
+    }
+    Q_ASSERT(isValidURL(url));
+
+    QMutexLocker l(&d->m_mutex);
+    return d->m_managed.value(url, 0);
 }
 
-void BackgroundParser::documentClosed ( IDocument* document )
+void BackgroundParser::documentClosed(IDocument* document)
 {
     QMutexLocker l(&d->m_mutex);
-    
+
     if(document->textDocument())
     {
         KTextEditor::Document* textDocument = document->textDocument();
-        
+
         if(!d->m_managedTextDocumentUrls.contains(textDocument))
             return; // Probably the document had an invalid url, and thus it wasn't added to the background parser
-        
+
         Q_ASSERT(d->m_managedTextDocumentUrls.contains(textDocument));
-        
+
         IndexedString url(d->m_managedTextDocumentUrls[textDocument]);
         Q_ASSERT(d->m_managed.contains(url));
-        
+
         kDebug() << "removing" << url.str() << "from background parser";
         delete d->m_managed[url];
         d->m_managedTextDocumentUrls.remove(textDocument);
@@ -708,7 +832,25 @@ void BackgroundParser::startTimer() {
     d->m_timer.start(d->m_delay);
 }
 
+void BackgroundParser::projectAboutToBeOpened(IProject* project)
+{
+    d->m_loadingProjects.insert(project);
 }
 
+void BackgroundParser::projectOpened(IProject* project)
+{
+    d->m_loadingProjects.remove(project);
+}
+
+void BackgroundParser::projectOpeningAborted(IProject* project)
+{
+    d->m_loadingProjects.remove(project);
+}
+
+}
+
+Q_DECLARE_TYPEINFO(KDevelop::BackgroundParserPrivate::DocumentParseTarget, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(KDevelop::BackgroundParserPrivate::DocumentParsePlan, Q_MOVABLE_TYPE);
+
 #include "backgroundparser.moc"
 
