@@ -53,8 +53,8 @@ using namespace KTextEditor;
  * Only reparse after a statement was completed (either with statement-completion or manually), or after the cursor was switched away
  * Incremental parsing:
  *  - All changes within a local function (or function parameter context): Update only the context (and all its importers)
- * 
- * @todo: Prevent recursive updates after insignificant changes 
+ *
+ * @todo: Prevent recursive updates after insignificant changes
  *             (whitespace changes, or changes that don't affect publically visible stuff, eg. local incremental changes)
  *             -> Maybe alter the file-modification caches directly
  * */
@@ -72,8 +72,8 @@ DocumentChangeTracker::DocumentChangeTracker( KTextEditor::Document* document )
     m_url = IndexedString(document->url());
     Q_ASSERT(document);
     Q_ASSERT(document->url().isValid());
-    
-    // Check whether a language plugin is tracking the document which belongs to a 
+
+    // Check whether a language plugin is tracking the document which belongs to a
     // whitespace-sensitive language (e.g. python)
     foreach ( KDevelop::ILanguage* lang, ICore::self()->languageController()->languagesForUrl(document->url()) ) {
         if ( ! lang || ! lang->languageSupport() ) {
@@ -83,28 +83,28 @@ DocumentChangeTracker::DocumentChangeTracker( KTextEditor::Document* document )
             m_whitespaceSensitivity = lang->languageSupport()->whitespaceSensititivy();
         }
     }
-    
+
     connect(document, SIGNAL(textInserted(KTextEditor::Document*,KTextEditor::Range)), SLOT(textInserted(KTextEditor::Document*,KTextEditor::Range)));
     connect(document, SIGNAL(textRemoved(KTextEditor::Document*,KTextEditor::Range,QString)), SLOT(textRemoved(KTextEditor::Document*,KTextEditor::Range,QString)));
     connect(document, SIGNAL(textChanged(KTextEditor::Document*,KTextEditor::Range,QString,KTextEditor::Range)), SLOT(textChanged(KTextEditor::Document*,KTextEditor::Range,QString,KTextEditor::Range)));
     connect(document, SIGNAL(destroyed(QObject*)), SLOT(documentDestroyed(QObject*)));
     connect(document, SIGNAL(documentSavedOrUploaded(KTextEditor::Document*,bool)), SLOT(documentSavedOrUploaded(KTextEditor::Document*,bool)));
-    
+
     m_moving = dynamic_cast<KTextEditor::MovingInterface*>(document);
     Q_ASSERT(m_moving);
     m_changedRange = m_moving->newMovingRange(KTextEditor::Range(), KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
-    
+
     connect(m_document, SIGNAL(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)), this, SLOT(aboutToInvalidateMovingInterfaceContent(KTextEditor::Document*)));
-    
+
     ModificationRevision::setEditorRevisionForFile(m_url, m_moving->revision());
-    
+
     reset();
 }
 
 QList< QPair< SimpleRange, QString > > DocumentChangeTracker::completions() const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     QList< QPair< SimpleRange , QString > > ret;
     return ret;
 }
@@ -112,18 +112,18 @@ QList< QPair< SimpleRange, QString > > DocumentChangeTracker::completions() cons
 Range DocumentChangeTracker::changedRange() const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     return m_changedRange->toRange();
 }
 
 void DocumentChangeTracker::reset()
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     // We don't reset the insertion here, as it may continue
     m_needUpdate = false;
     m_changedRange->setRange(KTextEditor::Range::invalid());
-    
+
     m_revisionAtLastReset = acquireRevision(m_moving->revision());
     Q_ASSERT(m_revisionAtLastReset);
     m_textAtLastReset = m_document->text();
@@ -132,28 +132,28 @@ void DocumentChangeTracker::reset()
 RevisionReference DocumentChangeTracker::currentRevision()
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     return acquireRevision(m_moving->revision());
 }
 
 RevisionReference DocumentChangeTracker::revisionAtLastReset() const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     return m_revisionAtLastReset;
 }
 
 QString DocumentChangeTracker::textAtLastReset() const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     return m_textAtLastReset;
 }
 
 bool DocumentChangeTracker::needUpdate() const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     return m_needUpdate;
 }
 
@@ -179,24 +179,24 @@ void DocumentChangeTracker::textChanged( Document* document, Range /*oldRange*/,
 
     QString oldTextWithoutWhitespace = oldText;
     oldTextWithoutWhitespace.remove(whiteSpaceRegExp);
-    
+
     QString newTextWithoutWhitespace = newText;
     newTextWithoutWhitespace.remove(whiteSpaceRegExp);
-    
+
     if(oldTextWithoutWhitespace.isEmpty() && newTextWithoutWhitespace.isEmpty() && checkMergeTokens(newRange, oldText, newText))
     {
         // Only whitespace was changed, no update is required
     }else{
         m_needUpdate = true;
     }
-    
+
     #ifdef ALWAYS_UPDATE
     m_needUpdate = true;
     #endif
-    
+
     m_currentCleanedInsertion.clear();
     m_lastInsertionPosition = KTextEditor::Cursor::invalid();
-    
+
     updateChangedRange(newRange);
 }
 
@@ -206,13 +206,13 @@ void DocumentChangeTracker::updateChangedRange( Range changed )
         m_changedRange->setRange(changed);
     else
         m_changedRange->setRange(changed.encompass(m_changedRange->toRange()));
-    
+
 //     Q_ASSERT(m_moving->revision() != m_revisionAtLastReset->revision()); // May happen after reload
 
     // When reloading, textRemoved is called with an invalid m_document->url(). For that reason, we use m_url instead.
-        
+
     ModificationRevision::setEditorRevisionForFile(m_url, m_moving->revision());
-    
+
     if(needUpdate())
         ICore::self()->languageController()->backgroundParser()->addDocument(m_url, TopDUContext::AllDeclarationsContextsAndUses);
 }
@@ -220,11 +220,11 @@ void DocumentChangeTracker::updateChangedRange( Range changed )
 void DocumentChangeTracker::textInserted( Document* document, Range range )
 {
     QString text = document->text(range);
-    
+
     if ( m_whitespaceSensitivity == ILanguageSupport::Sensitive ) {
         m_needUpdate = true;
     }
-    
+
     if ( ! m_needUpdate ) {
         QString textWithoutWhitespace = text;
         textWithoutWhitespace.remove(whiteSpaceRegExp);
@@ -251,11 +251,11 @@ void DocumentChangeTracker::textInserted( Document* document, Range range )
             m_needUpdate = true;
         }
     }
-    
+
     #ifdef ALWAYS_UPDATE
     m_needUpdate = true;
     #endif
-    
+
     if(m_lastInsertionPosition == KTextEditor::Cursor::invalid() || m_lastInsertionPosition == range.start())
     {
         m_currentCleanedInsertion.append(text);
@@ -268,24 +268,24 @@ void DocumentChangeTracker::textInserted( Document* document, Range range )
 void DocumentChangeTracker::textRemoved( Document* /*document*/, Range oldRange, QString oldText )
 {
     QString text = oldText;
-    
+
     QString textWithoutWhitespace = text;
     textWithoutWhitespace.remove(whiteSpaceRegExp);
-    
+
     if(textWithoutWhitespace.isEmpty() && checkMergeTokens(Range(oldRange.start(), oldRange.start()), oldText, ""))
     {
         // Only whitespace was changed, no update is required
     }else{
         m_needUpdate = true; // If we've inserted something else than whitespace, an update is required
     }
-    
+
     #ifdef ALWAYS_UPDATE
     m_needUpdate = true;
     #endif
-    
+
     m_currentCleanedInsertion.clear();
     m_lastInsertionPosition = KTextEditor::Cursor::invalid();
-    
+
     updateChangedRange(oldRange);
 }
 
@@ -329,25 +329,25 @@ void DocumentChangeTracker::aboutToInvalidateMovingInterfaceContent ( Document*
 KDevelop::RangeInRevision DocumentChangeTracker::transformBetweenRevisions(KDevelop::RangeInRevision range, qint64 fromRevision, qint64 toRevision) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if((fromRevision == -1 || holdingRevision(fromRevision)) && (toRevision == -1 || holdingRevision(toRevision)))
     {
         m_moving->transformCursor(range.start.line, range.start.column, KTextEditor::MovingCursor::MoveOnInsert, fromRevision, toRevision);
         m_moving->transformCursor(range.end.line, range.end.column, KTextEditor::MovingCursor::StayOnInsert, fromRevision, toRevision);
     }
-    
+
     return range;
 }
 
 KDevelop::CursorInRevision DocumentChangeTracker::transformBetweenRevisions(KDevelop::CursorInRevision cursor, qint64 fromRevision, qint64 toRevision, KTextEditor::MovingCursor::InsertBehavior behavior) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if((fromRevision == -1 || holdingRevision(fromRevision)) && (toRevision == -1 || holdingRevision(toRevision)))
     {
         m_moving->transformCursor(cursor.line, cursor.column, behavior, fromRevision, toRevision);
     }
-    
+
     return cursor;
 }
 
@@ -374,9 +374,9 @@ SimpleCursor DocumentChangeTracker::transformToCurrentRevision(CursorInRevision
 RevisionLockerAndClearerPrivate::RevisionLockerAndClearerPrivate(DocumentChangeTracker* tracker, qint64 revision) : m_tracker(tracker), m_revision(revision)
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     moveToThread(QApplication::instance()->thread());
-    
+
     // Lock the revision
     m_tracker->lockRevision(revision);
 }
@@ -394,10 +394,10 @@ RevisionLockerAndClearer::~RevisionLockerAndClearer()
 RevisionReference DocumentChangeTracker::acquireRevision(qint64 revision)
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if(!holdingRevision(revision) && revision != m_moving->revision())
         return RevisionReference();
-    
+
     RevisionReference ret(new RevisionLockerAndClearer);
     ret->m_p = new RevisionLockerAndClearerPrivate(this, revision);
     return ret;
@@ -406,14 +406,14 @@ RevisionReference DocumentChangeTracker::acquireRevision(qint64 revision)
 bool DocumentChangeTracker::holdingRevision(qint64 revision) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     return m_revisionLocks.contains(revision);
 }
 
 void DocumentChangeTracker::lockRevision(qint64 revision)
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     QMap< qint64, int >::iterator it = m_revisionLocks.find(revision);
     if(it != m_revisionLocks.end())
         ++(*it);
@@ -427,7 +427,7 @@ void DocumentChangeTracker::lockRevision(qint64 revision)
 void DocumentChangeTracker::unlockRevision(qint64 revision)
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     QMap< qint64, int >::iterator it = m_revisionLocks.find(revision);
     if(it == m_revisionLocks.end())
     {
@@ -435,98 +435,107 @@ void DocumentChangeTracker::unlockRevision(qint64 revision)
         return;
     }
     --(*it);
-    
+
     if(*it == 0)
     {
-        m_moving->unlockRevision(revision);        
+        m_moving->unlockRevision(revision);
         m_revisionLocks.erase(it);
     }
 }
 
-qint64 RevisionLockerAndClearer::revision() const {
+qint64 RevisionLockerAndClearer::revision() const
+{
     return m_p->revision();
 }
-RangeInRevision RevisionLockerAndClearer::transformToRevision(const KDevelop::RangeInRevision& range, const KDevelop::RevisionLockerAndClearer::Ptr& to)
+
+RangeInRevision RevisionLockerAndClearer::transformToRevision(const KDevelop::RangeInRevision& range,
+                                                              const KDevelop::RevisionLockerAndClearer::Ptr& to) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if(!m_p->m_tracker || !valid() || (to && !to->valid()))
         return range;
-    
+
     qint64 fromRevision = revision();
     qint64 toRevision = -1;
-    
+
     if(to)
         toRevision = to->revision();
-    
+
     return m_p->m_tracker->transformBetweenRevisions(range, fromRevision, toRevision);
 }
 
-CursorInRevision RevisionLockerAndClearer::transformToRevision(const KDevelop::CursorInRevision& cursor, const KDevelop::RevisionLockerAndClearer::Ptr& to, MovingCursor::InsertBehavior behavior)
+CursorInRevision RevisionLockerAndClearer::transformToRevision(const KDevelop::CursorInRevision& cursor,
+                                                               const KDevelop::RevisionLockerAndClearer::Ptr& to,
+                                                               MovingCursor::InsertBehavior behavior) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if(!m_p->m_tracker || !valid() || (to && !to->valid()))
         return cursor;
-    
+
     qint64 fromRevision = revision();
     qint64 toRevision = -1;
-    
+
     if(to)
         toRevision = to->revision();
-    
+
     return m_p->m_tracker->transformBetweenRevisions(cursor, fromRevision, toRevision, behavior);
 }
 
-RangeInRevision RevisionLockerAndClearer::transformFromRevision(const KDevelop::RangeInRevision& range, const KDevelop::RevisionLockerAndClearer::Ptr& from)
+RangeInRevision RevisionLockerAndClearer::transformFromRevision(const KDevelop::RangeInRevision& range,
+                                                                const KDevelop::RevisionLockerAndClearer::Ptr& from) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if(!m_p->m_tracker || !valid())
         return range;
-    
+
     qint64 toRevision = revision();
     qint64 fromRevision = -1;
-    
+
     if(from)
         fromRevision = from->revision();
-    
+
     return m_p->m_tracker->transformBetweenRevisions(range, fromRevision, toRevision);
 }
 
-CursorInRevision RevisionLockerAndClearer::transformFromRevision(const KDevelop::CursorInRevision& cursor, const KDevelop::RevisionLockerAndClearer::Ptr& from, MovingCursor::InsertBehavior behavior)
+CursorInRevision RevisionLockerAndClearer::transformFromRevision(const KDevelop::CursorInRevision& cursor,
+                                                                 const KDevelop::RevisionLockerAndClearer::Ptr& from,
+                                                                 MovingCursor::InsertBehavior behavior) const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if(!m_p->m_tracker)
         return cursor;
-    
+
     qint64 toRevision = revision();
     qint64 fromRevision = -1;
-    
+
     if(from)
         fromRevision = from->revision();
-    
+
     return m_p->m_tracker->transformBetweenRevisions(cursor, fromRevision, toRevision, behavior);
 }
 
-
-SimpleRange RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::RangeInRevision& range)
+SimpleRange RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::RangeInRevision& range) const
 {
     return transformToRevision(range, KDevelop::RevisionLockerAndClearer::Ptr()).castToSimpleRange();
 }
 
-SimpleCursor RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::CursorInRevision& cursor, MovingCursor::InsertBehavior behavior)
+SimpleCursor RevisionLockerAndClearer::transformToCurrentRevision(const KDevelop::CursorInRevision& cursor,
+                                                                  MovingCursor::InsertBehavior behavior) const
 {
     return transformToRevision(cursor, KDevelop::RevisionLockerAndClearer::Ptr(), behavior).castToSimpleCursor();
 }
 
-RangeInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KDevelop::SimpleRange& range)
+RangeInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KDevelop::SimpleRange& range) const
 {
     return transformFromRevision(RangeInRevision::castFromSimpleRange(range), RevisionReference());
 }
 
-CursorInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KDevelop::SimpleCursor& cursor, MovingCursor::InsertBehavior behavior)
+CursorInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KDevelop::SimpleCursor& cursor,
+                                                                        MovingCursor::InsertBehavior behavior) const
 {
     return transformFromRevision(CursorInRevision::castFromSimpleCursor(cursor), RevisionReference(), behavior);
 }
@@ -534,13 +543,13 @@ CursorInRevision RevisionLockerAndClearer::transformFromCurrentRevision(const KD
 bool RevisionLockerAndClearer::valid() const
 {
     VERIFY_FOREGROUND_LOCKED
-    
+
     if(!m_p->m_tracker)
         return false;
-    
+
     if(revision() == -1)
         return true; // The 'current' revision is always valid
-    
+
     return m_p->m_tracker->holdingRevision(revision());
 }
 
