@@ -51,6 +51,7 @@
 #include <codegen/coderepresentation.h>
 #include <duchain/declaration.h>
 #include <duchain/use.h>
+#include <interfaces/icodehighlighting.h>
 
 
 using namespace KTextEditor;
@@ -65,32 +66,31 @@ class ParseJobPrivate
 {
 public:
 
-    ParseJobPrivate(const KUrl& url) :
-          document( IndexedString(url.pathOrUrl()) )
-        , backgroundParser( 0 )
-        , abortMutex(new QMutex)
+    ParseJobPrivate(const IndexedString& url_, ILanguageSupport* languageSupport_) :
+          url( url_ )
+        , languageSupport( languageSupport_ )
         , hasReadContents( false )
         , abortRequested( false )
         , aborted( false )
         , features( TopDUContext::VisibleDeclarationsAndContexts )
+        , parsePriority( 0 )
+        , sequentialProcessingFlags( ParseJob::IgnoresSequentialProcessing )
     {
     }
 
     ~ParseJobPrivate()
     {
-        delete abortMutex;
     }
 
     ReferencedTopDUContext duContext;
 
-    KDevelop::IndexedString document;
-    QString errorMessage;
-    BackgroundParser* backgroundParser;
+    IndexedString url;
+    ILanguageSupport* languageSupport;
 
-    QMutex* abortMutex;
+    QMutex abortMutex;
 
     ParseJob::Contents contents;
-    
+
     bool hasReadContents : 1;
     volatile bool abortRequested : 1;
     bool aborted : 1;
@@ -99,26 +99,61 @@ public:
     QWeakPointer<DocumentChangeTracker> tracker;
     RevisionReference revision;
     RevisionReference previousRevision;
+
+    int parsePriority;
+    ParseJob::SequentialProcessingFlags sequentialProcessingFlags;
 };
 
-ParseJob::ParseJob( const KUrl &url )
+ParseJob::ParseJob( const IndexedString& url, KDevelop::ILanguageSupport* languageSupport )
         : ThreadWeaver::JobSequence(),
-        d(new ParseJobPrivate(url))
+        d(new ParseJobPrivate(url, languageSupport))
 {}
 
 ParseJob::~ParseJob()
 {
     typedef QWeakPointer<QObject> QObjectPointer;
-    foreach(const QObjectPointer &p, d->notify)
-        if(p)
-            QMetaObject::invokeMethod(p.data(), "updateReady", Qt::QueuedConnection, Q_ARG(KDevelop::IndexedString, d->document), Q_ARG(KDevelop::ReferencedTopDUContext, d->duContext));
+    foreach(const QObjectPointer &p, d->notify) {
+        if(p) {
+            QMetaObject::invokeMethod(p.data(), "updateReady", Qt::QueuedConnection, Q_ARG(KDevelop::IndexedString, d->url), Q_ARG(KDevelop::ReferencedTopDUContext, d->duContext));
+        }
+    }
 
     delete d;
 }
 
+ILanguageSupport* ParseJob::languageSupport() const
+{
+    return d->languageSupport;
+}
+
+void ParseJob::setParsePriority(int priority)
+{
+    d->parsePriority = priority;
+}
+
+int ParseJob::parsePriority() const
+{
+    return d->parsePriority;
+}
+
+bool ParseJob::requiresSequentialProcessing() const
+{
+    return d->sequentialProcessingFlags & RequiresSequentialProcessing;
+}
+
+bool ParseJob::respectsSequentialProcessing() const
+{
+    return d->sequentialProcessingFlags & RespectsSequentialProcessing;
+}
+
+void ParseJob::setSequentialProcessingFlags(SequentialProcessingFlags flags)
+{
+    d->sequentialProcessingFlags = flags;
+}
+
 IndexedString ParseJob::document() const
 {
-    return d->document;
+    return d->url;
 }
 
 bool ParseJob::success() const
@@ -137,22 +172,21 @@ bool ParseJob::hasStaticMinimumFeatures()
     return ::staticMinimumFeatures.size();
 }
 
-TopDUContext::Features ParseJob::staticMinimumFeatures(IndexedString url)
+TopDUContext::Features ParseJob::staticMinimumFeatures(const IndexedString& url)
 {
     QMutexLocker lock(&minimumFeaturesMutex);
     TopDUContext::Features features = (TopDUContext::Features)0;
-    
+
     if(::staticMinimumFeatures.contains(url))
         foreach(const TopDUContext::Features &f, ::staticMinimumFeatures[url])
             features = (TopDUContext::Features)(features | f);
-    
+
     return features;
 }
 
 TopDUContext::Features ParseJob::minimumFeatures() const
 {
-    
-    return (TopDUContext::Features)(d->features | staticMinimumFeatures(d->document));
+    return (TopDUContext::Features)(d->features | staticMinimumFeatures(d->url));
 }
 
 void ParseJob::setDuChain(ReferencedTopDUContext duChain)
@@ -167,14 +201,14 @@ ReferencedTopDUContext ParseJob::duChain() const
 
 bool ParseJob::abortRequested() const
 {
-    QMutexLocker lock(d->abortMutex);
+    QMutexLocker lock(&d->abortMutex);
 
     return d->abortRequested;
 }
 
 void ParseJob::requestAbort()
 {
-    QMutexLocker lock(d->abortMutex);
+    QMutexLocker lock(&d->abortMutex);
 
     d->abortRequested = true;
 }
@@ -185,17 +219,17 @@ void ParseJob::abortJob()
     setFinished(true);
 }
 
-void ParseJob::setNotifyWhenReady(QList< QWeakPointer< QObject > > notify
+void ParseJob::setNotifyWhenReady(const QList< QWeakPointer< QObject > >& notify
 ) {
     d->notify = notify;
 }
 
-void ParseJob::setStaticMinimumFeatures(IndexedString url, TopDUContext::Features features) {
+void ParseJob::setStaticMinimumFeatures(const IndexedString& url, TopDUContext::Features features) {
     QMutexLocker lock(&minimumFeaturesMutex);
     ::staticMinimumFeatures[url].append(features);
 }
 
-void ParseJob::unsetStaticMinimumFeatures(IndexedString url, TopDUContext::Features features) {
+void ParseJob::unsetStaticMinimumFeatures(const IndexedString& url, TopDUContext::Features features) {
     QMutexLocker lock(&minimumFeaturesMutex);
     ::staticMinimumFeatures[url].removeOne(features);
     if(::staticMinimumFeatures[url].isEmpty())
@@ -206,7 +240,7 @@ KDevelop::ProblemPointer ParseJob::readContents()
 {
     Q_ASSERT(!d->hasReadContents);
     d->hasReadContents = true;
-    
+
     QString localFile(document().toUrl().toLocalFile());
     QFileInfo fileInfo( localFile );
 
@@ -233,10 +267,10 @@ KDevelop::ProblemPointer ParseJob::readContents()
 
             t->reset(); // Reset the tracker to the current revision
             Q_ASSERT(t->revisionAtLastReset());
-            
+
             d->contents.contents = t->textAtLastReset().toUtf8();
             d->contents.modification = KDevelop::ModificationRevision( lastModified, t->revisionAtLastReset()->revision() );
-            
+
             d->revision = t->acquireRevision(d->contents.modification.revision);
             hadTracker = true;
         }
@@ -248,11 +282,11 @@ KDevelop::ProblemPointer ParseJob::readContents()
         if (fileInfo.size() > maximumFileSize) {
             KDevelop::ProblemPointer p(new Problem());
             p->setSource(KDevelop::ProblemData::Disk);
-            ///NOTE: no i18n to get it in for 4.3, will be fixed in 4.4
-            p->setDescription(QString("Skipped file that is too large: '%1'").arg(localFile));
-            p->setExplanation(QString("The file is %1 and exceeds the limit of %2.")
-                                 .arg(KGlobal::locale()->formatByteSize(fileInfo.size()))
-                                 .arg(KGlobal::locale()->formatByteSize(maximumFileSize)));
+            p->setDescription(i18nc("%1: filename", "Skipped file that is too large: '%1'", localFile ));
+            p->setExplanation(i18nc("%1: file size, %2: limit file size",
+                                    "The file is %1 and exceeds the limit of %2.",
+                                    KGlobal::locale()->formatByteSize(fileInfo.size()),
+                                    KGlobal::locale()->formatByteSize(maximumFileSize)));
             p->setFinalLocation(DocumentRange(document(), SimpleRange::invalid()));
             kWarning( 9007 ) << p->description() << p->explanation();
             return p;
@@ -278,15 +312,15 @@ KDevelop::ProblemPointer ParseJob::readContents()
                   break;
             }
             p->setFinalLocation(DocumentRange(document(), SimpleRange::invalid()));
-            
+
             kWarning( 9007 ) << "Could not open file" << document().str() << "(path" << localFile << ")" ;
-            
+
             return p;
         }
-        
+
         d->contents.contents = file.readAll(); ///@todo Convert from local encoding to utf-8 if they don't match
         d->contents.modification = KDevelop::ModificationRevision(lastModified);
-        
+
         file.close();
     }
 
@@ -295,7 +329,7 @@ KDevelop::ProblemPointer ParseJob::readContents()
     d->contents.contents.push_back((char)0);
     d->contents.contents.push_back((char)0);
     d->contents.contents.push_back((char)0);
-    
+
     return KDevelop::ProblemPointer();
 }
 
@@ -309,7 +343,7 @@ struct MovingRangeTranslator : public DUChainVisitor
 {
     MovingRangeTranslator(qint64 _source, qint64 _target, MovingInterface* _moving) : source(_source), target(_target), moving(_moving) {
     }
-    
+
     virtual void visit(DUContext* context) {
         translateRange(context);
         ///@todo Also map import-positions
@@ -322,11 +356,11 @@ struct MovingRangeTranslator : public DUChainVisitor
             context->changeUseRange(u, r);
         }
     }
-    
+
     virtual void visit(Declaration* declaration) {
         translateRange(declaration);
     }
-    
+
     void translateRange(DUChainBase* object)
     {
         RangeInRevision r = object->range();
@@ -336,8 +370,14 @@ struct MovingRangeTranslator : public DUChainVisitor
 
     void translateRange(RangeInRevision& r)
     {
-        moving->transformCursor(r.start.line, r.start.column, MovingCursor::MoveOnInsert, source, target);
-        moving->transformCursor(r.end.line, r.end.column, MovingCursor::StayOnInsert, source, target);
+        // PHP and python use top contexts that start at (0, 0) end at INT_MAX, so make sure that doesn't overflow
+        // or translate the start of the top context away from (0, 0)
+        if ( r.start.line != 0 || r.start.column != 0 ) {
+            moving->transformCursor(r.start.line, r.start.column, MovingCursor::MoveOnInsert, source, target);
+        }
+        if ( r.end.line != std::numeric_limits<int>::max() || r.end.column != std::numeric_limits<int>::max() ) {
+            moving->transformCursor(r.end.line, r.end.column, MovingCursor::StayOnInsert, source, target);
+        }
     }
 
     KTextEditor::Range range;
@@ -349,36 +389,36 @@ struct MovingRangeTranslator : public DUChainVisitor
 void ParseJob::translateDUChainToRevision(TopDUContext* context)
 {
     qint64 targetRevision = d->contents.modification.revision;
-    
+
     if(targetRevision == -1)
     {
         kDebug() << "invalid target revision" << targetRevision;
         return;
     }
-    
+
     qint64 sourceRevision;
 
     {
         DUChainReadLocker duChainLock;
-        
+
         Q_ASSERT(context->parsingEnvironmentFile());
-        
+
         // Cannot map if there is no source revision
         sourceRevision = context->parsingEnvironmentFile()->modificationRevision().revision;
-        
+
         if(sourceRevision == -1)
         {
             kDebug() << "invalid source revision" << sourceRevision;
             return;
         }
     }
-    
+
     if(sourceRevision > targetRevision)
     {
         kDebug() << "for document" << document().str() << ": source revision is higher than target revision:" << sourceRevision << " > " << targetRevision;
         return;
     }
-    
+
     ForegroundLock lock;
     if(DocumentChangeTracker* t = d->tracker.data())
     {
@@ -393,18 +433,18 @@ void ParseJob::translateDUChainToRevision(TopDUContext* context)
             kDebug() << "not translating because the document revision does not match the tracker start revision (maybe the document was cleared)";
             return;
         }
-        
+
         if(!t->holdingRevision(sourceRevision) || !t->holdingRevision(targetRevision))
         {
             kDebug() << "lost one of the translation revisions, not doing the map";
             return;
         }
-        
+
         // Perform translation
         MovingInterface* moving = t->documentMovingInterface();
-        
+
         DUChainWriteLocker wLock;
-        
+
         MovingRangeTranslator translator(sourceRevision, targetRevision, moving);
         context->visit(translator);
 
@@ -415,7 +455,7 @@ void ParseJob::translateDUChainToRevision(TopDUContext* context)
             translator.translateRange(r);
             (*problem)->setRange(r);
         }
-        
+
         // Update the modification revision in the meta-data
         ModificationRevision modRev = context->parsingEnvironmentFile()->modificationRevision();
         modRev.revision = targetRevision;
@@ -423,7 +463,62 @@ void ParseJob::translateDUChainToRevision(TopDUContext* context)
     }
 }
 
+bool ParseJob::isUpdateRequired(const IndexedString& languageString)
+{
+    if (abortRequested()) {
+        return false;
+    }
+
+    if (minimumFeatures() & TopDUContext::ForceUpdate) {
+        return true;
+    }
+
+    DUChainReadLocker lock;
+    if (abortRequested()) {
+        return false;
+    }
+    foreach(const ParsingEnvironmentFilePointer &file, DUChain::self()->allEnvironmentFiles(document())) {
+        if (file->language() != languageString) {
+            continue;
+        }
+        if (!file->needsUpdate() && file->featuresSatisfied(minimumFeatures())) {
+            kDebug() << "Already up to date" << document().str();
+            setDuChain(file->topContext());
+            lock.unlock();
+            highlightDUChain();
+            return false;
+        }
+        break;
+    }
+    return !abortRequested();
+}
+
+void ParseJob::highlightDUChain()
+{
+    ENSURE_CHAIN_NOT_LOCKED
+    if (!d->languageSupport->codeHighlighting() || !duChain() || abortRequested()) {
+        // language doesn't support highlighting
+        return;
+    }
+    if (!d->hasReadContents && !d->tracker) {
+        d->tracker = ICore::self()->languageController()->backgroundParser()->trackerForUrl(document());
+    }
+    if (d->tracker) {
+        d->languageSupport->codeHighlighting()->highlightDUChain(duChain());
+    }
+}
+
+ControlFlowGraph* ParseJob::controlFlowGraph()
+{
+    return 0;
+}
+
+DataAccessRepository* ParseJob::dataAccessInformation()
+{
+    return 0;
+}
+
+
 }
 
 #include "parsejob.moc"
-
