@@ -20,7 +20,7 @@
 #include "komparesupport.h"
 #include <config-kdevplatform.h>
 
-#if HAVE_KOMPARE
+#ifdef HAVE_KOMPARE
 
 #include <stddef.h>
 #include <cstddef>
@@ -153,7 +153,7 @@ struct KompareWidgetsPrivate
 {
 };
 
-KompareWidgets::KompareWidgets() : d(0)
+KompareWidgets::KompareWidgets()
 {
 }
 
