@@ -24,6 +24,7 @@
 #include "indexedstring.h"
 #include "appendedlist_static.h"
 #include "repositories/itemrepository.h"
+#include "util/kdevhash.h"
 
 #define ifDebug(x)
 
@@ -75,11 +76,11 @@ public:
       Q_ASSERT(dynamic);
       //this must stay thread-safe(may be called by multiple threads at a time)
       //The thread-safety is given because all threads will have the same result, and it will only be written once at the end.
-      uint hash = m_identifier.hash();
+      KDevHash kdevhash;
+      kdevhash << m_identifier.hash() << m_unique;
       FOREACH_FUNCTION_STATIC(const IndexedTypeIdentifier& templateIdentifier, templateIdentifiers)
-        hash = hash * 13 + IndexedTypeIdentifier(templateIdentifier).hash();
-      hash += m_unique;
-      m_hash = hash;
+        kdevhash << IndexedTypeIdentifier(templateIdentifier).hash();
+      m_hash = kdevhash;
     }
 
     mutable uint m_hash;
@@ -450,15 +451,8 @@ void Identifier::setTemplateIdentifiers(const QList<IndexedTypeIdentifier>& temp
 
 QString Identifier::toString() const
 {
-  if (!this) {
-    return "(null identifier)";
-  }
-
   QString ret = identifier().str();
 
-/*  if(isUnique())
-    ret += "unique";*/
-
   if (templateIdentifiersCount()) {
     ret.append("< ");
     for (uint i = 0; i < templateIdentifiersCount(); ++i) {
@@ -971,7 +965,13 @@ void QualifiedIdentifier::prepareWrite() {
 }
 
 uint IndexedTypeIdentifier::hash() const {
-    return m_identifier.getIndex() * 13 + (m_isConstant ? 17 : 0) + (m_isReference ? 12371 : 0) + (m_isRValue ? 4543 : 0) + m_pointerConstMask * 89321 + m_pointerDepth * 1023;
+    quint32 bitfields = m_isConstant
+      | (m_isReference << 1)
+      | (m_isRValue << 2)
+      | (m_isVolatile << 3)
+      | (m_pointerDepth << 4)
+      | (m_pointerConstMask << 9);
+    return KDevHash() << m_identifier.getIndex() << bitfields;
 }
 
 bool IndexedTypeIdentifier::operator==(const IndexedTypeIdentifier& rhs) const {
@@ -979,6 +979,7 @@ bool IndexedTypeIdentifier::operator==(const IndexedTypeIdentifier& rhs) const {
         && m_isConstant == rhs.m_isConstant
         && m_isReference == rhs.m_isReference
         && m_isRValue == rhs.m_isRValue
+        && m_isVolatile == rhs.m_isVolatile
         && m_pointerConstMask == rhs.m_pointerConstMask
         && m_pointerDepth == rhs.m_pointerDepth;
 }
@@ -1011,14 +1012,25 @@ void IndexedTypeIdentifier::setIsConstant(bool isConst) {
   m_isConstant = isConst;
 }
 
+bool IndexedTypeIdentifier::isVolatile() const
+{
+  return m_isVolatile;
+}
+
+void IndexedTypeIdentifier::setIsVolatile(bool isVolatile)
+{
+  m_isVolatile = isVolatile;
+}
+
 ///Returns the pointer depth. Example for C++: "char*" has pointer-depth 1, "char***" has pointer-depth 3
 int IndexedTypeIdentifier::pointerDepth() const {
   return m_pointerDepth;
 }
 
 /**Sets the pointer-depth to the specified count
-  * For efficiency-reasons the maximum currently is 32. */
+  * For efficiency-reasons the maximum currently is 23. */
 void IndexedTypeIdentifier::setPointerDepth(int depth) {
+  Q_ASSERT(depth <= 23 && depth >= 0);
   ///Clear the mask in removed fields
   for(int s = depth; s < (int)m_pointerDepth; ++s)
     setIsConstPointer(s, false);
@@ -1041,6 +1053,9 @@ QString IndexedTypeIdentifier::toString(bool ignoreExplicitlyGlobal) const {
   QString ret;
   if(isConstant())
     ret += "const ";
+  if(isVolatile())
+    ret += "volatile ";
+
   ret += m_identifier.identifier().toString(ignoreExplicitlyGlobal);
   for(int a = 0; a < pointerDepth(); ++a) {
     ret += '*';
@@ -1060,6 +1075,7 @@ IndexedTypeIdentifier::IndexedTypeIdentifier(KDevelop::IndexedQualifiedIdentifie
 , m_isConstant(false)
 , m_isReference(false)
 , m_isRValue(false)
+, m_isVolatile(false)
 , m_pointerDepth(0)
 , m_pointerConstMask(0)
 { }
@@ -1069,6 +1085,7 @@ IndexedTypeIdentifier::IndexedTypeIdentifier(const QString& identifier, bool isE
 , m_isConstant(false)
 , m_isReference(false)
 , m_isRValue(false)
+, m_isVolatile(false)
 , m_pointerDepth(0)
 , m_pointerConstMask(0)
 { }
@@ -1274,4 +1291,16 @@ void initIdentifierRepository() {
 
 }
 
+QDebug operator<<(QDebug s, const KDevelop::Identifier& identifier)
+{
+  s.nospace() << identifier.toString();
+  return s.space();
+}
+
+QDebug operator<<(QDebug s, const KDevelop::QualifiedIdentifier& identifier)
+{
+  s.nospace() << identifier.toString();
+  return s.space();
+}
+
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
