@@ -73,16 +73,15 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
   }
   
   if( m_previousContext ) {
-    modifyHtml() += navigationHighlight("Back to ");
-    makeLink( m_previousContext->name(), m_previousContext->name(), NavigationAction(m_previousContext) );
-    modifyHtml() += "<br>";
+    QString link = createLink( m_previousContext->name(), m_previousContext->name(), NavigationAction(m_previousContext) );
+    modifyHtml() += navigationHighlight(i18n("Back to %1<br />", link));
   }
   
   KSharedPtr<IDocumentation> doc;
   
   if( !shorten ) {
     doc = ICore::self()->documentationController()->documentationForDeclaration(m_declaration.data());
-    
+
     const AbstractFunctionDeclaration* function = dynamic_cast<const AbstractFunctionDeclaration*>(m_declaration.data());
     if( function ) {
       htmlFunction();
@@ -98,7 +97,7 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
         //Do not show the own name as type of typedefs
         if(useType.cast<TypeAliasType>())
           useType = useType.cast<TypeAliasType>()->type();
-      }
+      } 
       
       eventuallyMakeTypeLinks( useType );
 
@@ -263,11 +262,11 @@ QString AbstractDeclarationNavigationContext::html(bool shorten)
     if(comment.isEmpty() && doc) {
       comment = doc->description();
       if(!comment.isEmpty()) {
-        modifyHtml() += commentHighlight(comment) /*+ "<br />"*/;
+        connect(doc.data(), SIGNAL(descriptionChanged()), this, SIGNAL(contentsChanged()));
+        modifyHtml() += "<br />" + commentHighlight(comment);
       }
     } else if(!comment.isEmpty()) {
-      comment.replace("<br />", "\n"); //do not escape html newlines within the comment
-      comment.replace("<br/>", "\n");
+      comment.replace(QRegExp("<br */>"), "\n"); //do not escape html newlines within the comment
       comment = Qt::escape(comment);
       comment.replace('\n', "<br />"); //Replicate newlines in html
       modifyHtml() += commentHighlight(comment);
@@ -483,6 +482,9 @@ void AbstractDeclarationNavigationContext::htmlClass()
       case ClassDeclarationData::Interface:
         modifyHtml() += "interface ";
         break;
+      case ClassDeclarationData::Trait:
+        modifyHtml() += "trait ";
+        break;
       default:
         modifyHtml() += "<unknown type> ";
         break;
@@ -645,15 +647,17 @@ QStringList AbstractDeclarationNavigationContext::declarationDetails(Declaration
   }
 
   if( decl->isDefinition() )
-    details << "definition";
+    details << i18nc("tells if a declaration is defining the variable's value", "definition");
+  if( decl->isExplicitlyDeleted() )
+    details << "deleted";
 
   if( memberDecl && memberDecl->isForwardDeclaration() )
-    details << "forward";
+    details << i18nc("as in c++ forward declaration", "forward");
 
   AbstractType::Ptr t(decl->abstractType());
   if( t ) {
     if( t->modifiers() & AbstractType::ConstModifier )
-      details << "constant";
+      details << i18nc("a variable that won't change, const", "constant");
     if( t->modifiers() & AbstractType::VolatileModifier )
       details << "volatile";
   }
