@@ -16,8 +16,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef ABSTRACTNAVIGATIONCONTEXT_H
-#define ABSTRACTNAVIGATIONCONTEXT_H
+#ifndef KDEVPLATFORM_ABSTRACTNAVIGATIONCONTEXT_H
+#define KDEVPLATFORM_ABSTRACTNAVIGATIONCONTEXT_H
 
 #include <KDE/KSharedPtr>
 
@@ -25,8 +25,7 @@
 #include "../duchainpointer.h"
 #include "navigationaction.h"
 #include "../types/structuretype.h"
-
-
+#include <util/ksharedobject.h>
 
 namespace KDevelop {
 
@@ -59,8 +58,9 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(Colorizer::Formatting);
 class AbstractNavigationContext;
 typedef KSharedPtr<AbstractNavigationContext> NavigationContextPointer;
 
-class KDEVPLATFORMLANGUAGE_EXPORT AbstractNavigationContext : public KShared
+class KDEVPLATFORMLANGUAGE_EXPORT AbstractNavigationContext : public QObject, public KShared
 {
+  Q_OBJECT
   public:
     AbstractNavigationContext( KDevelop::TopDUContextPointer topContext = KDevelop::TopDUContextPointer(), AbstractNavigationContext* previousContext = 0 );
 
@@ -103,6 +103,9 @@ class KDEVPLATFORMLANGUAGE_EXPORT AbstractNavigationContext : public KShared
 
     NavigationContextPointer execute(const NavigationAction& action);
 
+  Q_SIGNALS:
+    void contentsChanged();
+
   protected:
     
     /// Returns the html font-size prefix (aka. <small> or similar) for the given mode
