@@ -40,7 +40,6 @@
 #include "abstractnavigationcontext.h"
 #include "abstractdeclarationnavigationcontext.h"
 #include "navigationaction.h"
-#include "useswidget.h"
 #include "../../../interfaces/icore.h"
 #include "../../../interfaces/idocumentcontroller.h"
 #include <qapplication.h>
@@ -63,6 +62,9 @@ QSize AbstractNavigationWidget::sizeHint() const
   if(m_browser) {
     updateIdealSize();
     QSize ret = QSize(qMin(m_idealTextSize.width(), maxNavigationWidgetWidth), qMin(m_idealTextSize.height(), 300));
+    if(m_idealTextSize.height()>=300) { //make space for the scrollbar in case it's not fitting
+      ret.rwidth() += 17; //m_browser->verticalScrollBar()->width() returns 100, for some reason
+    }
     
     if(m_currentWidget) {
       ret.setHeight( ret.height() + m_currentWidget->sizeHint().height() );
@@ -82,7 +84,11 @@ void AbstractNavigationWidget::initBrowser(int height) {
   m_browser = new KTextBrowser;
   
   // since we can embed arbitrary HTML we have to make sure it stays readable by forcing a black-white palette
-  m_browser->setPalette( QPalette( Qt::black, Qt::white ) );
+  QPalette p;
+  p.setColor(QPalette::AlternateBase, Qt::white);
+  p.setColor(QPalette::Base, Qt::white);
+  p.setColor(QPalette::Text, Qt::black);
+  m_browser->setPalette( p );
 
   m_browser->setOpenLinks(false);
   m_browser->setOpenExternalLinks(false);
@@ -92,7 +98,7 @@ void AbstractNavigationWidget::initBrowser(int height) {
   layout->setMargin(0);
   setLayout(layout);
 
-  connect( m_browser, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(anchorClicked(const QUrl&)) );
+  connect( m_browser, SIGNAL(anchorClicked(QUrl)), this, SLOT(anchorClicked(QUrl)) );
   
   foreach(QWidget* w, findChildren<QWidget*>())
     w->setContextMenuPolicy(Qt::NoContextMenu);
@@ -119,9 +125,12 @@ void AbstractNavigationWidget::setContext(NavigationContextPointer context, int
   if (!m_startContext)
     m_startContext = m_context;
 
+  bool wasInitial = (m_context == m_startContext);
+  
   m_context = context;
   update();
   
+  emit contextChanged(wasInitial, m_context == m_startContext);
   emit sizeHintChanged();
 }
 
@@ -187,7 +196,7 @@ void AbstractNavigationWidget::update() {
     if(m_context->isWidgetMaximized()) {
       //Leave unused room to the widget
       m_browser->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
-      m_browser->setMaximumHeight(25);
+      m_browser->setMaximumHeight(m_idealTextSize.height());
     }
   }
 
@@ -215,21 +224,6 @@ void AbstractNavigationWidget::anchorClicked(const QUrl& url) {
     setContext( nextContext );
 }
 
-void AbstractNavigationWidget::keyPressEvent(QKeyEvent* event) {
-  QWidget::keyPressEvent(event);
-}
-
-void AbstractNavigationWidget::executeContextAction(QString action) {
-  DUChainReadLocker lock( DUChain::lock() );
-  //We may get deleted while the call to acceptLink, so make sure we don't crash in that case
-  QPointer<AbstractNavigationWidget> thisPtr(this);
-  NavigationContextPointer oldContext = m_context;
-  NavigationContextPointer nextContext = m_context->executeLink(action);
-  
-  if(thisPtr)
-    setContext( nextContext );
-}
-
 void AbstractNavigationWidget::next() {
   DUChainReadLocker lock( DUChain::lock() );
   Q_ASSERT( m_context );
