@@ -16,8 +16,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEV_INCLUDEITEM_H
-#define KDEV_INCLUDEITEM_H
+#ifndef KDEVPLATFORM_INCLUDEITEM_H
+#define KDEVPLATFORM_INCLUDEITEM_H
 
 #include <kurl.h>
 
@@ -25,23 +25,24 @@
 
 namespace KDevelop {
 
-class KDEVPLATFORMLANGUAGE_EXPORT IncludeItem {
+class KDEVPLATFORMLANGUAGE_EXPORT IncludeItem
+{
 public:
   IncludeItem();
 
   ///Constructs the url from basePath and name.
   KUrl url() const;
 
-  ///If this is true, this item represents a sub-directory. Else it represents a file.
-  bool isDirectory;
   ///The name of this include-item, starting behind basePath.
   QString name;
   ///basePath + name = Absolute path of file
   KUrl basePath;
   ///Which path in the include-path was used to find this item?
   int pathNumber;
+  ///If this is true, this item represents a sub-directory. Else it represents a file.
+  bool isDirectory;
 };
 
 }
 
-#endif // KDEV_INCLUDEITEM_H
+#endif // KDEVPLATFORM_INCLUDEITEM_H
