@@ -16,8 +16,8 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifndef OUTPUTVIEWTEST_H
-#define OUTPUTVIEWTEST_H
+#ifndef KDEVPLATFORM_OUTPUTMODELTEST_H
+#define KDEVPLATFORM_OUTPUTMODELTEST_H
 
 #include <QObject>
 
@@ -32,16 +32,9 @@ public:
     explicit OutputModelTest(QObject* parent = 0);
 
 private slots:
-    void testSetFilteringStrategy();
-    void benchmarkAddlinesNofilter();
-    void benchmarkAddlinesCompilerfilter();
-    void benchmarkAddlinesScriptErrorfilter();
-    void benchmarkAddlinesStaticAnalysisfilter();
-    void benchAddLongLine();
-
-private:
-    void do_currentBench(KDevelop::OutputModel& testee);
+    void bench();
+    void bench_data();
 };
 
 }
-#endif // OUTPUTVIEWTEST_H
+#endif // KDEVPLATFORM_OUTPUTMODELTEST_H
