@@ -18,11 +18,12 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef PROJECTVCSPAGE_H
-#define PROJECTVCSPAGE_H
+#ifndef KDEVPLATFORM_PLUGIN_PROJECTVCSPAGE_H
+#define KDEVPLATFORM_PLUGIN_PROJECTVCSPAGE_H
 
 #include "appwizardpagewidget.h"
 #include <QMap>
+#include <vcs/interfaces/ibasicversioncontrol.h>
 
 namespace Ui
 {
@@ -32,7 +33,6 @@ class ProjectVcsPage;
 namespace KDevelop
 {
 class IPluginController;
-class VcsMapping;
 class VcsImportMetadataWidget;
 }
 
@@ -44,18 +44,22 @@ class ProjectVcsPage : public AppWizardPageWidget
 public:
     ProjectVcsPage( KDevelop::IPluginController*, QWidget* parent = 0 );
     ~ProjectVcsPage();
+    bool shouldContinue();
 signals:
     void valid();
     void invalid();
 public slots:
     void setSourceLocation( const KUrl& );
+    void vcsTypeChanged(int);
+    void validateData();
 public:
     QString pluginName() const;
-    KDevelop::VcsMapping mapping() const;
+    KUrl source() const;
+    KDevelop::VcsLocation destination() const;
     QString commitMessage() const;
 private:
-    QMap<int, KDevelop::VcsImportMetadataWidget*> importWidgets;
-    QMap<int, QPair<QString,QString> > vcsPlugins;
+    QList<KDevelop::VcsImportMetadataWidget*> importWidgets;
+    QList<QPair<QString,QString> > vcsPlugins;
     Ui::ProjectVcsPage* m_ui;
 };
 
