@@ -70,14 +70,25 @@ void NativeAppConfigPage::loadFromConfiguration(const KConfigGroup& cfg, KDevelo
     bool b = blockSignals( true );
     projectTarget->setBaseItem( project ? project->projectItem() : 0, true);
     projectTarget->setCurrentItemPath( cfg.readEntry( ExecutePlugin::projectTargetEntry, QStringList() ) );
-    executablePath->setUrl( cfg.readEntry( ExecutePlugin::executableEntry, KUrl() ) );
-    if( cfg.readEntry( ExecutePlugin::isExecutableEntry, false ) ) 
-    {
-        executableRadio->setChecked( true );
-    } else 
-    {
+
+    KUrl exe = cfg.readEntry( ExecutePlugin::executableEntry, KUrl());
+    if( !exe.isEmpty() || project ){
+        executablePath->setUrl( !exe.isEmpty() ? exe : project->folder() );
+    }else{
+        KDevelop::IProjectController* pc = KDevelop::ICore::self()->projectController();
+        if( pc ){
+            executablePath->setUrl( pc->projects().count() ? pc->projects().first()->folder() : KUrl() );
+        }
+    }
+
+    //executablePath->setFilter("application/x-executable");
+
+    executableRadio->setChecked( true );
+    if ( !cfg.readEntry( ExecutePlugin::isExecutableEntry, false ) && projectTarget->count() ){
         projectTargetRadio->setChecked( true );
     }
+
+    arguments->setClearButtonShown( true );
     arguments->setText( cfg.readEntry( ExecutePlugin::argumentsEntry, "" ) );
     workingDirectory->setUrl( cfg.readEntry( ExecutePlugin::workingDirEntry, KUrl() ) );
     environment->setCurrentProfile( cfg.readEntry( ExecutePlugin::environmentGroupEntry, "default" ) );
@@ -149,7 +160,7 @@ NativeAppConfigPage::NativeAppConfigPage( QWidget* parent )
     connect( terminal, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()) );
     connect( dependencyAction, SIGNAL(currentIndexChanged(int)), SLOT(activateDeps(int)) );
     connect( targetDependency, SIGNAL(textChanged(QString)), SLOT(depEdited(QString)));
-    connect( browseProject, SIGNAL(clicked(bool)), targetDependency, SLOT(selectItemDialog()));
+    connect( browseProject, SIGNAL(clicked(bool)), SLOT(selectItemDialog()));
 }
 
 
@@ -235,6 +246,13 @@ void NativeAppConfigPage::addDep()
 //     dependencies->selectionModel()->select( dependencies->model()->index( dependencies->model()->rowCount() - 1, 0, QModelIndex() ), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::SelectCurrent );
 }
 
+void NativeAppConfigPage::selectItemDialog()
+{
+    if(targetDependency->selectItemDialog()) {
+        addDep();
+    }
+}
+
 void NativeAppConfigPage::removeDep()
 {
     QList<QListWidgetItem*> list = dependencies->selectedItems();
@@ -410,10 +428,19 @@ QList<KDevelop::ProjectTargetItem*> targetsInFolder(KDevelop::ProjectFolderItem*
     return ret;
 }
 
+bool actionLess(QAction* a, QAction* b)
+{
+    return a->text() < b->text();
+}
+
+bool menuLess(QMenu* a, QMenu* b)
+{
+    return a->title() < b->title();
+}
+
 QMenu* NativeAppConfigType::launcherSuggestions()
 {
-    QMenu* ret = new QMenu;
-    ret->setTitle(i18n("Project Executables"));
+    QMenu* ret = new QMenu(i18n("Project Executables"));
     
     KDevelop::ProjectModel* model = KDevelop::ICore::self()->projectController()->projectModel();
     QList<KDevelop::IProject*> projects = KDevelop::ICore::self()->projectController()->projects();
@@ -421,18 +448,47 @@ QMenu* NativeAppConfigType::launcherSuggestions()
     foreach(KDevelop::IProject* project, projects) {
         if(project->projectFileManager()->features() & KDevelop::IProjectFileManager::Targets) {
             QList<KDevelop::ProjectTargetItem*> targets=targetsInFolder(project->projectItem());
-            
-            QMenu* projectMenu = ret->addMenu(project->name());
+            QHash<KDevelop::ProjectBaseItem*, QList<QAction*> > targetsContainer;
+            QMenu* projectMenu = ret->addMenu(KIcon("project-development"), project->name());
             foreach(KDevelop::ProjectTargetItem* target, targets) {
                 if(target->executable()) {
                     QStringList path = model->pathFromIndex(target->index());
-                    QAction* act = projectMenu->addAction(QString());
-                    act->setData(KDevelop::joinWithEscaping(path, '/','\\'));
-                    path.removeFirst();
-                    act->setText(path.join("/"));
-                    connect(act, SIGNAL(triggered(bool)), SLOT(suggestionTriggered()));
+                    if(!path.isEmpty()){
+                        QAction* act = new QAction(projectMenu);
+                        act->setData(KDevelop::joinWithEscaping(path, '/','\\'));
+                        act->setProperty("name", target->text());
+                        path.removeFirst();
+                        act->setText(path.join("/"));
+                        act->setIcon(KIcon("system-run"));
+                        connect(act, SIGNAL(triggered(bool)), SLOT(suggestionTriggered()));
+                        targetsContainer[target->parent()].append(act);
+                    }
                 }
             }
+
+            QList<QAction*> separateActions;
+            QList<QMenu*> submenus;
+            foreach(KDevelop::ProjectBaseItem* folder, targetsContainer.keys()) {
+                QList<QAction*> actions = targetsContainer.value(folder);
+                if(actions.size()==1 || !folder->parent()) {
+                    separateActions += actions.first();
+                } else {
+                    foreach(QAction* a, actions) {
+                        a->setText(a->property("name").toString());
+                    }
+                    QStringList path = model->pathFromIndex(folder->index());
+                    path.removeFirst();
+                    QMenu* submenu = new QMenu(path.join("/"));
+                    submenu->addActions(actions);
+                    submenus += submenu;
+                }
+            }
+            qSort(separateActions.begin(), separateActions.end(), actionLess);
+            qSort(submenus.begin(), submenus.end(), menuLess);
+            foreach(QMenu* m, submenus)
+                projectMenu->addMenu(m);
+            projectMenu->addActions(separateActions);
+
             projectMenu->setEnabled(!projectMenu->isEmpty());
         }
     }
