@@ -181,9 +181,9 @@ void NativeAppJob::processError( QProcess::ProcessError error )
     if( error == QProcess::FailedToStart )
     {
         setError( -1 );
-        QString errmsg =  i18n("Could not start program '%1'. Make sure that the "
-                           "path is specified correctly.", proc->program().join(" ") );
-        KMessageBox::error( KDevelop::ICore::self()->uiController()->activeMainWindow(), errmsg, i18n("Could not start application") );
+        QString errmsg =  i18n("*** Could not start program '%1'. Make sure that the "
+                           "path is specified correctly ***", proc->program().join(" ") );
+        appendLine( errmsg );
         setErrorText( errmsg );
         emitResult();
     }
