@@ -22,10 +22,11 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#ifndef GIT_INIT_H
-#define GIT_INIT_H
+#ifndef KDEVPLATFORM_PLUGIN_GIT_INIT_H
+#define KDEVPLATFORM_PLUGIN_GIT_INIT_H
 
 #include <QtCore/QObject>
+#include <QtCore/QString>
 
 class GitPlugin;
 
@@ -53,6 +54,7 @@ private slots:
     void testAdd();
     void testCommit();
     void testBranching();
+    void testBranch(const QString &branchName);
     void revHistory();
     void testAnnotation();
     void testRemoveEmptyFolder();
