@@ -29,24 +29,28 @@
 
 using namespace KDevelop;
 
-GrepOutputItem::GrepOutputItem(DocumentChangePointer change, const QString &text)
+GrepOutputItem::GrepOutputItem(DocumentChangePointer change, const QString &text, bool checkable)
     : QStandardItem(), m_change(change)
 {
     setText(text);
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
     
-    setCheckable(true);
-    setCheckState(Qt::Checked);
+    setCheckable(checkable);
+    if(checkable)
+        setCheckState(Qt::Checked);
 }
 
-GrepOutputItem::GrepOutputItem(const QString& filename, const QString& text)
+GrepOutputItem::GrepOutputItem(const QString& filename, const QString& text, bool checkable)
     : QStandardItem(), m_change(new DocumentChange(IndexedString(filename), SimpleRange::invalid(), QString(), QString()))
 {
     setText(text);
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-    setCheckable(true);
-    setTristate(true);
-    setCheckState(Qt::Checked);
+    setCheckable(checkable);
+    if(checkable)
+    {
+        setTristate(true);
+        setCheckState(Qt::Checked);
+    }
 }
 
 int GrepOutputItem::lineNumber() const 
@@ -142,7 +146,7 @@ QVariant GrepOutputItem::data ( int role ) const {
         QString start = Qt::escape(text().left(m_change->m_range.start.column));
         QString repl  = "<b>" + Qt::escape(grepModel->replacementFor(m_change->m_oldText)) + "</b>";
         QString end   = Qt::escape(text().right(text().length() - m_change->m_range.end.column));
-        return QVariant((start + repl + end).trimmed());
+        return QVariant(QString(start + repl + end).trimmed());
     }
     else
     {
@@ -157,7 +161,7 @@ GrepOutputItem::~GrepOutputItem()
 
 GrepOutputModel::GrepOutputModel( QObject *parent )
     : QStandardItemModel( parent ), m_regExp(""), m_replacement(""), m_replacementTemplate(""), m_finalReplacement(""),
-      m_finalUpToDate(false), m_rootItem(0), m_fileCount(0), m_matchCount(0)
+      m_finalUpToDate(false), m_rootItem(0), m_fileCount(0), m_matchCount(0), m_itemsCheckable(false)
 {
     connect(this, SIGNAL(itemChanged(QStandardItem*)),
               this, SLOT(updateCheckState(QStandardItem*)));
@@ -169,6 +173,9 @@ GrepOutputModel::~GrepOutputModel()
 void GrepOutputModel::clear()
 {
     QStandardItemModel::clear();
+    // the above clear() also destroys the root item, so invalidate the pointer
+    m_rootItem = 0;
+
     m_fileCount = 0;
     m_matchCount = 0;
 }
@@ -195,9 +202,7 @@ QString GrepOutputModel::replacementFor(const QString &text)
 {
     if(!m_finalUpToDate)
     {
-        QString r = (m_regExp.patternSyntax() == QRegExp::Wildcard) ?
-                     m_replacement : QString(m_replacement).replace("\\", "\\\\");
-        m_finalReplacement = substitudePattern(m_replacementTemplate, r);
+        m_finalReplacement = substitudePattern(m_replacementTemplate, m_replacement);
         m_finalUpToDate = true;
     }
     return QString(text).replace(m_regExp, m_finalReplacement);
@@ -222,13 +227,11 @@ void GrepOutputModel::activate( const QModelIndex &idx )
     if(!doc)
         return;
     if (KTextEditor::Document* tdoc = doc->textDocument()) {
-        QString text = tdoc->line(line);
-        int index = m_regExp.indexIn(text);
-        if (index!=-1) {
-            range.setBothLines(line);
-            range.start().setColumn(index);
-            range.end().setColumn(index+m_regExp.matchedLength());
-            doc->setTextSelection( range );
+        KTextEditor::Range matchRange = grepitem->change()->m_range.textRange();
+        QString actualText = tdoc->text(matchRange);
+        QString expectedText = grepitem->change()->m_oldText;
+        if (actualText == expectedText) {
+            range = matchRange;
         }
     }
 
@@ -237,10 +240,24 @@ void GrepOutputModel::activate( const QModelIndex &idx )
 
 QModelIndex GrepOutputModel::previousItemIndex(const QModelIndex &currentIdx) const
 {
-    int row = currentIdx.row();
-    GrepOutputItem* current_item = dynamic_cast<GrepOutputItem*>(itemFromIndex(currentIdx));
-    if(current_item->parent() != 0) //we do nothing if it's the root item
-    {
+    GrepOutputItem* current_item = 0;
+
+    if (!currentIdx.isValid()) {
+        // no item selected, search recursively for the last item in search results
+        QStandardItem *it = item(0,0);
+        while (it) {
+            QStandardItem *child = it->child( it->rowCount() - 1 );
+            if (!child) return it->index();
+            it = child;
+        }
+        return QModelIndex();
+    }
+    else
+        current_item = dynamic_cast<GrepOutputItem*>(itemFromIndex(currentIdx));
+
+    if (current_item->parent() != 0) {
+        int row = currentIdx.row();
+
         if(!current_item->isText()) // the item is a file
         {
             int item_row = current_item->row();
@@ -270,10 +287,24 @@ QModelIndex GrepOutputModel::previousItemIndex(const QModelIndex &currentIdx) co
 
 QModelIndex GrepOutputModel::nextItemIndex(const QModelIndex &currentIdx) const
 {
-    int row = currentIdx.row();
-    GrepOutputItem* current_item = dynamic_cast<GrepOutputItem*>(itemFromIndex(currentIdx));
-    if(current_item->parent() != 0) //we do nothing if it's the root item
-    {
+    GrepOutputItem* current_item = 0;
+
+    if (!currentIdx.isValid()) {
+        QStandardItem *it = item(0,0);
+        if (!it) return QModelIndex();
+        current_item = dynamic_cast<GrepOutputItem*>(it);
+    }
+    else
+        current_item = dynamic_cast<GrepOutputItem*>(itemFromIndex(currentIdx));
+
+    if (current_item->parent() == 0) {
+        // root item with overview of search results
+        if (current_item->rowCount() > 0)
+            return nextItemIndex(current_item->child(0)->index());
+        else
+            return QModelIndex();
+    } else {
+        int row = currentIdx.row();
         if(!current_item->isText()) // the item is a file
         {
             int item_row = current_item->row();
@@ -299,6 +330,37 @@ QModelIndex GrepOutputModel::nextItemIndex(const QModelIndex &currentIdx) const
     return currentIdx;
 }
 
+const GrepOutputItem *GrepOutputModel::getRootItem() const {
+    return m_rootItem;
+}
+
+bool GrepOutputModel::itemsCheckable() const
+{
+    return m_itemsCheckable;
+}
+
+void GrepOutputModel::makeItemsCheckable(bool checkable)
+{
+    if(m_itemsCheckable == checkable)
+        return;
+    if(m_rootItem)
+        makeItemsCheckable(checkable, m_rootItem);
+    m_itemsCheckable = checkable;
+}
+
+void GrepOutputModel::makeItemsCheckable(bool checkable, GrepOutputItem* item)
+{
+    item->setCheckable(checkable);
+    if(checkable)
+    {
+        item->setCheckState(Qt::Checked);
+        if(item->rowCount() && checkable)
+            item->setTristate(true);
+    }
+    for(int row = 0; row < item->rowCount(); ++row)
+        makeItemsCheckable(checkable, static_cast<GrepOutputItem*>(item->child(row, 0)));
+}
+
 void GrepOutputModel::appendOutputs( const QString &filename, const GrepOutputItem::List &items )
 {
     if(items.isEmpty())
@@ -306,26 +368,35 @@ void GrepOutputModel::appendOutputs( const QString &filename, const GrepOutputIt
     
     if(rowCount() == 0)
     {
-        m_rootItem = new GrepOutputItem("", "");
+        m_rootItem = new GrepOutputItem("", "", m_itemsCheckable);
         appendRow(m_rootItem);
     }
     
     m_fileCount  += 1;
     m_matchCount += items.length();
 
-    const QString matchText = i18np("1 match", "%1 matches", m_matchCount);
-    const QString fileText = i18np("1 file", "%1 files", m_fileCount);
+    const QString matchText = i18np("<b>1</b> match", "<b>%1</b> matches", m_matchCount);
+    const QString fileText = i18np("<b>1</b> file", "<b>%1</b> files", m_fileCount);
 
-    m_rootItem->setText(i18nc("%1 is e.g. '4 matches', %2 is e.g. '1 file'", "%1 in %2", matchText, fileText));
+    m_rootItem->setText(i18nc("%1 is e.g. '4 matches', %2 is e.g. '1 file'", "<h3>%1 in %2</h3>", matchText, fileText));
     
-    QString fnString = i18np("%2 <i>(one match)</i>", "%2 <i>(%1 matches)</i>", items.length(), ICore::self()->projectController()->prettyFileName(filename));
+    QString fnString = i18np("<big>%2 <i>(one match)</i></big>", "<big>%2 <i>(%1 matches)</i></big>", items.length(), ICore::self()->projectController()->prettyFileName(filename));
 
-    GrepOutputItem *fileItem = new GrepOutputItem(filename, fnString);
+    GrepOutputItem *fileItem = new GrepOutputItem(filename, fnString, m_itemsCheckable);
     m_rootItem->appendRow(fileItem);
     //m_tracker.addUrl(KUrl(filename));
     foreach( const GrepOutputItem& item, items )
     {
-        fileItem->appendRow(new GrepOutputItem(item));
+        GrepOutputItem* copy = new GrepOutputItem(item);
+        copy->setCheckable(m_itemsCheckable);
+        if(m_itemsCheckable)
+        {
+            copy->setCheckState(Qt::Checked);
+            if(copy->rowCount())
+                copy->setTristate(true);
+        }
+        
+        fileItem->appendRow(copy);
     }
 }
 
@@ -349,6 +420,8 @@ void GrepOutputModel::updateCheckState(QStandardItem* item)
 void GrepOutputModel::doReplacements()
 {
     Q_ASSERT(m_rootItem);
+    if (!m_rootItem)
+        return; // nothing to do, abort
 
     DocumentChangeSet changeSet;
     changeSet.setFormatPolicy(DocumentChangeSet::NoAutoFormat);
@@ -377,10 +450,28 @@ void GrepOutputModel::doReplacements()
     {
         DocumentChangePointer ch = result.m_reasonChange;
         if(ch)
-            emit showErrorMessage(i18n("Failed to replace <b>%1</b> by <b>%2</b> in %3:%4:%5").arg(Qt::escape(ch->m_oldText)).arg(Qt::escape(ch->m_newText))
-                        .arg(ch->m_document.toUrl().toLocalFile()).arg(ch->m_range.start.line + 1).arg(ch->m_range.start.column + 1));
+            emit showErrorMessage(i18nc("%1 is the old text, %2 is the new text, %3 is the file path, %4 and %5 are its row and column", "Failed to replace <b>%1</b> by <b>%2</b> in %3:%4:%5", Qt::escape(ch->m_oldText), Qt::escape(ch->m_newText), ch->m_document.toUrl().toLocalFile(), ch->m_range.start.line + 1, ch->m_range.start.column + 1));
     }
 }
 
+void GrepOutputModel::showMessageSlot(IStatus* status, const QString& message)
+{
+    m_savedMessage = message;
+    m_savedIStatus = status;
+    showMessageEmit();
+}
+
+void GrepOutputModel::showMessageEmit()
+{
+    emit showMessage(m_savedIStatus, m_savedMessage);
+}
+
+bool GrepOutputModel::hasResults()
+{
+    return(m_matchCount > 0);
+}
+
+
+
 #include "grepoutputmodel.moc"
 
