@@ -32,6 +32,7 @@
 #include <sublime/area.h>
 #include <sublime/view.h>
 #include <sublime/document.h>
+#include <sublime/mainwindow.h>
 #include <KLineEdit>
 #include <KTextEditor/Document>
 #include <QMenu>
@@ -81,6 +82,9 @@ PatchReviewToolView::PatchReviewToolView( QWidget* parent, PatchReviewPlugin* pl
     connect( plugin, SIGNAL( startingNewReview() ), SLOT( startingNewReview() ) );
     connect( ICore::self()->documentController(), SIGNAL( documentActivated( KDevelop::IDocument* ) ), this, SLOT( documentActivated( KDevelop::IDocument* ) ) );
 
+    Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
+    connect(w, SIGNAL(areaChanged(Sublime::Area*)), m_plugin, SLOT(areaChanged(Sublime::Area*)));
+
     showEditDialog();
     patchChanged();
 }
@@ -495,7 +499,7 @@ void PatchReviewToolView::kompareModelChanged() {
 
             VcsStatusInfo status;
             status.setUrl( file );
-            status.setState( VcsStatusInfo::ItemModified );
+            status.setState( cnt>0 ? VcsStatusInfo::ItemModified : VcsStatusInfo::ItemUpToDate );
 
             m_fileModel->updateState( status, cnt );
         }
