@@ -22,22 +22,13 @@
 #include "projectmanagerview.h"
 
 #include <QtGui/QHeaderView>
-#include <QtGui/QVBoxLayout>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QStandardItem>
-#include <QtGui/QToolButton>
 #include <QtGui/QKeyEvent>
 
-#include <kxmlguiwindow.h>
 #include <kiconloader.h>
-#include <kmenu.h>
 #include <kdebug.h>
 #include <kurl.h>
 #include <klocale.h>
 #include <kactioncollection.h>
-#include <kfadewidgeteffect.h>
-#include <kcombobox.h>
-#include <kjob.h>
 #include <KLineEdit>
 
 #include <interfaces/iselectioncontroller.h>
@@ -46,52 +37,22 @@
 #include <interfaces/isession.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iuicontroller.h>
-#include <interfaces/iruncontroller.h>
 #include <interfaces/idocumentcontroller.h>
 #include <interfaces/iproject.h>
-#include <project/interfaces/ibuildsystemmanager.h>
-#include <project/interfaces/iprojectbuilder.h>
+#include <project/projectproxymodel.h>
 #include <project/projectmodel.h>
 
 #include "../openwith/iopenwith.h"
 
-#include <KParts/MainWindow>
 #include <sublime/mainwindow.h>
 
 #include "tests/modeltest.h"
-#include <project/projectproxymodel.h>
 #include "projectmanagerviewplugin.h"
+#include "vcsoverlayproxymodel.h"
 #include "ui_projectmanagerview.h"
 
 using namespace KDevelop;
 
-//BEGIN ProjectManagerFilterAction
-
-ProjectManagerFilterAction::ProjectManagerFilterAction(ProjectManagerView* parent)
-    : KAction( parent )
-    , m_projectManagerView(parent)
-{
-    setIcon(KIcon("view-filter"));
-    setText(i18n("Filter..."));
-    setToolTip(i18n("Insert wildcard patterns to filter the project view"
-                    " for files and targets for matching items."));
-}
-
-QWidget* ProjectManagerFilterAction::createWidget( QWidget* parent )
-{
-    KLineEdit* edit = new KLineEdit(parent);
-    edit->setClickMessage(i18n("Filter..."));
-    edit->setClearButtonShown(true);
-    connect(edit, SIGNAL(textChanged(QString)), this, SIGNAL(filterChanged(QString)));
-
-    const QString filterString = m_projectManagerView->filterString();
-    edit->setText(filterString);
-
-    return edit;
-}
-
-//END ProjectManagerFilterAction
-
 ProjectManagerViewItemContext::ProjectManagerViewItemContext(const QList< ProjectBaseItem* >& items, ProjectManagerView* view)
     : ProjectItemContext(items), m_view(view)
 {
@@ -105,7 +66,6 @@ ProjectManagerView *ProjectManagerViewItemContext::view() const
 
 static const char* sessionConfigGroup = "ProjectManagerView";
 static const char* splitterStateConfigKey = "splitterState";
-static const char* filterConfigKey = "filter";
 static const int projectTreeViewStrechFactor = 75; // %
 static const int projectBuildSetStrechFactor = 25; // %
 
@@ -147,21 +107,11 @@ ProjectManagerView::ProjectManagerView( ProjectManagerViewPlugin* plugin, QWidge
     m_ui->buildSetView->setProjectView( this );
 
     m_modelFilter = new ProjectProxyModel( this );
-    m_modelFilter->setDynamicSortFilter( true );
     m_modelFilter->setSourceModel(ICore::self()->projectController()->projectModel());
+    m_overlayProxy = new VcsOverlayProxyModel( this );
+    m_overlayProxy->setSourceModel(m_modelFilter);
 
-    m_ui->projectTreeView->setModel( m_modelFilter );
-
-    QString filterText;
-    if (pmviewConfig.hasKey(filterConfigKey)) {
-        filterText = pmviewConfig.readEntry(filterConfigKey, QString());
-    }
-    setFilterString(filterText);
-
-    ProjectManagerFilterAction* filterAction = new ProjectManagerFilterAction(this);
-    connect(filterAction, SIGNAL(filterChanged(QString)),
-            this, SLOT(setFilterString(QString)));
-    addAction(filterAction);
+    m_ui->projectTreeView->setModel( m_overlayProxy );
 
     connect( m_ui->projectTreeView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
              this, SLOT(selectionChanged()) );
@@ -210,7 +160,7 @@ void ProjectManagerView::selectionChanged()
     QList<ProjectBaseItem*> selected;
     foreach( const QModelIndex& idx, m_ui->projectTreeView->selectionModel()->selectedRows() )
     {
-        selected << m_modelFilter->itemFromProxyIndex( idx );
+        selected << ICore::self()->projectController()->projectModel()->itemFromIndex(indexFromView( idx ));
     }
     selected.removeAll(0);
     KDevelop::ICore::self()->selectionController()->updateSelection( new ProjectManagerViewItemContext( selected, this ) );
@@ -225,8 +175,9 @@ ProjectManagerView::~ProjectManagerView()
 {
     KConfigGroup pmviewConfig(ICore::self()->activeSession()->config(), sessionConfigGroup);
     pmviewConfig.writeEntry(splitterStateConfigKey, m_ui->splitter->saveState());
-    pmviewConfig.writeEntry(filterConfigKey, m_filterString);
     pmviewConfig.sync();
+
+    delete m_ui;
 }
 
 QList<KDevelop::ProjectBaseItem*> ProjectManagerView::selectedItems() const
@@ -234,8 +185,7 @@ QList<KDevelop::ProjectBaseItem*> ProjectManagerView::selectedItems() const
     QList<KDevelop::ProjectBaseItem*> items;
     foreach( const QModelIndex &idx, m_ui->projectTreeView->selectionModel()->selectedIndexes() )
     {
-        KDevelop::ProjectBaseItem* item =
-                ICore::self()->projectController()->projectModel()->itemFromIndex( m_modelFilter->mapToSource(idx) );
+        KDevelop::ProjectBaseItem* item = ICore::self()->projectController()->projectModel()->itemFromIndex(indexFromView(idx));
         if( item )
             items << item;
         else
@@ -248,7 +198,7 @@ void ProjectManagerView::selectItems(const QList< ProjectBaseItem* >& items)
 {
     QItemSelection selection;
     foreach (ProjectBaseItem *item, items) {
-        QModelIndex indx = m_modelFilter->mapFromSource(item->model()->indexFromItem(item));
+        QModelIndex indx = indexToView(item->index());
         selection.append(QItemSelectionRange(indx, indx));
         m_ui->projectTreeView->setCurrentIndex(indx);
     }
@@ -257,7 +207,7 @@ void ProjectManagerView::selectItems(const QList< ProjectBaseItem* >& items)
 
 void ProjectManagerView::expandItem(ProjectBaseItem* item)
 {
-    m_ui->projectTreeView->expand( m_modelFilter->mapFromSource(item->model()->indexFromItem(item)));
+    m_ui->projectTreeView->expand( indexToView(item->index()));
 }
 
 void ProjectManagerView::locateCurrentDocument()
@@ -277,7 +227,7 @@ void ProjectManagerView::locateCurrentDocument()
     QModelIndex bestMatch;
     foreach (IProject* proj, ICore::self()->projectController()->projects()) {
         foreach (KDevelop::ProjectFileItem* item, proj->filesForUrl(doc->url())) {
-            QModelIndex index = m_modelFilter->proxyIndexFromItem(item);
+            QModelIndex index = indexToView(item->index());
             if (index.isValid()) {
                 if (!bestMatch.isValid()) {
                     bestMatch = index;
@@ -304,15 +254,14 @@ void ProjectManagerView::openUrl( const KUrl& url )
     IOpenWith::openFiles(KUrl::List() << url);
 }
 
-QString ProjectManagerView::filterString() const
+QModelIndex ProjectManagerView::indexFromView(const QModelIndex& index) const
 {
-    return m_filterString;
+    return m_modelFilter->mapToSource( m_overlayProxy->mapToSource(index) );
 }
 
-void ProjectManagerView::setFilterString(const QString &text)
+QModelIndex ProjectManagerView::indexToView(const QModelIndex& index) const
 {
-    m_filterString = text;
-    m_modelFilter->setFilterString(text);
+    return m_overlayProxy->mapFromSource( m_modelFilter->mapFromSource(index) );
 }
 
 #include "projectmanagerview.moc"
