@@ -18,8 +18,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVPROJECTMANAGERVIEW_H
-#define KDEVPROJECTMANAGERVIEW_H
+#ifndef KDEVPLATFORM_PLUGIN_PROJECTMANAGERVIEW_H
+#define KDEVPLATFORM_PLUGIN_PROJECTMANAGERVIEW_H
 
 #include <QtGui/QWidget>
 #include <KAction>
@@ -35,6 +35,7 @@ class ProjectManagerView;
 }
 
 class ProjectProxyModel;
+class VcsOverlayProxyModel;
 
 namespace KDevelop
 {
@@ -44,22 +45,6 @@ class ProjectBaseItem;
 class ProjectManagerView;
 class ProjectManagerViewPlugin;
 
-class ProjectManagerFilterAction : public KAction {
-    Q_OBJECT
-
-public:
-    explicit ProjectManagerFilterAction(ProjectManagerView* parent);
-
-signals:
-    void filterChanged(const QString& filter);
-
-protected:
-    virtual QWidget* createWidget( QWidget* parent );
-
-private:
-    ProjectManagerView* m_projectManagerView;
-};
-
 //own subclass to the current view can be passed from ProjectManagetView to ProjectManagerViewPlugin
 class ProjectManagerViewItemContext : public KDevelop::ProjectItemContext
 {
@@ -81,7 +66,6 @@ public:
     QList<KDevelop::ProjectBaseItem*> selectedItems() const;
     void selectItems(const QList<KDevelop::ProjectBaseItem*> &items);
     void expandItem(KDevelop::ProjectBaseItem *item);
-    QString filterString() const;
 
 protected:
     virtual bool eventFilter(QObject* obj, QEvent* event);
@@ -91,16 +75,18 @@ private slots:
     void locateCurrentDocument();
     void updateSyncAction();
     void openUrl( const KUrl& );
-    void setFilterString(const QString&);
 
 private:
+    QModelIndex indexFromView(const QModelIndex& index) const;
+    QModelIndex indexToView(const QModelIndex& index) const;
+
     QAction* m_syncAction;
     Ui::ProjectManagerView* m_ui;
     QStringList m_cachedFileList;
     ProjectProxyModel* m_modelFilter;
+    VcsOverlayProxyModel* m_overlayProxy;
     ProjectManagerViewPlugin* m_plugin;
-    QString m_filterString;
 };
 
-#endif // KDEVPROJECTMANAGER_H
+#endif // KDEVPLATFORM_PLUGIN_PROJECTMANAGERVIEW_H
 
