@@ -72,16 +72,6 @@ class KDevProjectManagerViewFactory: public KDevelop::IToolViewFactory
         {
             return "org.kdevelop.ProjectsView";
         }
-        virtual QList< QAction* > contextMenuActions(QWidget* viewWidget) const
-        {
-            QList<QAction*> actions;
-            foreach(QAction* action, viewWidget->actions()) {
-                if (!qobject_cast<ProjectManagerFilterAction*>(action)) {
-                    actions << action;
-                }
-            }
-            return actions;
-        }
     private:
         ProjectManagerViewPlugin *mplugin;
 };
@@ -92,7 +82,7 @@ public:
     ProjectManagerViewPluginPrivate()
     {}
     KDevProjectManagerViewFactory *factory;
-    QList<KDevelop::ProjectBaseItem*> ctxProjectItemList;
+    QList<QPersistentModelIndex> ctxProjectItemList;
     KAction* m_buildAll;
     KAction* m_build;
     KAction* m_install;
@@ -101,6 +91,16 @@ public:
     KAction* m_prune;
 };
 
+static QList<ProjectBaseItem*> itemsFromIndexes(const QList<QPersistentModelIndex>& indexes)
+{
+    QList<ProjectBaseItem*> items;
+    ProjectModel* model = ICore::self()->projectController()->projectModel();
+    foreach(const QModelIndex& index, indexes) {
+        items += model->itemFromIndex(index);
+    }
+    return items;
+}
+
 ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVariantList& )
         : IPlugin( ProjectManagerFactory::componentData(), parent ), d(new ProjectManagerViewPluginPrivate)
 {
@@ -119,6 +119,7 @@ ProjectManagerViewPlugin::ProjectManagerViewPlugin( QObject *parent, const QVari
     d->m_install = new KAction( i18n("Install Selection"), this );
     d->m_install->setIconText( i18n("Install") );
     d->m_install->setIcon(KIcon("run-build-install"));
+    d->m_install->setShortcut( Qt::SHIFT + Qt::Key_F8 );
     d->m_install->setEnabled( false );
     connect( d->m_install, SIGNAL(triggered()), this, SLOT(installProjectItems()) );
     actionCollection()->addAction( "project_install", d->m_install );
@@ -217,7 +218,7 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
     needsPaste = needsCreateFolder;
     
     foreach( ProjectBaseItem* item, items ) {
-        d->ctxProjectItemList << item;
+        d->ctxProjectItemList << item->index();
         //needsBuildItems if items are limited to targets and buildfolders
         needsBuildItems &= item->target() || item->type() == ProjectBaseItem::BuildFolder;
 
@@ -260,7 +261,8 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
         action->setIcon(KIcon("run-clean"));
         connect( action, SIGNAL(triggered()), this, SLOT(cleanItemsFromContextMenu()) );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
-        action = new KAction( i18n( "Add to Buildset" ), this );
+        action = new KAction( i18n( "Add to Build Set" ), this );
+        action->setIcon(KIcon("list-add"));
         connect( action, SIGNAL(triggered()), this, SLOT(addItemsFromContextMenuToBuildset()) );
         menuExt.addAction( ContextMenuExtension::BuildGroup, action );
     }
@@ -311,8 +313,10 @@ ContextMenuExtension ProjectManagerViewPlugin::contextMenuExtension( KDevelop::C
 void ProjectManagerViewPlugin::closeProjects()
 {
     QList<KDevelop::IProject*> projectsToClose;
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+    ProjectModel* model = ICore::self()->projectController()->projectModel();
+    foreach( const QModelIndex& index, d->ctxProjectItemList )
     {
+        KDevelop::ProjectBaseItem* item = model->itemFromIndex(index);
         if( !projectsToClose.contains( item->project() ) )
         {
             projectsToClose << item->project();
@@ -328,19 +332,19 @@ void ProjectManagerViewPlugin::closeProjects()
 
 void ProjectManagerViewPlugin::installItemsFromContextMenu()
 {
-    runBuilderJob( BuilderJob::Install, d->ctxProjectItemList );
+    runBuilderJob( BuilderJob::Install, itemsFromIndexes(d->ctxProjectItemList) );
     d->ctxProjectItemList.clear();
 }
 
 void ProjectManagerViewPlugin::cleanItemsFromContextMenu()
 {
-    runBuilderJob( BuilderJob::Clean, d->ctxProjectItemList );
+    runBuilderJob( BuilderJob::Clean, itemsFromIndexes( d->ctxProjectItemList ) );
     d->ctxProjectItemList.clear();
 }
 
 void ProjectManagerViewPlugin::buildItemsFromContextMenu()
 {
-    runBuilderJob( BuilderJob::Build, d->ctxProjectItemList );
+    runBuilderJob( BuilderJob::Build, itemsFromIndexes( d->ctxProjectItemList ) );
     d->ctxProjectItemList.clear();
 }
 
@@ -417,7 +421,7 @@ void ProjectManagerViewPlugin::buildProjectItems()
 
 void ProjectManagerViewPlugin::addItemsFromContextMenuToBuildset( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ))
     {
         ICore::self()->projectController()->buildSetModel()->addProjectItem( item );
     }
@@ -425,7 +429,7 @@ void ProjectManagerViewPlugin::addItemsFromContextMenuToBuildset( )
 
 void ProjectManagerViewPlugin::runTargetsFromContextMenu( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ))
     {
         KDevelop::ProjectExecutableTargetItem* t=item->executable();
         if(t)
@@ -439,14 +443,15 @@ void ProjectManagerViewPlugin::projectConfiguration( )
 {
     if( !d->ctxProjectItemList.isEmpty() )
     {
-        core()->projectController()->configureProject( d->ctxProjectItemList.at( 0 )->project() );
+        ProjectModel* model = ICore::self()->projectController()->projectModel();
+        core()->projectController()->configureProject( model->itemFromIndex(d->ctxProjectItemList.at( 0 ))->project() );
     }
 }
 
 void ProjectManagerViewPlugin::reloadFromContextMenu( )
 {
     QList< KDevelop::ProjectFolderItem* > folders;
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ) )
     {
         if ( item->folder() ) {
             // since reloading should be recursive, only pass the upper-most items
@@ -474,7 +479,7 @@ void ProjectManagerViewPlugin::reloadFromContextMenu( )
 
 void ProjectManagerViewPlugin::createFolderFromContextMenu( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ))
     {
         if ( item->folder() ) {
             QWidget* window(ICore::self()->uiController()->activeMainWindow()->window());
@@ -491,7 +496,7 @@ void ProjectManagerViewPlugin::createFolderFromContextMenu( )
 
 void ProjectManagerViewPlugin::removeFromContextMenu()
 {
-    removeItems(d->ctxProjectItemList);
+    removeItems(itemsFromIndexes( d->ctxProjectItemList ));
 }
 
 void ProjectManagerViewPlugin::removeItems(const QList< ProjectBaseItem* >& items)
@@ -553,7 +558,7 @@ void ProjectManagerViewPlugin::removeItems(const QList< ProjectBaseItem* >& item
 
 void ProjectManagerViewPlugin::removeTargetFilesFromContextMenu()
 {
-    QList<ProjectBaseItem*> items = d->ctxProjectItemList;
+    QList<ProjectBaseItem*> items = itemsFromIndexes( d->ctxProjectItemList );
     QMap< IBuildSystemManager*, QList<KDevelop::ProjectFileItem*> > itemsByBuildSystem;
     foreach(ProjectBaseItem *item, items)
         itemsByBuildSystem[item->project()->buildSystemManager()].append(item->file());
@@ -565,7 +570,7 @@ void ProjectManagerViewPlugin::removeTargetFilesFromContextMenu()
 
 void ProjectManagerViewPlugin::renameItemFromContextMenu()
 {
-    renameItems(d->ctxProjectItemList);
+    renameItems(itemsFromIndexes( d->ctxProjectItemList ));
 }
 
 void ProjectManagerViewPlugin::renameItems(const QList< ProjectBaseItem* >& items)
@@ -632,7 +637,7 @@ ProjectFileItem* createFile(const ProjectFolderItem* item)
 
 void ProjectManagerViewPlugin::createFileFromContextMenu( )
 {
-    foreach( KDevelop::ProjectBaseItem* item, d->ctxProjectItemList )
+    foreach( KDevelop::ProjectBaseItem* item, itemsFromIndexes( d->ctxProjectItemList ) )
     {
         if ( item->folder() ) {
             createFile(item->folder());
