@@ -19,8 +19,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-#ifndef QUICKOPENPLUGIN_H
-#define QUICKOPENPLUGIN_H
+#ifndef KDEVPLATFORM_PLUGIN_QUICKOPENPLUGIN_H
+#define KDEVPLATFORM_PLUGIN_QUICKOPENPLUGIN_H
 
 #include <QtCore/QVariant>
 #include <QtCore/QTimer>
@@ -97,6 +97,7 @@ public slots:
     void quickOpenDefinition();
     void quickOpenNavigate();
     void quickOpenNavigateFunctions();
+    void quickOpenDocumentation();
 
     void previousFunction();
     void nextFunction();
@@ -122,6 +123,7 @@ private:
     class ProjectFileDataProvider* m_projectFileData;
     class ProjectItemDataProvider* m_projectItemData;
     class OpenFilesDataProvider* m_openFilesData;
+    class DocumentationQuickOpenProvider* m_documentationItemData;
     QStringList lastUsedScopes;
     QStringList lastUsedItems;
   
@@ -160,14 +162,14 @@ class QuickOpenWidget : public QMenu {
   private slots:
   void currentChanged( const QModelIndex& current, const QModelIndex& previous );
   void currentChanged( const QItemSelection& current, const QItemSelection& previous );
+  
+  void updateTimerInterval( bool cheapFilterChange );
 
   void accept();
   void textChanged( const QString& str );
   void updateProviders();
   void doubleClicked ( const QModelIndex & index );
 
-  void updateScrollBarState();
-
   void applyFilter();
 
   private:
@@ -216,7 +218,7 @@ class QuickOpenLineEdit : public KDevelop::IQuickOpenLine {
     bool insideThis(QObject* object);
     void showWithWidget(QuickOpenWidget* widget);
     
-    virtual void setDefaultText(QString text) {
+    virtual void setDefaultText(const QString& text) {
       m_defaultText = text;
       setClickMessage(m_defaultText);
     }
@@ -236,6 +238,6 @@ class QuickOpenLineEdit : public KDevelop::IQuickOpenLine {
     QuickOpenWidgetCreator* m_widgetCreator;
 };
 
-#endif // QUICKOPENPLUGIN_H
+#endif // KDEVPLATFORM_PLUGIN_QUICKOPENPLUGIN_H
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
