@@ -23,6 +23,7 @@
 
 #include "standardoutputview.h"
 #include <QtCore/QTimer>
+#include <QtCore/QRegExp>
 #include <QtGui/QAbstractItemDelegate>
 #include <QtGui/QItemSelectionModel>
 #include <QtGui/QTreeView>
@@ -32,6 +33,8 @@
 #include <QtGui/QStackedWidget>
 #include <QtGui/QApplication>
 #include <QtGui/QClipboard>
+#include <QtGui/QWidgetAction>
+#include <QtGui/QSortFilterProxyModel>
 #include <kmenu.h>
 #include <kaction.h>
 #include <kdebug.h>
@@ -40,14 +43,26 @@
 #include <kicon.h>
 #include <ktabwidget.h>
 #include <kstandardaction.h>
+#include <klineedit.h>
 
 #include <outputview/ioutputviewmodel.h>
 #include <util/focusedtreeview.h>
 
 #include "toolviewdata.h"
 
-OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
-    : QWidget( parent ), tabwidget(0), data(tvdata)
+OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
+    : QWidget( parent )
+    , tabwidget(0)
+    , stackwidget(0)
+    , data(tvdata)
+    , m_closeButton(0)
+    , m_closeAllButton(0)
+    , nextAction(0)
+    , previousAction(0)
+    , activateOnSelect(0)
+    , focusOnSelect(0)
+    , filterInput(0)
+    , filterAction(0)
 {
     setWindowTitle(i18n("Output View"));
     setWindowIcon(tvdata->icon);
@@ -58,12 +73,25 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
         tabwidget = new KTabWidget(this);
         layout->addWidget( tabwidget );
         m_closeButton = new QToolButton( this );
-        connect( m_closeButton, SIGNAL( clicked() ),
-                 this, SLOT( closeActiveView() ) );
+        connect( m_closeButton, SIGNAL(clicked()),
+                 this, SLOT(closeActiveView()) );
         m_closeButton->setIcon( KIcon("tab-close") );
         m_closeButton->adjustSize();
         m_closeButton->setToolTip( i18n( "Close the currently active output view") );
-        tabwidget->setCornerWidget( m_closeButton, Qt::TopRightCorner );
+        m_closeAllButton = new QToolButton( this );
+        connect(m_closeAllButton, SIGNAL(clicked()),
+                this, SLOT(closeOtherViews()));
+        m_closeAllButton->setIcon(KIcon("tab-close-other"));
+        m_closeAllButton->adjustSize();
+        m_closeAllButton->setToolTip( i18n( "Close all other output views" ) );
+
+        QWidget* toolbar = new QWidget(this);
+        QBoxLayout* toolbarLayout =  new QBoxLayout(QBoxLayout::LeftToRight);
+        toolbarLayout->setMargin(0);
+        toolbar->setLayout(toolbarLayout);
+        toolbarLayout->addWidget(m_closeButton);
+        toolbarLayout->addWidget(m_closeAllButton);
+        tabwidget->setCornerWidget(toolbar, Qt::TopRightCorner);
     } else if ( data->type == KDevelop::IOutputView::HistoryView )
     {
         stackwidget = new QStackedWidget( this );
@@ -78,16 +106,18 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
     }
 
     activateOnSelect = new KToggleAction( KIcon(), i18n("Select activated Item"), this );
-    addAction(activateOnSelect);
     activateOnSelect->setChecked( true );
     focusOnSelect = new KToggleAction( KIcon(), i18n("Focus when selecting Item"), this );
-    addAction(focusOnSelect);
     focusOnSelect->setChecked( false );
+    if( data->option & KDevelop::IOutputView::ShowItemsButton )
+    {
+        addAction(activateOnSelect);
+        addAction(focusOnSelect);
+    }
 
     QAction *separator = new QAction(this);
     separator->setSeparator(true);
-    addAction(separator);
-    
+
     KAction *selectAllAction = KStandardAction::selectAll(this, SLOT(selectAll()), this);
     selectAllAction->setShortcut(KShortcut()); //FIXME: why does CTRL-A conflict with Katepart (while CTRL-Cbelow doesn't) ?
     selectAllAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
@@ -97,11 +127,39 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
     copyAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
     addAction(copyAction);
 
-    connect( data, SIGNAL( outputAdded( int ) ),
-             this, SLOT( addOutput( int ) ) );
+    if( data->option & KDevelop::IOutputView::AddFilterAction )
+    {
+        addAction(separator);
+        filterInput = new KLineEdit();
+        filterInput->setMaximumWidth(150);
+        filterInput->setMinimumWidth(100);
+        filterInput->setClickMessage(i18n("Search..."));
+        filterInput->setClearButtonShown(true);
+        filterInput->setToolTip(i18n("Enter a wild card string to filter the output view"));
+        filterAction = new QWidgetAction(this);
+        filterAction->setDefaultWidget(filterInput);
+        addAction(filterAction);
 
-    connect( this, SIGNAL( outputRemoved( int, int ) ),
-             data->plugin, SIGNAL( outputRemoved( int, int ) ) );
+        connect(filterInput, SIGNAL(textEdited(QString)),
+                this, SLOT(outputFilter(QString)) );
+        if( data->type & KDevelop::IOutputView::MultipleView )
+        {
+            connect(tabwidget, SIGNAL(currentChanged(int)),
+                    this, SLOT(updateFilter(int)));
+        } else if ( data->type == KDevelop::IOutputView::HistoryView )
+        {
+            connect(stackwidget, SIGNAL(currentChanged(int)),
+                    this, SLOT(updateFilter(int)));
+        }
+    }
+
+    addActions(data->actionList);
+
+    connect( data, SIGNAL(outputAdded(int)),
+             this, SLOT(addOutput(int)) );
+
+    connect( this, SIGNAL(outputRemoved(int,int)),
+             data->plugin, SIGNAL(outputRemoved(int,int)) );
 
     connect( data->plugin, SIGNAL(selectNextItem()), this, SLOT(selectNextItem()) );
     connect( data->plugin, SIGNAL(selectPrevItem()), this, SLOT(selectPrevItem()) );
@@ -117,7 +175,6 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
 void OutputWidget::addOutput( int id )
 {
     QTreeView* listview = createListView(id);
-    listview->setSelectionMode(QAbstractItemView::ContiguousSelection);
     setCurrentWidget( listview );
     connect( data->outputdata.value(id), SIGNAL(modelChanged(int)), this, SLOT(changeModel(int)));
     connect( data->outputdata.value(id), SIGNAL(delegateChanged(int)), this, SLOT(changeDelegate(int)));
@@ -138,10 +195,11 @@ void OutputWidget::setCurrentWidget( QTreeView* view )
 
 void OutputWidget::changeDelegate( int id )
 {
-    if( data->outputdata.contains( id ) && views.contains( id ) )
+    if( data->outputdata.contains( id ) && views.contains( id ) ) {
         views.value(id)->setItemDelegate(data->outputdata.value(id)->delegate);
-    else
+    } else {
         addOutput(id);
+    }
 }
 
 void OutputWidget::changeModel( int id )
@@ -154,12 +212,12 @@ void OutputWidget::changeModel( int id )
         if (!od->model)
             return;
 
-        disconnect( od->model,SIGNAL(rowsInserted(const QModelIndex&, int, int)), this,
-                    SLOT(rowsInserted(const QModelIndex&, int, int)) );
+        disconnect( od->model,SIGNAL(rowsInserted(QModelIndex,int,int)), this,
+                    SLOT(rowsInserted(QModelIndex,int,int)) );
         if( od->behaviour & KDevelop::IOutputView::AutoScroll )
         {
-            connect( od->model,SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-                     SLOT(rowsInserted(const QModelIndex&, int, int)) );
+            connect( od->model,SIGNAL(rowsInserted(QModelIndex,int,int)),
+                     SLOT(rowsInserted(QModelIndex,int,int)) );
         }
     }
     else
@@ -181,9 +239,20 @@ void OutputWidget::removeOutput( int id )
                 if( idx != -1 )
                 {
                     tabwidget->removeTab( idx );
+                    if( proxyModels.contains( idx ) )
+                    {
+                        delete proxyModels.take( idx );
+                        filters.remove( idx );
+                    }
                 }
             } else
             {
+                int idx = stackwidget->indexOf( w );
+                if( idx != -1 && proxyModels.contains( idx ) )
+                {
+                    delete proxyModels.take( idx );
+                    filters.remove( idx );
+                }
                 stackwidget->removeWidget( w );
             }
             delete w;
@@ -192,10 +261,15 @@ void OutputWidget::removeOutput( int id )
         {
             views.value( id )->setModel( 0 );
             views.value( id )->setItemDelegate( 0 );
+            if( proxyModels.contains( 0 ) ) {
+                delete proxyModels.take( 0 );
+                filters.remove( 0 );
+            }
         }
-        disconnect( data->outputdata.value( id )->model,SIGNAL(rowsInserted(const QModelIndex&, int, int)),
-                    this, SLOT(rowsInserted(const QModelIndex&, int, int)) );
+        disconnect( data->outputdata.value( id )->model,SIGNAL(rowsInserted(QModelIndex,int,int)),
+                    this, SLOT(rowsInserted(QModelIndex,int,int)) );
         
+        views.remove( id );
         emit outputRemoved( data->toolViewId, id );
     }
     enableActions();
@@ -213,13 +287,32 @@ void OutputWidget::closeActiveView()
             OutputData* od = data->outputdata.value(id);
             if( od->behaviour & KDevelop::IOutputView::AllowUserClose )
             {
-                removeOutput( id );
+                data->plugin->removeOutput( id );
             }
         }
     }
     enableActions();
 }
 
+void OutputWidget::closeOtherViews()
+{
+    QWidget* widget = tabwidget->currentWidget();
+    if (!widget)
+        return;
+
+    foreach (int id, views.keys()) {
+        if (views.value(id) == widget) {
+            continue; // leave the active view open
+        }
+
+        OutputData* od = data->outputdata.value(id);
+        if (od->behaviour & KDevelop::IOutputView::AllowUserClose) {
+            data->plugin->removeOutput( id );
+        }
+    }
+    enableActions();
+}
+
 QWidget* OutputWidget::currentWidget()
 {
     QWidget* widget;
@@ -319,6 +412,19 @@ void OutputWidget::activate(const QModelIndex& index)
     }
 }
 
+static QTreeView* createFocusedTreeView( QWidget* parent )
+{
+    QTreeView* listview = new KDevelop::FocusedTreeView(parent);
+    listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
+    listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
+    listview->setHeaderHidden(true);
+    listview->setUniformRowHeights(true);
+    listview->setRootIsDecorated(false);
+    listview->setSelectionMode( QAbstractItemView::ContiguousSelection );
+
+    return listview;
+}
+
 QTreeView* OutputWidget::createListView(int id)
 {
     QTreeView* listview = 0;
@@ -327,17 +433,13 @@ QTreeView* OutputWidget::createListView(int id)
         if( data->type & KDevelop::IOutputView::MultipleView || data->type & KDevelop::IOutputView::HistoryView )
         {
             kDebug() << "creating listview";
-            listview = new KDevelop::FocusedTreeView(this);
-            listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
-            listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
-            listview->setHeaderHidden(true);
-            listview->setRootIsDecorated(false);
-            
+            listview = createFocusedTreeView(this);
+
             views[id] = listview;
-            connect( listview, SIGNAL(activated(const QModelIndex&)),
-                     this, SLOT(activate(const QModelIndex&)));
-            connect( listview, SIGNAL(clicked(const QModelIndex&)),
-                     this, SLOT(activate(const QModelIndex&)));
+            connect( listview, SIGNAL(activated(QModelIndex)),
+                     this, SLOT(activate(QModelIndex)));
+            connect( listview, SIGNAL(clicked(QModelIndex)),
+                     this, SLOT(activate(QModelIndex)));
 
             if( data->type & KDevelop::IOutputView::MultipleView )
             {
@@ -351,17 +453,13 @@ QTreeView* OutputWidget::createListView(int id)
         {
             if( views.isEmpty() )
             {
-                listview = new KDevelop::FocusedTreeView(this);
-                listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
-                listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
-                listview->setRootIsDecorated(false);
-                listview->setHeaderHidden(true);
+                listview = createFocusedTreeView(this);
 
                 layout()->addWidget( listview );
-                connect( listview, SIGNAL(activated(const QModelIndex&)),
-                         this, SLOT(activate(const QModelIndex&)));
-                connect( listview, SIGNAL(clicked(const QModelIndex&)),
-                         this, SLOT(activate(const QModelIndex&)));
+                connect( listview, SIGNAL(activated(QModelIndex)),
+                         this, SLOT(activate(QModelIndex)));
+                connect( listview, SIGNAL(clicked(QModelIndex)),
+                         this, SLOT(activate(QModelIndex)));
             } else
             {
                 listview = views.begin().value();
@@ -464,8 +562,8 @@ void OutputWidget::copySelection()
     QClipboard *cb = QApplication::clipboard();
     QModelIndexList indexes = view->selectionModel()->selectedRows();
     QString content;
-    Q_FOREACH( QModelIndex index, indexes) {
-      content += view->model()->data(index).toString() + "\n";
+    Q_FOREACH( const QModelIndex& index, indexes) {
+      content += view->model()->data(index).toString() + '\n';
     }
     cb->setText(content);
 }
@@ -482,6 +580,44 @@ void OutputWidget::selectAll()
     view->selectAll();
 }
 
+void OutputWidget::outputFilter(const QString filter)
+{
+    QWidget* widget = currentWidget();
+    if( !widget )
+        return;
+    QAbstractItemView *view = dynamic_cast<QAbstractItemView*>(widget);
+    if( !view )
+        return;
+    int index = 0;
+    if( data->type & KDevelop::IOutputView::MultipleView )
+    {
+        index = tabwidget->currentIndex();
+    } else if( data->type & KDevelop::IOutputView::HistoryView )
+    {
+        index = stackwidget->currentIndex();
+    }
+    if( !dynamic_cast<QSortFilterProxyModel*>(view->model()) )
+    {
+        QSortFilterProxyModel* _proxyModel = new QSortFilterProxyModel(view->model());
+        _proxyModel->setDynamicSortFilter(true);
+        _proxyModel->setSourceModel(view->model());
+        proxyModels.insert(index, _proxyModel);
+        view->setModel(_proxyModel);
+    }
+    QRegExp regExp(filter,Qt::CaseInsensitive);
+    proxyModels[index]->setFilterRegExp(regExp);
+    filters[index] = filter;
+}
 
+void OutputWidget::updateFilter(int index)
+{
+    if(filters.contains(index))
+    {
+        filterInput->setText(filters[index]);
+    } else
+    {
+        filterInput->clear();
+    }
+}
 
 #include "outputwidget.moc"
