@@ -18,8 +18,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef ABSTRACTGENERICMANAGER_H
-#define ABSTRACTGENERICMANAGER_H
+#ifndef KDEVPLATFORM_ABSTRACTGENERICMANAGER_H
+#define KDEVPLATFORM_ABSTRACTGENERICMANAGER_H
 
 #include "projectexport.h"
 
@@ -73,7 +73,8 @@ protected:
     /**
      * Filter interface making it possible to hide files and folders from a project.
      *
-     * The default implementation will show all files.
+     * The default implementation will query all IProjectFilter plugins and ask them
+     * whether a given url should be included or not.
      *
      * @return True when @p url should belong to @p project, false otherwise.
      */
@@ -100,18 +101,6 @@ protected:
      */
     KDirWatch* projectWatcher( KDevelop::IProject* project ) const;
 
-    /**
-     * Sets a list of filenames to ignore when importing a project
-     * the filter is applied to files and folders, so both will be ignored.
-     *
-     * The filenames are matched via QString::operator==(), so no wildcard or
-     * regex-matching for now
-     * 
-     * This can be used for things like VCS-folders/files or other things a
-     * plugin might want to hide.
-     */
-    void setImportFileNameFilter( const QStringList& filterNames );
-
 Q_SIGNALS:
     void folderAdded(KDevelop::ProjectFolderItem* folder);
     void folderRemoved(KDevelop::ProjectFolderItem* folder);
@@ -142,4 +131,4 @@ private:
 
 }
 
-#endif // ABSTRACTGENERICMANAGER_H
+#endif // KDEVPLATFORM_ABSTRACTGENERICMANAGER_H
