@@ -19,8 +19,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef IBUILDSYSTEMMANAGER_H
-#define IBUILDSYSTEMMANAGER_H
+#ifndef KDEVPLATFORM_IBUILDSYSTEMMANAGER_H
+#define KDEVPLATFORM_IBUILDSYSTEMMANAGER_H
 
 #include <KUrl>
 
