@@ -19,8 +19,8 @@
     the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
     Boston, MA 02110-1301, USA.
 */
-#ifndef IPROJECTFILEMANAGER_H
-#define IPROJECTFILEMANAGER_H
+#ifndef KDEVPLATFORM_IPROJECTFILEMANAGER_H
+#define KDEVPLATFORM_IPROJECTFILEMANAGER_H
 
 #include <QtCore/QStringList>
 
