@@ -19,8 +19,8 @@
     Boston, MA 02110-1301, USA.
 */
 
-#ifndef KDEVPROJECTMODEL_H
-#define KDEVPROJECTMODEL_H
+#ifndef KDEVPLATFORM_PROJECTMODEL_H
+#define KDEVPLATFORM_PROJECTMODEL_H
 
 #include <QtCore/QAbstractItemModel>
 #include "projectexport.h"
@@ -212,7 +212,7 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectBaseItem
 
         /**
          * Renames the item to the new name.
-         * @returns status information wether the renaming succeeded.
+         * @returns status information whether the renaming succeeded.
          */
         virtual RenameStatus rename( const QString& newname );
         
@@ -378,6 +378,12 @@ class KDEVPLATFORMPROJECT_EXPORT ProjectModel: public QAbstractItemModel
 {
     Q_OBJECT
 public:
+    enum Roles {
+          ProjectRole = Qt::UserRole+1
+        , ProjectItemRole
+        , LastRole
+    };
+
     ProjectModel( QObject *parent = 0 );
     virtual ~ProjectModel();
 
@@ -437,5 +443,6 @@ Q_DECLARE_METATYPE(KDevelop::ProjectLibraryTargetItem*)
 Q_DECLARE_METATYPE(KDevelop::ProjectExecutableTargetItem*)
 Q_DECLARE_METATYPE(KDevelop::ProjectTargetItem*)
 Q_DECLARE_METATYPE(KDevelop::ProjectBuildFolderItem*)
+Q_DECLARE_METATYPE(QList<KDevelop::ProjectBaseItem*>)
 
-#endif // KDEVPROJECTMODEL_H
+#endif // KDEVPLATFORM_PROJECTMODEL_H
