@@ -28,7 +28,6 @@
 #include <projectproxymodel.h>
 #include <tests/modeltest.h>
 #include <tests/testproject.h>
-#include <projectproxymodel.h>
 #include <tests/kdevsignalspy.h>
 #include <tests/autotestshell.h>
 #include <tests/testcore.h>
@@ -44,52 +43,6 @@ using KDevelop::ProjectBuildFolderItem;
 
 using KDevelop::TestProject;
 
-class AddItemThread : public QThread
-{
-Q_OBJECT
-public:
-    AddItemThread( ProjectBaseItem* _parentItem, QObject* parent = 0 )
-        : QThread( parent ), parentItem( _parentItem )
-    {
-    }
-    virtual void run()
-    {
-        this->sleep( 1 );
-        KUrl url = parentItem->url();
-        url.addPath("folder1");
-        ProjectFolderItem* folder = new ProjectFolderItem( 0, url, parentItem );
-        url.addPath( "file1" );
-        new ProjectFileItem( 0, url, folder );
-        emit addedItems();
-    }
-signals:
-    void addedItems();
-private:
-    ProjectBaseItem* parentItem;
-};
-
-class SignalReceiver : public QObject
-{
-Q_OBJECT
-public:
-    SignalReceiver(ProjectModel* _model, QObject* parent = 0)
-        : QObject(parent), model( _model )
-    {
-    }
-    QThread* threadOfSignalEmission() const
-    {
-        return threadOfReceivedSignal;
-    }
-private slots:
-    void rowsInserted( const QModelIndex&, int, int )
-    {
-        threadOfReceivedSignal = QThread::currentThread();
-    }
-private:
-    QThread* threadOfReceivedSignal;
-    ProjectModel* model;
-};
-
 void debugItemModel(QAbstractItemModel* m, const QModelIndex& parent=QModelIndex(), int depth=0)
 {
     Q_ASSERT(m);
@@ -510,19 +463,6 @@ void ProjectModelTest::testWithProject()
     QCOMPARE( item->url(), proj->folder() );
 }
 
-void ProjectModelTest::testAddItemInThread()
-{
-    ProjectFolderItem* root = new ProjectFolderItem( 0, KUrl("file:///f1"), 0 );
-    model->appendRow( root );
-    AddItemThread t( root );
-    SignalReceiver check( model );
-    connect( model, SIGNAL(rowsInserted(QModelIndex,int,int)), &check, SLOT(rowsInserted(QModelIndex,int,int)), Qt::DirectConnection );
-    KDevelop::KDevSignalSpy spy( &t, SIGNAL(addedItems()), Qt::QueuedConnection );
-    t.start();
-    QVERIFY(spy.wait( 10000 ));
-    QCOMPARE( qApp->thread(), check.threadOfSignalEmission() );
-}
-
 void ProjectModelTest::testItemsForUrl()
 {
     QFETCH(KUrl, url);
@@ -566,23 +506,20 @@ void ProjectModelTest::testItemsForUrl_data()
 void ProjectModelTest::testProjectProxyModel()
 {
     ProjectFolderItem* root = new ProjectFolderItem(0, KUrl("file:///tmp/"));
-    new ProjectFileItem(0, KUrl("file:///tmp/a1/"), root);
     new ProjectFileItem(0, KUrl("file:///tmp/b1/"), root);
-    new ProjectFileItem(0, KUrl("file:///tmp/c1/"), root);
+    new ProjectFileItem(0, KUrl("file:///tmp/a1/"), root);
     new ProjectFileItem(0, KUrl("file:///tmp/d1/"), root);
+    new ProjectFileItem(0, KUrl("file:///tmp/c1/"), root);
     model->appendRow(root);
-    
+
     QModelIndex proxyRoot = proxy->mapFromSource(root->index());
     QCOMPARE(model->rowCount(root->index()), 4);
     QCOMPARE(proxy->rowCount(proxyRoot), 4);
-    
-    proxy->setFilterString("*1");
-    QCOMPARE(proxy->rowCount(proxyRoot), 4);
-    
-    proxy->setFilterString("a*");
-    debugItemModel(proxy);
-    QCOMPARE(proxy->rowCount(proxyRoot), 1);
-    
+    QCOMPARE(proxy->index(0, 0, proxy->index(0, 0)).data().toString(), QString("a1"));
+    QCOMPARE(proxy->index(1, 0, proxy->index(0, 0)).data().toString(), QString("b1"));
+    QCOMPARE(proxy->index(2, 0, proxy->index(0, 0)).data().toString(), QString("c1"));
+    QCOMPARE(proxy->index(3, 0, proxy->index(0, 0)).data().toString(), QString("d1"));
+
     model->clear();
 }
 
@@ -611,5 +548,3 @@ void ProjectModelTest::testProjectFileIcon()
 }
 
 QTEST_KDEMAIN( ProjectModelTest, GUI)
-#include "projectmodeltest.moc"
-#include "moc_projectmodeltest.cpp"
