@@ -27,7 +27,6 @@ Boston, MA 02110-1301, USA.
 #include <QtGui/QDragEnterEvent>
 #include <QtGui/QDropEvent>
 #include <QtGui/QMenuBar>
-#include <QtCore/QMimeData>
 #include <QtDBus/QDBusConnection>
 
 #include <KDE/KApplication>
@@ -44,6 +43,7 @@ Boston, MA 02110-1301, USA.
 #include <kxmlguifactory.h>
 #include <ktoggleaction.h>
 #include <KWindowSystem>
+#include <KMenuBar>
 
 #include <sublime/area.h>
 #include "shellextension.h"
@@ -55,6 +55,7 @@ Boston, MA 02110-1301, USA.
 #include "workingsetcontroller.h"
 #include "sessioncontroller.h"
 #include "sourceformattercontroller.h"
+#include "areadisplay.h"
 
 #include <interfaces/isession.h>
 #include <interfaces/iprojectcontroller.h>
@@ -71,18 +72,12 @@ void MainWindow::applyMainWindowSettings(const KConfigGroup& config, bool force)
         KXmlGuiWindow::applyMainWindowSettings(config, force);
 }
 
-QWidget* MainWindow::customButtonForAreaSwitcher ( Sublime::Area* area )
-{
-    return Core::self()->workingSetControllerInternal()->createSetManagerWidget(this, area);
-}
-
 MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
         : Sublime::MainWindow( parent, flags )
 {
     QDBusConnection::sessionBus().registerObject( "/kdevelop/MainWindow",
         this, QDBusConnection::ExportScriptableSlots );
 
-    setAreaSwitcherCornerWidget(Core::self()->workingSetControllerInternal()->createSetManagerWidget(this));
     setAcceptDrops( true );
     KConfigGroup cg = KGlobal::config()->group( "UiSettings" );
     int bottomleft = cg.readEntry( "BottomLeftCornerOwner", 0 );
@@ -112,8 +107,7 @@ MainWindow::MainWindow( Sublime::Controller *parent, Qt::WFlags flags )
         setXMLFile( ShellExtension::getInstance() ->xmlFile() );
     }
 
-//    connect(this->guiFactory(), SIGNAL(clientAdded(KXMLGUIClient*)),
-//            d, SLOT(fixToolbar()));
+    menuBar()->setCornerWidget(new AreaDisplay(this), Qt::TopRightCorner);
 }
 
 MainWindow::~ MainWindow()
@@ -122,8 +116,7 @@ MainWindow::~ MainWindow()
 
     if (memberList().count() == 1) {
         // We're closing down...
-        Core::self()->cleanup();
-        Core::self()->deleteLater();
+        Core::self()->shutdown();
     }
 
     delete d;
@@ -206,8 +199,6 @@ void MainWindow::loadSettings()
     else if( bottomright == 1 )
         setCorner( Qt::BottomRightCorner, Qt::BottomDockWidgetArea );
 
-    setupAreaSelector();
-
     Sublime::MainWindow::loadSettings();
 }
 
