@@ -20,8 +20,8 @@ along with this library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 */
-#ifndef KDEV_MAINWINDOW_H
-#define KDEV_MAINWINDOW_H
+#ifndef KDEVPLATFORM_MAINWINDOW_H
+#define KDEVPLATFORM_MAINWINDOW_H
 
 #include <KDE/KXmlGuiWindow>
 
@@ -52,8 +52,6 @@ public:
 
     /*! @p status must implement KDevelop::IStatus */
     void registerStatus(QObject* status);
-    
-    virtual QWidget* customButtonForAreaSwitcher( Sublime::Area* area );
 
 public Q_SLOTS:
     /*! Shows an error message in the status bar.
@@ -66,9 +64,10 @@ public Q_SLOTS:
         return Sublime::MainWindow::windowTitle();
     }
 
-public Q_SLOTS:
     virtual void setVisible( bool visible );
     void configureShortcuts();
+    virtual void loadSettings();
+    virtual void saveSettings();
 
 Q_SIGNALS:
     void finishedLoading();
@@ -79,10 +78,6 @@ protected:
     //reimplemented from KXMLGUIBuilder to support visible menubar separators
     QAction *createCustomElement(QWidget *parent, int index, const QDomElement &element);
 
-public Q_SLOTS:
-    virtual void loadSettings();
-    virtual void saveSettings();
-protected:
     virtual void initialize();
     virtual void cleanup();
     virtual void initializeStatusBar();
