@@ -49,6 +49,7 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/isession.h>
 #include <interfaces/idebugcontroller.h>
 #include <interfaces/idocumentationcontroller.h>
+#include <interfaces/ipluginversion.h>
 
 //#include <kross/krossplugin.h>
 
@@ -175,13 +176,7 @@ PluginController::~PluginController()
 
 KPluginInfo PluginController::pluginInfo( const IPlugin* plugin ) const
 {
-    for ( PluginControllerPrivate::InfoToPluginMap::ConstIterator it = d->loadedPlugins.constBegin();
-          it != d->loadedPlugins.constEnd(); ++it )
-    {
-        if ( it.value() == plugin )
-            return it.key();
-    }
-    return KPluginInfo();
+    return d->loadedPlugins.key(const_cast<IPlugin*>(plugin));
 }
 
 void PluginController::cleanup()
@@ -306,6 +301,7 @@ bool PluginController::unloadPlugin(IPlugin* plugin, PluginDeletion deletion)
 {
     kDebug() << "unloading plugin:" << plugin << pluginInfo( plugin ).name();
 
+    emit unloadingPlugin(plugin);
     plugin->unload();
     emit pluginUnloaded(plugin);
 
@@ -440,7 +436,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
     if ( plugin )
     {
         if ( plugin->hasError() ) {
-            KMessageBox::error(0, i18n("Plugin '%1' could not be loaded correctly and was disabled.\nReason: %2.", info.name(), plugin->errorDescription()));
+            kWarning() << i18n("Plugin '%1' could not be loaded correctly and was disabled.\nReason: %2.", info.name(), plugin->errorDescription());
             info.setPluginEnabled(false);
             info.save(Core::self()->activeSession()->config()->group(pluginControllerGrp));
             unloadPlugin(pluginId);
@@ -463,7 +459,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
         else
         {
             kWarning() << "Loading plugin '" << pluginId
-                << "' failed, KPluginLoader reported error: '" << endl <<
+                << "' failed, KServiceTypeTrader reported error: '" << endl <<
                 str_error << "'";
         }
     }
