@@ -53,6 +53,7 @@ Boston, MA 02110-1301, USA.
 #include <interfaces/isession.h>
 #include <QSignalMapper>
 #include <interfaces/contextmenuextension.h>
+#include <sublime/area.h>
 #include <kmenu.h>
 
 using namespace KDevelop;
@@ -74,7 +75,7 @@ class DebugMode : public ILaunchMode
 {
 public:
     DebugMode() {}
-    virtual KIcon icon() const { return KIcon(); }
+    virtual KIcon icon() const { return KIcon("tools-report-bug"); }
     virtual QString id() const { return "debug"; }
     virtual QString name() const { return i18n("Debug"); }
 };
@@ -83,7 +84,7 @@ class ProfileMode : public ILaunchMode
 {
 public:
     ProfileMode() {}
-    virtual KIcon icon() const { return KIcon(); }
+    virtual KIcon icon() const { return KIcon("office-chart-area"); }
     virtual QString id() const { return "profile"; }
     virtual QString name() const { return i18n("Profile"); }
 };
@@ -107,8 +108,8 @@ public:
     RunController* q;
 
     QHash<KJob*, KAction*> jobs;
-    KActionMenu* stopAction;
-    KAction* profileAction;
+    KAction* stopAction;
+    KActionMenu* stopJobsMenu;
     KAction* runAction;
     KAction* dbgAction;
     KSelectAction* currentTargetAction;
@@ -119,6 +120,9 @@ public:
     QSignalMapper* launchAsMapper;
     QMap<int,QPair<QString,QString> > launchAsInfo;
     KDevelop::ProjectBaseItem* contextItem;
+    DebugMode* debugMode;
+    ExecuteMode* executeMode;
+    ProfileMode* profileMode;
     bool hasLaunchConfigType( const QString& typeId )
     {
         return launchConfigurationTypes.contains( typeId );
@@ -136,12 +140,7 @@ public:
             grp.sync();
         }
     }
-    void enableLaunchActions()
-    {
-        runAction->setEnabled( !launchConfigurations.isEmpty() );
-        profileAction->setEnabled( !launchConfigurations.isEmpty() );
-        dbgAction->setEnabled( !launchConfigurations.isEmpty() );
-    }
+    
     void configureLaunches()
     {
         LaunchConfigurationDialog dlg;
@@ -175,7 +174,7 @@ public:
             ILauncher* launcher = 0;
             foreach (ILauncher *l, type->launchers())
             {
-                //kDebug() << "avaliable launcher" << l << l->id() << l->supportedModes();
+                //kDebug() << "available launcher" << l << l->id() << l->supportedModes();
                 if (l->supportedModes().contains(mode->id())) {
                     launcher = l;
                     break;
@@ -187,8 +186,8 @@ public:
                 ILaunchConfiguration* ilaunch = 0;
                 foreach (LaunchConfiguration *l, launchConfigurations) {
                     QStringList path = l->config().readEntry(ConfiguredFromProjectItemEntry, QStringList());
-                    if (path == itemPath) {
-                        //kDebug() << "allready generated ilaunch" << ilaunch;
+                    if (l->type() == type && path == itemPath) {
+                        kDebug() << "already generated ilaunch" << path;
                         ilaunch = l;
                         break;
                     }
@@ -304,6 +303,9 @@ RunController::RunController(QObject *parent)
     d->launchChangeMapper = new QSignalMapper( this );
     d->launchAsMapper = 0;
     d->contextItem = 0;
+    d->executeMode = 0;
+    d->debugMode = 0;
+    d->profileMode = 0;
 
     if(!(Core::self()->setupFlags() & Core::NoUi)) {
         // Note that things like registerJob() do not work without the actions, it'll simply crash.
@@ -330,23 +332,33 @@ void KDevelop::RunController::launchChanged( LaunchConfiguration* l )
 
 void RunController::cleanup()
 {
+    delete d->executeMode;
+    d->executeMode = 0;
+    delete d->profileMode;
+    d->profileMode = 0;
+    delete d->debugMode;
+    d->debugMode = 0;
+
     stopAllProcesses();
     d->saveCurrentLaunchAction();
 }
 
 void RunController::initialize()
 {
-    addLaunchMode( new ExecuteMode() );
-    addLaunchMode( new ProfileMode() );
-    addLaunchMode( new DebugMode() );
+    d->executeMode = new ExecuteMode();
+    addLaunchMode( d->executeMode );
+    d->profileMode = new ProfileMode();
+    addLaunchMode( d->profileMode );
+    d->debugMode = new DebugMode;
+    addLaunchMode( d->debugMode );
     d->readLaunchConfigs( Core::self()->activeSession()->config(), 0 );
 
     foreach (IProject* project, Core::self()->projectController()->projects()) {
         slotProjectOpened(project);
     }
-    connect(Core::self()->projectController(), SIGNAL(projectOpened( KDevelop::IProject* )),
+    connect(Core::self()->projectController(), SIGNAL(projectOpened(KDevelop::IProject*)),
             this, SLOT(slotProjectOpened(KDevelop::IProject*)));
-    connect(Core::self()->projectController(), SIGNAL(projectClosing( KDevelop::IProject* )),
+    connect(Core::self()->projectController(), SIGNAL(projectClosing(KDevelop::IProject*)),
             this, SLOT(slotProjectClosing(KDevelop::IProject*)));
     connect(Core::self()->projectController(), SIGNAL(projectConfigurationChanged(KDevelop::IProject*)),
              this, SLOT(slotRefreshProject(KDevelop::IProject*)));
@@ -355,7 +367,6 @@ void RunController::initialize()
     {
         // Only do this in GUI mode
         d->updateCurrentLaunchAction();
-        d->enableLaunchActions();
     }
 }
 
@@ -383,7 +394,10 @@ KJob* RunController::execute(const QString& runMode, ILaunchConfiguration* launc
     ILauncher* launcher = run->type()->launcherForId( launcherId );
 
     if( !launcher ) {
-        kWarning() << i18n("Launcher could not be found for the name '%1'. Check the launch configuration.", launcherId );
+        KMessageBox::error(
+            qApp->activeWindow(), 
+            i18n("The current launch configuration does not support the '%1' mode.", runMode),
+            "");
         return 0;
     }
 
@@ -402,48 +416,59 @@ void RunController::setupActions()
     action = new KAction (i18n("Configure Launches..."), this);
     ac->addAction("configure_launches", action);
     action->setStatusTip(i18n("Open Launch Configuration Dialog"));
-    action->setToolTip(i18n("Open Launch Configuration Dialog"));
-    action->setWhatsThis(i18n("<p>Opens a dialog to setup new launch configurations, or to change the existing ones.</p>"));
+    action->setToolTip(i18nc("@info:tooltip", "Open Launch Configuration Dialog"));
+    action->setWhatsThis(i18nc("@info:whatsthis", "Opens a dialog to setup new launch configurations, or to change the existing ones."));
     connect(action, SIGNAL(triggered(bool)), SLOT(configureLaunches()));
 
     d->runAction = new KAction( KIcon("system-run"), i18n("Execute Launch"), this);
-    d->runAction->setIconText( i18nc("Short text for 'Execute Launch' used in the toolbar", "Execute") );
+    d->runAction->setIconText( i18nc("Short text for 'Execute launch' used in the toolbar", "Execute") );
     d->runAction->setShortcut(Qt::SHIFT + Qt::Key_F9);
-    d->runAction->setToolTip(i18n("Execute current Launch"));
-    d->runAction->setStatusTip(i18n("Execute current Launch"));
-    d->runAction->setWhatsThis(i18n("<b>Execute Launch</b><p>Executes the target or the program specified in currently active launch configuration.</p>"));
+    d->runAction->setToolTip(i18nc("@info:tooltip", "Execute current launch"));
+    d->runAction->setStatusTip(i18n("Execute current launch"));
+    d->runAction->setWhatsThis(i18nc("@info:whatsthis", "Executes the target or the program specified in currently active launch configuration."));
     ac->addAction("run_execute", d->runAction);
     connect(d->runAction, SIGNAL(triggered(bool)), this, SLOT(slotExecute()));
 
-    d->dbgAction = new KAction( KIcon("dbgrun"), i18n("Debug Launch"), this);
+    d->dbgAction = new KAction( KIcon("debug-run"), i18n("Debug Launch"), this);
     d->dbgAction->setShortcut(Qt::Key_F9);
-    d->dbgAction->setIconText( i18nc("Short text for 'Debug Launch' used in the toolbar", "Debug") );
-    d->dbgAction->setToolTip(i18n("Debug current Launch"));
-    d->dbgAction->setStatusTip(i18n("Debug current Launch"));
-    d->dbgAction->setWhatsThis(i18n("<b>Debug Launch</b><p>Executes the target or the program specified in currently active launch configuration inside a Debugger.</p>"));
+    d->dbgAction->setIconText( i18nc("Short text for 'Debug launch' used in the toolbar", "Debug") );
+    d->dbgAction->setToolTip(i18nc("@info:tooltip", "Debug current launch"));
+    d->dbgAction->setStatusTip(i18n("Debug current launch"));
+    d->dbgAction->setWhatsThis(i18nc("@info:whatsthis", "Executes the target or the program specified in currently active launch configuration inside a Debugger."));
     ac->addAction("run_debug", d->dbgAction);
     connect(d->dbgAction, SIGNAL(triggered(bool)), this, SLOT(slotDebug()));
+    Core::self()->uiControllerInternal()->area(0, "code")->addAction(d->dbgAction);
 
-    d->profileAction = new KAction( KIcon(""), i18n("Profile Launch"), this);
-    d->profileAction->setToolTip(i18n("Profile current Launch"));
-    d->profileAction->setStatusTip(i18n("Profile current Launch"));
-    d->profileAction->setWhatsThis(i18n("<b>Profile Launch</b><p>Executes the target or the program specified in currently active launch configuration inside a Profiler.</p>"));
-    ac->addAction("run_profile", d->profileAction);
-    connect(d->profileAction, SIGNAL(triggered(bool)), this, SLOT(slotProfile()));
+//     TODO: at least get a profile target, it's sad to have the menu entry without a profiler
+//     KAction* profileAction = new KAction( KIcon(""), i18n("Profile Launch"), this);
+//     profileAction->setToolTip(i18nc("@info:tooltip", "Profile current launch"));
+//     profileAction->setStatusTip(i18n("Profile current launch"));
+//     profileAction->setWhatsThis(i18nc("@info:whatsthis", "Executes the target or the program specified in currently active launch configuration inside a Profiler."));
+//     ac->addAction("run_profile", profileAction);
+//     connect(profileAction, SIGNAL(triggered(bool)), this, SLOT(slotProfile()));
 
-    action = d->stopAction = new KActionMenu( KIcon("dialog-close"), i18n("Stop Jobs"), this);
-    action->setIconText(i18nc("Short text for 'Stop Jobs' used in the toolbar", "Stop"));
-    action->setShortcut(Qt::Key_Escape);
-    action->setToolTip(i18n("Stop all currently running jobs"));
-    action->setWhatsThis(i18n("<b>Stop Jobs</b><p>Requests that all running jobs are stopped.</p>"));
+    action = d->stopAction = new KAction( KIcon("process-stop"), i18n("Stop All Jobs"), this);
+    action->setIconText(i18nc("Short text for 'Stop All Jobs' used in the toolbar", "Stop All"));
+    // Ctrl+Escape would be nicer, but thats taken by the ksysguard desktop shortcut
+    action->setShortcut(QKeySequence("Ctrl+Shift+Escape"));
+    action->setToolTip(i18nc("@info:tooltip", "Stop all currently running jobs"));
+    action->setWhatsThis(i18nc("@info:whatsthis", "Requests that all running jobs are stopped."));
     action->setEnabled(false);
-    ac->addAction("run_stop", action);
+    ac->addAction("run_stop_all", action);
     connect(action, SIGNAL(triggered(bool)), this, SLOT(stopAllProcesses()));
+    Core::self()->uiControllerInternal()->area(0, "debug")->addAction(action);
+
+    action = d->stopJobsMenu = new KActionMenu( KIcon("process-stop"), i18n("Stop"), this);
+    action->setIconText(i18nc("Short text for 'Stop' used in the toolbar", "Stop"));
+    action->setToolTip(i18nc("@info:tooltip", "Menu allowing to stop individual jobs"));
+    action->setWhatsThis(i18nc("@info:whatsthis", "List of jobs that can be stopped individually."));
+    action->setEnabled(false);
+    ac->addAction("run_stop_menu", action);
 
     d->currentTargetAction = new KSelectAction( i18n("Current Launch Configuration"), this);
-    d->currentTargetAction->setToolTip(i18n("Current Launch Configuration"));
-    d->currentTargetAction->setStatusTip(i18n("Current Launch Configuration"));
-    d->currentTargetAction->setWhatsThis(i18n("<p>Select which launch configuration to run when run is invoked.</p>"));
+    d->currentTargetAction->setToolTip(i18nc("@info:tooltip", "Current launch configuration"));
+    d->currentTargetAction->setStatusTip(i18n("Current launch Configuration"));
+    d->currentTargetAction->setWhatsThis(i18nc("@info:whatsthis", "Select which launch configuration to run when run is invoked."));
     ac->addAction("run_default_target", d->currentTargetAction);
 }
 
@@ -460,6 +485,8 @@ void KDevelop::RunController::slotProjectOpened(KDevelop::IProject * project)
 
 void KDevelop::RunController::slotProjectClosing(KDevelop::IProject * project)
 {
+    if (!d->currentTargetAction) return;
+
     foreach (QAction* action, d->currentTargetAction->actions()) {
         LaunchConfiguration* l = static_cast<LaunchConfiguration*>(qvariant_cast<void*>(action->data()));
         if ( project == l->project() ) {
@@ -472,7 +499,6 @@ void KDevelop::RunController::slotProjectClosing(KDevelop::IProject * project)
                 d->currentTargetAction->actions().first()->setChecked(true);
         }
     }
-    d->enableLaunchActions();
 }
 
 void KDevelop::RunController::slotRefreshProject(KDevelop::IProject* project)
@@ -483,17 +509,36 @@ void KDevelop::RunController::slotRefreshProject(KDevelop::IProject* project)
 
 void RunController::slotDebug()
 {
-    executeDefaultLaunch( "debug" );
+    if(d->launchConfigurations.isEmpty()) {
+        LaunchConfigurationDialog d;
+        d.exec();
+    }
+    
+    if(!d->launchConfigurations.isEmpty())
+        executeDefaultLaunch( "debug" );
 }
 
 void RunController::slotProfile()
 {
-    executeDefaultLaunch( "profile" );
+    if(d->launchConfigurations.isEmpty()) {
+        LaunchConfigurationDialog d;
+        d.exec();
+    }
+    
+    if(!d->launchConfigurations.isEmpty())
+        executeDefaultLaunch( "profile" );
 }
 
 void RunController::slotExecute()
 {
-    executeDefaultLaunch( "execute" );
+    
+    if(d->launchConfigurations.isEmpty()) {
+        LaunchConfigurationDialog d;
+        d.exec();
+    }
+    
+    if(!d->launchConfigurations.isEmpty())
+        executeDefaultLaunch( "execute" );
 }
 
 LaunchConfiguration* KDevelop::RunController::defaultLaunch() const
@@ -509,12 +554,17 @@ void KDevelop::RunController::registerJob(KJob * job)
     if (!job)
         return;
 
+    if (!(job->capabilities() & KJob::Killable)) {
+        // see e.g. https://bugs.kde.org/show_bug.cgi?id=314187
+        kWarning() << "non-killable job" << job << "registered - this might lead to crashes on shutdown.";
+    }
+
     if (!d->jobs.contains(job)) {
         KAction* stopJobAction = 0;
         if (Core::self()->setupFlags() != Core::NoUi) {
-            stopJobAction = new KAction(job->objectName().isEmpty() ? i18n("Unnamed job") : job->objectName(), this);
+            stopJobAction = new KAction(job->objectName().isEmpty() ? i18n("<%1> Unnamed job", job->staticMetaObject.className()) : job->objectName(), this);
             stopJobAction->setData(QVariant::fromValue(static_cast<void*>(job)));
-            d->stopAction->addAction(stopJobAction);
+            d->stopJobsMenu->addAction(stopJobAction);
             connect (stopJobAction, SIGNAL(triggered(bool)), SLOT(slotKillJob()));
 
             job->setUiDelegate( new KDialogJobUiDelegate() );
@@ -523,6 +573,7 @@ void KDevelop::RunController::registerJob(KJob * job)
         d->jobs.insert(job, stopJobAction);
 
         connect( job, SIGNAL(finished(KJob*)), SLOT(finished(KJob*)) );
+        connect( job, SIGNAL(destroyed(QObject*)), SLOT(jobDestroyed(QObject*)) );
 
         IRunController::registerJob(job);
 
@@ -566,15 +617,26 @@ void KDevelop::RunController::checkState()
         emit runStateChanged(d->state);
     }
 
-    if (Core::self()->setupFlags() != Core::NoUi)
+    if (Core::self()->setupFlags() != Core::NoUi) {
         d->stopAction->setEnabled(running);
+        d->stopJobsMenu->setEnabled(running);
+    }
 }
 
 void KDevelop::RunController::stopAllProcesses()
 {
+    // composite jobs might remove child jobs, see also:
+    // https://bugs.kde.org/show_bug.cgi?id=258904
+    // foreach already iterates over a copy
     foreach (KJob* job, d->jobs.keys()) {
-        if (job->capabilities() & KJob::Killable)
+        // now we check the real list whether it was deleted
+        if (!d->jobs.contains(job))
+            continue;
+        if (job->capabilities() & KJob::Killable) {
             job->kill(KJob::EmitResult);
+        } else {
+            kWarning() << "cannot stop non-killable job: " << job;
+        }
     }
 }
 
@@ -599,7 +661,29 @@ void KDevelop::RunController::finished(KJob * job)
             break;
 
         default:
-            KMessageBox::error(qApp->activeWindow(), job->errorString(), i18n("Process Error"));
+        {
+            ///WARNING: do *not* use a nested event loop here, it might cause
+            ///         random crashes later on, see e.g.:
+            ///         https://bugs.kde.org/show_bug.cgi?id=309811
+            KDialog* dialog = new KDialog(qApp->activeWindow());
+            dialog->setAttribute(Qt::WA_DeleteOnClose);
+            dialog->setWindowTitle(i18n("Process Error"));
+            dialog->setButtons(KDialog::Close);
+            KMessageBox::createKMessageBox(dialog, QMessageBox::Warning,
+                                           job->errorString(), QStringList(),
+                                           QString(), 0, KMessageBox::NoExec
+            );
+            dialog->show();
+        }
+    }
+}
+
+void RunController::jobDestroyed(QObject* job)
+{
+    KJob* kjob = static_cast<KJob*>(job);
+    if (d->jobs.contains(kjob)) {
+        kWarning() << "job destroyed without emitting finished signal!";
+        unregisterJob(kjob);
     }
 }
 
@@ -695,7 +779,6 @@ void KDevelop::RunController::addLaunchConfiguration(KDevelop::LaunchConfigurati
     {
         d->addLaunchAction( l );
         d->launchConfigurations << l;
-        d->enableLaunchActions();
         if( !d->currentTargetAction->currentAction() )
         {
             if( !d->currentTargetAction->actions().isEmpty() )
@@ -737,8 +820,6 @@ void KDevelop::RunController::removeLaunchConfiguration(KDevelop::LaunchConfigur
 
     d->launchConfigurations.removeAll( l );
 
-    d->enableLaunchActions();
-
     delete l;
 }
 
@@ -764,6 +845,28 @@ void RunController::setDefaultLaunch(ILaunchConfiguration* l)
     }
 }
 
+bool launcherNameExists(const QString& name)
+{
+    foreach(ILaunchConfiguration* config, Core::self()->runControllerInternal()->launchConfigurations()) {
+        if(config->name()==name)
+            return true;
+    }
+    return false;
+}
+
+QString makeUnique(const QString& name)
+{
+    if(launcherNameExists(name)) {
+        for(int i=2; ; i++) {
+            QString proposed = QString("%1 (%2)").arg(name).arg(i);
+            if(!launcherNameExists(proposed)) {
+                return proposed;
+            }
+        }
+    }
+    return name;
+}
+
 ILaunchConfiguration* RunController::createLaunchConfiguration ( LaunchConfigurationType* type,
                                                                  const QPair<QString,QString>& launcher,
                                                                  IProject* project, const QString& name )
@@ -790,8 +893,10 @@ ILaunchConfiguration* RunController::createLaunchConfiguration ( LaunchConfigura
     QString cfgName = name;
     if( name.isEmpty() )
     {
-        cfgName = i18n("New %1 Configuration", type->name() );
+        cfgName = i18n("New %1 Launcher", type->name() );
+        cfgName = makeUnique(cfgName);
     }
+    
     launchConfigGroup.writeEntry(LaunchConfiguration::LaunchConfigurationNameEntry, cfgName );
     launchConfigGroup.writeEntry(LaunchConfiguration::LaunchConfigurationTypeEntry, type->id() );
     launchConfigGroup.sync();
@@ -813,7 +918,7 @@ ContextMenuExtension RunController::contextMenuExtension ( Context* ctx )
 {
     delete d->launchAsMapper;
     d->launchAsMapper = new QSignalMapper( this );
-    kDebug() << "connected launchmapper:" << connect( d->launchAsMapper, SIGNAL( mapped( int ) ), SLOT( launchAs( int ) ) );
+    connect( d->launchAsMapper, SIGNAL(mapped(int)), SLOT(launchAs(int)) );
     d->launchAsInfo.clear();
     d->contextItem = 0;
     ContextMenuExtension ext;
@@ -836,14 +941,14 @@ ContextMenuExtension RunController::contextMenuExtension ( Context* ctx )
                             hasLauncher = true;
                         }
                     }
-                    if( type->canLaunch(itm) && hasLauncher )
+                    if( hasLauncher && type->canLaunch(itm) )
                     {
                         d->launchAsInfo[i] = qMakePair( type->id(), mode->id() );
                         KAction* act = new KAction( d->launchAsMapper );
                         act->setText( type->name() );
                         kDebug() << "Setting up mapping for:" << i << "for action" << act->text() << "in mode" << mode->name();
                         d->launchAsMapper->setMapping( act, i );
-                        kDebug() << "action connected:" << connect( act, SIGNAL( triggered() ), d->launchAsMapper, SLOT( map() ) );
+                        connect( act, SIGNAL(triggered()), d->launchAsMapper, SLOT(map()) );
                         menu->addAction(act);
                         i++;
                     }
