@@ -24,6 +24,7 @@
 #include <QVBoxLayout>
 #include <QWidget>
 #include <QLabel>
+#include <QLayout>
 
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -294,15 +295,33 @@ public:
     TextEditorWidgetPrivate()
     {
         widget = 0;
-        statusBar = 0;
         widgetLayout = 0;
         view = 0;
         statusLabel = 0;
     }
+
+    void viewEditModeChanged(KTextEditor::View* view, KTextEditor::View::EditMode mode)
+    {
+#ifdef KTEXTEDITOR_HAS_VIMODE
+        if ( ! statusLabel ) {
+            statusLabel = new QLabel();
+            view->layout()->addWidget(statusLabel);
+        }
+        if ( mode == KTextEditor::View::EditViMode ) {
+            statusLabel->setText(view->viewMode() + "    <i>" + view->document()->url().fileName() + "</i>");
+            statusLabel->setHidden(false);
+        }
+        else {
+            statusLabel->setHidden(true);
+        }
+#else
+        Q_UNUSED(view);
+        Q_UNUSED(mode);
+#endif
+    }
     QWidget* widget;
     QVBoxLayout* widgetLayout;
     QPointer<KTextEditor::View> view;
-    KStatusBar *statusBar;
     QLabel* statusLabel;
     QString status;
     const TextView* textView;
@@ -362,7 +381,7 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
 
         d->setStatus(d->document, false);
 
-        /* It appears, that by default a part will be deleted the the
+        /* It appears, that by default a part will be deleted the
            first view containing it is deleted.  Since we do want
            to have several views, disable that behaviour.  */
         d->document->setAutoDeletePart(false);
@@ -801,6 +820,9 @@ void KDevelop::TextEditorWidget::setEditorView(KTextEditor::View* view)
     
     viewStatusChanged(view, view->cursorPosition());
 
+    connect(view, SIGNAL(viewEditModeChanged(KTextEditor::View*,KTextEditor::View::EditMode)),
+            this, SLOT(viewEditModeChanged(KTextEditor::View*,KTextEditor::View::EditMode)));
+
     d->widgetLayout->insertWidget(0, d->view);
     setFocusProxy(view);
 }
