@@ -21,6 +21,7 @@
 #include <QMap>
 #include <QList>
 #include <QStringList>
+#include <QAction>
 
 #include <kdebug.h>
 
@@ -94,10 +95,9 @@ struct AreaPrivate {
     QString iconName;
     QString workingSet;
     QWeakPointer<View> activeView;
+    QList<QAction*> m_actions;
 };
 
-
-
 // class Area
 
 Area::Area(Controller *controller, const QString &name, const QString &title)
@@ -470,6 +470,22 @@ void Area::clearViews(bool silent)
         closeView(view, silent);
 }
 
+QList<QAction*> Area::actions() const
+{
+    return d->m_actions;
+}
+
+void Area::addAction(QAction* action)
+{
+    connect(action, SIGNAL(destroyed(QObject*)), SLOT(actionDestroyed(QObject*)));
+    d->m_actions.append(action);
+}
+
+void Area::actionDestroyed(QObject* action)
+{
+    d->m_actions.removeAll(qobject_cast<QAction*>(action));
+}
+
 }
 
 #include "area.moc"
