@@ -16,8 +16,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#ifndef SUBLIMECONTAINER_H
-#define SUBLIMECONTAINER_H
+#ifndef KDEVPLATFORM_SUBLIMECONTAINER_H
+#define KDEVPLATFORM_SUBLIMECONTAINER_H
 
 #include <ktabwidget.h>
 
@@ -47,7 +47,7 @@ public:
     ~Container();
 
     /**Adds the widget for given @p view to the container.*/
-    void addWidget(View *view);
+    void addWidget(Sublime::View* view, int position = -1);
     /**Removes the widget from the container.*/
     void removeWidget(QWidget *w);
     /** @return true if widget is placed inside this container.*/
@@ -62,28 +62,37 @@ public:
     View *viewForWidget(QWidget *w) const;
 
     void setTabBarHidden(bool hide);
-    void setOpenAfterCurrent(bool after);
 
     /** Adds a corner widget to the left of this containers tab-bar. To remove it again, just delete it.
       * The ownership otherwise goes to the container. */
     void setLeftCornerWidget(QWidget* widget);
     void showTooltipForTab(int tab);
 
+    bool isCurrentTab(int tab) const;
+    /// @return Rect in global position of the tab identified by index @p tab
+    QRect tabRect(int tab) const;
+
 Q_SIGNALS:
     void activateView(Sublime::View* view);
-    void closeRequest(QWidget *w);
+    void requestClose(QWidget *w);
     void tabContextMenuRequested(Sublime::View* view, KMenu* menu);
-    void tabToolTipRequested(Sublime::View* view, QPoint pos);
+    /**
+     * @p view The view represented by the tab that was hovered
+     * @p Container The tab container that triggered the event
+     * @p idx The index of the tab that was hovered
+     */
+    void tabToolTipRequested(Sublime::View* view, Sublime::Container* container, int idx);
 
 private Q_SLOTS:
     void widgetActivated(int idx);
     void documentTitleChanged(Sublime::Document* doc);
     void statusIconChanged(Sublime::Document*);
     void statusChanged(Sublime::View *view);
-    void closeRequest(int idx);
+    void requestClose(int idx);
     void tabMoved(int from, int to);
     void wheelScroll(int);
-    void contextMenu(int,QPoint);
+    void contextMenu(int, const QPoint&);
+    void documentListActionTriggered(QAction*);
 
 private:
 
