@@ -27,6 +27,7 @@
 #include <QtGui/QHBoxLayout>
 #include <QtGui/QToolButton>
 #include <QtGui/QCommonStyle>
+#include <QTimer>
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -41,12 +42,52 @@
 #include "container.h"
 #include "controller.h"
 #include "mainwindow.h"
-#include "ideal.h"
+#include "idealcontroller.h"
 #include "holdupdates.h"
+#include "idealbuttonbarwidget.h"
 #include <KToolBar>
 #include <KSelectAction>
 #include <ktoggleaction.h>
 
+class IdealToolBar : public QToolBar
+{
+    Q_OBJECT
+    public:
+        explicit IdealToolBar(const QString& title, Sublime::IdealButtonBarWidget* buttons, QMainWindow* parent)
+            : QToolBar(title, parent), m_buttons(buttons)
+        {
+            setMovable(false);
+            setFloatable(false);
+            setObjectName(title);
+            layout()->setMargin(0);
+            
+            addWidget(m_buttons);
+        }
+
+        void hideWhenEmpty()
+        {
+            refresh();
+            
+            QTimer* t = new QTimer(this);
+            t->setInterval(100);
+            t->setSingleShot(true);
+            connect(t, SIGNAL(timeout()), SLOT(refresh()));
+            connect(this, SIGNAL(visibilityChanged(bool)), t, SLOT(start()));
+            connect(m_buttons, SIGNAL(emptyChanged()), t, SLOT(start()));
+        }
+
+    public slots:
+        void refresh()
+        {
+            if(m_buttons->isEmpty()==isVisible()) {
+                setVisible(!m_buttons->isEmpty());
+            }
+        }
+
+    private:
+        Sublime::IdealButtonBarWidget* m_buttons;
+};
+
 namespace Sublime {
 
 MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
@@ -73,7 +114,7 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
     connect(action, SIGNAL(toggled(bool)), SLOT(showBottomDock(bool)));
     ac->addAction("show_bottom_dock", action);
 
-    action = new KAction(i18n("Focus Editor"), this);
+    action = new KAction(i18nc("@action", "Focus Editor"), this);
     action->setShortcuts(QList<QKeySequence>() << (Qt::META | Qt::CTRL | Qt::Key_E) << Qt::META + Qt::Key_C);
     connect(action, SIGNAL(triggered(bool)), this, SLOT(focusEditor()));
     ac->addAction("focus_editor", action);
@@ -85,11 +126,13 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
 
     action = new KAction(i18n("Next Tool View"), this);
     action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_N);
+    action->setIcon(KIcon("go-next"));
     connect(action, SIGNAL(triggered(bool)), SLOT(selectNextDock()));
     ac->addAction("select_next_dock", action);
 
     action = new KAction(i18n("Previous Tool View"), this);
     action->setShortcut(Qt::META | Qt::CTRL | Qt::Key_P);
+    action->setIcon(KIcon("go-previous"));
     connect(action, SIGNAL(triggered(bool)), SLOT(selectPreviousDock()));
     ac->addAction("select_previous_dock", action);
 
@@ -98,31 +141,15 @@ MainWindowPrivate::MainWindowPrivate(MainWindow *w, Controller* controller)
 
     idealController = new IdealController(m_mainWindow);
 
-    QToolBar *leftToolBar = new QToolBar(i18n("Left Button Bar"), m_mainWindow);
-    leftToolBar->setObjectName("left_button_bar");
-    leftToolBar->setMovable(false);
-    leftToolBar->setFloatable(false);
-    leftToolBar->layout()->setMargin(0);
-    leftToolBar->addWidget(idealController->leftBarWidget);
-    idealController->leftBarWidget->show();
+    IdealToolBar* leftToolBar = new IdealToolBar(i18n("Left Button Bar"), idealController->leftBarWidget, m_mainWindow);
+    leftToolBar->hideWhenEmpty();
     m_mainWindow->addToolBar(Qt::LeftToolBarArea, leftToolBar);
 
-    QToolBar *rightToolBar = new QToolBar(i18n("Right Button Bar"), m_mainWindow);
-    rightToolBar->setObjectName("right_button_bar");
-    rightToolBar->setMovable(false);
-    rightToolBar->setFloatable(false);
-    rightToolBar->layout()->setMargin(0);
-    rightToolBar->addWidget(idealController->rightBarWidget);
-    idealController->rightBarWidget->show();
+    IdealToolBar* rightToolBar = new IdealToolBar(i18n("Right Button Bar"), idealController->rightBarWidget, m_mainWindow);
+    rightToolBar->hideWhenEmpty();
     m_mainWindow->addToolBar(Qt::RightToolBarArea, rightToolBar);
 
-    QToolBar *bottomToolBar = new QToolBar(i18n("Bottom Button Bar"), m_mainWindow);
-    bottomToolBar->setObjectName("bottom_button_bar");
-    bottomToolBar->setMovable(false);
-    bottomToolBar->setFloatable(false);
-    bottomToolBar->layout()->setMargin(0);
-    bottomToolBar->addWidget(idealController->bottomBarWidget);
-    idealController->bottomBarWidget->show();
+    IdealToolBar* bottomToolBar = new IdealToolBar(i18n("Bottom Button Bar"), idealController->bottomBarWidget, m_mainWindow);
     m_mainWindow->addToolBar(Qt::BottomToolBarArea, bottomToolBar);
 
     // adymo: intentionally do not add a toolbar for top buttonbar
@@ -257,7 +284,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         Q_ASSERT(splitter);
     }
 
-    if (index->isSplitted()) //this is a visible splitter
+    if (index->isSplit()) //this is a visible splitter
         splitter->setOrientation(index->orientation());
     else
     {
@@ -267,6 +294,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         {
             // After unsplitting, we might have to remove old splitters
             QWidget* widget = splitter->widget(0);
+            kDebug() << "deleting" << widget;
             widget->setParent(0);
             delete widget;
         }
@@ -280,7 +308,7 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
                     d->m_mainWindow, SLOT(tabContextMenuRequested(Sublime::View*,KMenu*)));
             connect(container, SIGNAL(tabToolTipRequested(Sublime::View*,Sublime::Container*,int)),
                     d->m_mainWindow, SLOT(tabToolTipRequested(Sublime::View*,Sublime::Container*,int)));
-            connect(container, SIGNAL(closeRequest(QWidget*)),
+            connect(container, SIGNAL(requestClose(QWidget*)),
                     d, SLOT(widgetCloseRequest(QWidget*)), Qt::QueuedConnection);
             splitter->addWidget(container);
         }
@@ -289,9 +317,13 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
         container->show();
 
         int position = 0;
+        bool hadActiveView = false;
+        Sublime::View* activeView = d->activeView;
+        
         foreach (View *view, index->views())
         {
             QWidget *widget = view->widget(container);
+            
             if (widget)
             {
                 if(!container->hasWidget(widget))
@@ -300,7 +332,11 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
                     d->viewContainers[view] = container;
                     d->widgetToView[widget] = view;
                 }
-                if(d->activeView == view)
+                if(activeView == view)
+                {
+                    hadActiveView = true;
+                    container->setCurrentWidget(widget);
+                }else if(topViews.contains(view) && !hadActiveView)
                     container->setCurrentWidget(widget);
             }
             position++;
@@ -309,9 +345,9 @@ Area::WalkerMode MainWindowPrivate::ViewCreator::operator() (AreaIndex *index)
     return Area::ContinueWalker;
 }
 
-void MainWindowPrivate::reconstructViews()
+void MainWindowPrivate::reconstructViews(QList<View*> topViews)
 {
-    ViewCreator viewCreator(this);
+    ViewCreator viewCreator(this, topViews);
     area->walkViews(viewCreator, area->rootIndex());
     setBackgroundVisible(area->views().isEmpty());
 }
@@ -403,8 +439,7 @@ struct ShownToolViewFinder {
     QList<View *> views;
 };
 
-void MainWindowPrivate::
-slotDockShown(Sublime::View* view, Sublime::Position pos, bool shown)
+void MainWindowPrivate::slotDockShown(Sublime::View* /*view*/, Sublime::Position pos, bool /*shown*/)
 {
     if (ignoreDockShown)
         return;
@@ -423,10 +458,6 @@ void MainWindowPrivate::viewRemovedInternal(AreaIndex* index, View* view)
 {
     Q_UNUSED(index);
     Q_UNUSED(view);
-    // A formerly non-empty working-set has become empty, and a relayout of the area-selector may be required
-    if(m_mainWindow->area()->views().size() == 0)
-        m_mainWindow->setupAreaSelector();
-    
     setBackgroundVisible(area->views().isEmpty());
 }
 
@@ -443,7 +474,7 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
         for(Sublime::AreaIndex* current = index; current; current = current->parent())
         {
         QSplitter *splitter = m_indexSplitters[current];
-        if (current->isSplitted() && splitter)
+        if (current->isSplit() && splitter)
         {
             // Also update the orientation
             splitter->setOrientation(current->orientation());
@@ -472,11 +503,7 @@ void MainWindowPrivate::viewAdded(Sublime::AreaIndex *index, Sublime::View *view
     emit m_mainWindow->viewAdded( view );
     
     setTabBarLeftCornerWidget(m_leftTabbarCornerWidget.data());
-    
-    // A formerly empty working-set may become non-empty, and a relayout of the area-selector may be required
-    if(m_mainWindow->area()->views().size() == 1)
-        m_mainWindow->setupAreaSelector();
-    
+
     setBackgroundVisible(false);
 }
 
@@ -665,7 +692,7 @@ void MainWindowPrivate::activateFirstVisibleView()
         m_mainWindow->activateView(area->views().first());
 }
 
-void MainWindowPrivate::widgetResized(Qt::DockWidgetArea dockArea, int thickness)
+void MainWindowPrivate::widgetResized(Qt::DockWidgetArea /*dockArea*/, int /*thickness*/)
 {
     //TODO: adymo: remove all thickness business
 }
@@ -679,169 +706,6 @@ void MainWindowPrivate::widgetCloseRequest(QWidget* widget)
     }
 }
 
-void MainWindowPrivate::toggleArea ( int index ) {
-    m_mainWindow->controller()->showArea(areaSwitcher->tabBar->areaId(index), m_mainWindow);
-}
-
-void AreaTabBar::paintEvent ( QPaintEvent* ev ) {
-    QTabBar::paintEvent(ev);
-    if ( currentIndex() != -1 ) {
-        QStylePainter p ( this );
-        //Draw highlight behind current area
-        QRect activeRect = tabRect ( currentIndex() );
-        QRect tabArea = activeRect;
-        QImage img ( tabArea.width(), tabArea.height(), QImage::Format_ARGB32 );
-        img.fill ( 0 );
-        QPainter paintImg ( &img );
-        QColor color ( palette().color ( QPalette::Active, QPalette::Highlight ) );
-        color.setAlpha ( 70 );
-        QRect paint = tabArea;
-        const int margin = 8;
-        paint.setLeft ( margin );
-        paint.setTop ( margin );
-        paint.setRight ( activeRect.width()-margin );
-        paint.setBottom ( activeRect.height()-margin );
-
-        paintImg.fillRect ( paint, color );
-        expblur<16,7> ( img, margin/2 );
-        p.drawImage ( tabArea, img );
-    }
-}
-
-void AreaTabWidget::paintEvent ( QPaintEvent* ev ) {
-    QWidget::paintEvent ( ev );
-
-    if ( tabBar->isVisible() && tabBar->count() > 0 ) {
-        QStylePainter p ( this );
-
-        QStyleOptionTabBarBase optTabBase;
-        optTabBase.init ( tabBar );
-        optTabBase.shape = tabBar->shape();
-        optTabBase.tabBarRect = tabBar->rect();
-        optTabBase.tabBarRect.moveTopLeft(tabBar->pos());
-
-        int sideWidth = width()-tabBar->width();
-
-        QStyleOptionTab tabOverlap;
-        tabOverlap.shape = tabBar->shape();
-        int overlap = style()->pixelMetric ( QStyle::PM_TabBarBaseOverlap, &tabOverlap, tabBar );
-        QRect rect;
-        rect.setRect ( 0, height()-overlap, sideWidth, overlap );
-        optTabBase.rect = rect;
-
-        QImage img ( sideWidth, height(), QImage::Format_ARGB32 );
-        img.fill ( 0 );
-        QStylePainter p2 ( &img, tabBar );
-        p2.drawPrimitive ( QStyle::PE_FrameTabBarBase, optTabBase );
-
-        {
-            //Blend the painted line out to the left
-            QLinearGradient blendOut ( 0, 0, sideWidth, 0 );
-            blendOut.setColorAt ( 0, QColor ( 255, 255, 255, 255 ) );
-            blendOut.setColorAt ( 1, QColor ( 0, 0, 0, 0 ) );
-            QBrush blendBrush ( blendOut );
-
-            p2.setCompositionMode ( QPainter::CompositionMode_DestinationOut );
-            p2.fillRect ( img.rect(), blendBrush );
-        }
-
-        p.setCompositionMode ( QPainter::CompositionMode_SourceOver );
-        p.drawImage ( img.rect(), img );
-    }
-}
-
-QSize AreaTabWidget::sizeHint() const {
-    //Resize to hold the whole length up to the menu
-    static bool zeroSizeHint = false;
-    if ( zeroSizeHint )
-        return QSize();
-    zeroSizeHint = true;
-    int available = bar()->parentWidget()->width() - bar()->sizeHint().width() - 10;
-    zeroSizeHint = false;
-    QSize orig = tabBar->sizeHint();
-    int addFade = available - orig.width();
-    
-    int perfectFade = 500;
-    if(areaSideWidget)
-        perfectFade += areaSideWidget->sizeHint().width();
-    
-    if(addFade > perfectFade)
-        addFade = perfectFade;
-    
-    int wantWidth = addFade + orig.width();
-    
-    if ( wantWidth > orig.width() )
-        orig.setWidth ( wantWidth );
-    return orig;
-}
-
-AreaTabWidget::AreaTabWidget ( QMenuBar* parent ) : QWidget ( parent ), areaSideWidget(0) {
-    m_layout = new QHBoxLayout ( this );
-    m_layout->setAlignment ( Qt::AlignRight );
-    tabBar = new AreaTabBar ( this );
-    m_layout->addWidget ( tabBar );
-    m_layout->setContentsMargins ( 0,0,0,0 );
-    m_leftLayout = new QVBoxLayout;
-    
-    m_leftLayout->setContentsMargins(11, 4, 11, 8); ///@todo These margins are a bit too hardcoded, should depend on style
-    m_layout->insertLayout(0, m_leftLayout);
-}
-
-QSize AreaTabBar::tabSizeHint ( int index ) const {
-    //Since we move all contents into the button, we give approximately the button size as size-hint
-    //QTabBar seems to add useless space for the non-existing tab text
-    QSize ret = QTabBar::tabSizeHint(index);
-    
-    if(ret.width() > buttons[index]->sizeHint().width()+16)
-        ret.setWidth(buttons[index]->sizeHint().width() + 16); ///@todo Where does the offset come from?
-    return ret;
-}
-
-
-void AreaTabButton::setIsCurrent ( bool arg1 ) {
-    m_isCurrent = arg1;
-}
-
-void AreaTabBar::setCurrentIndex ( int index ) {
-    m_currentIndex = index;
-    foreach(AreaTabButton* button, buttons) {
-        button->setIsCurrent(buttons.indexOf(button) == index);
-    }
-    QTabBar::setCurrentIndex ( index );
-    foreach(AreaTabButton* button, buttons) {
-        button->update();
-    }
-    update();
-}
-
-AreaTabBar::AreaTabBar ( QWidget* parent ) : QTabBar ( parent ), m_currentIndex ( -1 ) {
-    setShape ( QTabBar::RoundedNorth );
-    setDocumentMode ( true );
-    setExpanding ( false );
-    setLayoutDirection ( Qt::RightToLeft );
-    setDrawBase ( false );
-    setFocusPolicy( Qt::NoFocus );
-    QPalette pal = palette();
-}
-
-AreaTabButton::AreaTabButton ( QString text, QIcon icon, uint iconSize, QWidget* parent, bool isCurrent, QWidget* _customButtonWidget )
-	: QWidget ( parent ), customButtonWidget(_customButtonWidget), m_isCurrent ( isCurrent )
-{
-    QHBoxLayout* layout = new QHBoxLayout ( this );
-    iconLabel = new QLabel ( this );
-    iconLabel->setPixmap ( icon.pixmap ( QSize ( iconSize, iconSize ) ) );
-    iconLabel->setAutoFillBackground ( false );
-    textLabel = new QLabel ( this );
-    textLabel->setText ( text );
-    textLabel->setAutoFillBackground ( false );
-    if(customButtonWidget) {
-        customButtonWidget->setParent(this);
-        layout->addWidget(customButtonWidget);
-    }
-    layout->addWidget ( textLabel );
-    layout->addWidget ( iconLabel );
-    layout->setMargin ( 0 );
-}
 
 void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
 {
@@ -856,7 +720,7 @@ void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
     
     AreaIndex* putToIndex = area->rootIndex();
     QSplitter* splitter = m_indexSplitters[putToIndex];
-    while(putToIndex->isSplitted()) {
+    while(putToIndex->isSplit()) {
         putToIndex = putToIndex->first();
         splitter = m_indexSplitters[putToIndex];
     }
@@ -877,4 +741,5 @@ void MainWindowPrivate::setTabBarLeftCornerWidget(QWidget* widget)
 }
 
 #include "mainwindow_p.moc"
+#include "moc_mainwindow_p.cpp"
 
