@@ -18,48 +18,43 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  ***************************************************************************/
 
-#ifndef BRANCH_MANAGER_H
-#define BRANCH_MANAGER_H
+#ifndef KDEVPLATFORM_BRANCH_MANAGER_H
+#define KDEVPLATFORM_BRANCH_MANAGER_H
 
-#include <QtGui/QStringListModel>
 #include <KDE/KDialog>
-#include <QStandardItemModel>
 
-class BranchesListModel;
 class KJob;
+
 namespace Ui { class BranchDialogBase; }
 
 namespace KDevelop
 {
-    class DistributedVersionControlPlugin;
-class IBranchingVersionControl;
+class BranchesListModel;
+class DistributedVersionControlPlugin;
 }
 
 class BranchManager : public KDialog
 {
     Q_OBJECT
 public:
-    BranchManager(const QString &_repo, KDevelop::DistributedVersionControlPlugin* executor, QWidget *parent = 0);
+    BranchManager(const QString& repository, KDevelop::DistributedVersionControlPlugin* executor, QWidget *parent = 0);
     ~BranchManager();
-    
-    bool isValid() const { return m_valid; }
 
 signals:
     void checkedOut(KJob*);
 
 private slots:
     void createBranch();
-    void delBranch();
+    void deleteBranch();
+    void renameBranch();
     void checkoutBranch();
 
 private:
-    QString repo;
-    KDevelop::DistributedVersionControlPlugin* d;
+    QString m_repository;
+    KDevelop::DistributedVersionControlPlugin* m_dvcPlugin;
 
     Ui::BranchDialogBase* m_ui;
-    BranchesListModel* m_model;
-    bool m_valid;
-    
+    KDevelop::BranchesListModel* m_model;
 };
 
 #endif
