@@ -1,7 +1,7 @@
 /*  This file is part of KDevelop
     Copyright 2010 Aleix Pol <aleixpol@kde.org>
 
-    Splitted into separate class
+    Split into separate class
     Copyright 2011 Andrey Batyiev <batyiev@gmail.com>
 
     This library is free software; you can redistribute it and/or
@@ -161,16 +161,24 @@ QList<VcsStatusInfo> VcsFileChangesModel::checkedStatuses(QStandardItem *parent)
     return ret;
 }
 
+void VcsFileChangesModel::setAllChecked(bool checked)
+{
+    if(!d->allowSelection)
+        return;
+    QStandardItem* parent = invisibleRootItem();
+    for(int i = 0; i < parent->rowCount(); i++) {
+        QStandardItem* item = parent->child(i);
+        item->setCheckState(checked ? Qt::Checked : Qt::Unchecked);
+    }
+}
+
 QList<KUrl> VcsFileChangesModel::checkedUrls(QStandardItem *parent) const
 {
     QList<KUrl> ret;
 
-    if(!d->allowSelection)
-        return ret;
-
     for(int i = 0; i < parent->rowCount(); i++) {
         QStandardItem* item = parent->child(i);
-        if(item->checkState() == Qt::Checked) {
+        if(!d->allowSelection || item->checkState() == Qt::Checked) {
             ret << statusInfo(item).url();
         }
     }
@@ -178,6 +186,30 @@ QList<KUrl> VcsFileChangesModel::checkedUrls(QStandardItem *parent) const
     return ret;
 }
 
+QList<KUrl> VcsFileChangesModel::urls(QStandardItem *parent) const
+{
+    QList<KUrl> ret;
+
+    for(int i = 0; i < parent->rowCount(); i++) {
+        ret << statusInfo(parent->child(i)).url();
+    }
+
+    return ret;
+}
+
+void VcsFileChangesModel::checkUrls(QStandardItem *parent, const QList<KUrl>& urls) const
+{
+    QSet<KUrl> urlSet(urls.toSet());
+
+    if(!d->allowSelection)
+        return;
+
+    for(int i = 0; i < parent->rowCount(); i++) {
+        QStandardItem* item = parent->child(i);
+        item->setCheckState(urlSet.contains(statusInfo(item).url()) ? Qt::Checked : Qt::Unchecked);
+    }
+}
+
 void VcsFileChangesModel::setIsCheckbable(bool checkable)
 {
     d->allowSelection = checkable;
