@@ -29,16 +29,83 @@
 #include "vcsdiff.h"
 #include <interfaces/iplugincontroller.h>
 #include <KComboBox>
+#include <KTextEdit>
 #include <interfaces/isession.h>
 #include <interfaces/ibasicversioncontrol.h>
 
 using namespace KDevelop;
 
-VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater, const KUrl& url, IBasicVersionControl* vcs)
-    : VCSDiffPatchSource(updater), m_vcs(vcs)
+VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater)
+    : VCSDiffPatchSource(updater), m_vcs(updater->vcs())
 {
     Q_ASSERT(m_vcs);
+    m_commitMessageWidget = new QWidget;
+    QVBoxLayout* layout = new QVBoxLayout(m_commitMessageWidget.data());
+
+    m_commitMessageEdit = new KTextEdit;
+    m_commitMessageEdit.data()->setFont( KGlobalSettings::fixedFont() );
+    m_commitMessageEdit.data()->setLineWrapMode(QTextEdit::NoWrap);
+    m_vcs->setupCommitMessageEditor(updater->url(), m_commitMessageEdit.data());
     
+    QHBoxLayout* titleLayout = new QHBoxLayout;
+    titleLayout->addWidget(new QLabel(i18n("Commit Message:")));
+    
+    m_oldMessages = new KComboBox;
+    
+    m_oldMessages->addItem(i18n("Old Messages"));
+    foreach(QString message, oldMessages())
+        m_oldMessages->addItem(message, message);
+    m_oldMessages->setMaximumWidth(200);
+    
+    connect(m_oldMessages, SIGNAL(currentIndexChanged(QString)), this, SLOT(oldMessageChanged(QString)));
+    
+    titleLayout->addWidget(m_oldMessages);
+    
+    layout->addLayout(titleLayout);
+    layout->addWidget(m_commitMessageEdit.data());
+    connect(this, SIGNAL(reviewCancelled(QString)), SLOT(addMessageToHistory(QString)));
+    connect(this, SIGNAL(reviewFinished(QString,QList<KUrl>)), SLOT(addMessageToHistory(QString)));
+}
+
+QStringList VCSCommitDiffPatchSource::oldMessages() const
+{
+    KConfigGroup vcsGroup(ICore::self()->activeSession()->config(), "VCS");
+    return vcsGroup.readEntry("OldCommitMessages", QStringList());
+}
+
+void VCSCommitDiffPatchSource::addMessageToHistory(const QString& message)
+{
+    if(ICore::self()->shuttingDown())
+        return;
+    
+    KConfigGroup vcsGroup(ICore::self()->activeSession()->config(), "VCS");
+    
+    const int maxMessages = 10;
+    QStringList oldMessages = vcsGroup.readEntry("OldCommitMessages", QStringList());
+    
+    oldMessages.removeAll(message);
+    oldMessages.push_front(message);
+    oldMessages = oldMessages.mid(0, maxMessages);
+    
+    vcsGroup.writeEntry("OldCommitMessages", oldMessages);
+}
+
+void VCSCommitDiffPatchSource::oldMessageChanged(QString text)
+{
+    if(m_oldMessages->currentIndex() != 0)
+    {
+        m_oldMessages->setCurrentIndex(0);
+        m_commitMessageEdit.data()->setText(text);
+    }
+}
+
+VCSDiffPatchSource::VCSDiffPatchSource(VCSDiffUpdater* updater)
+    : m_updater(updater)
+{
+    update();
+    KDevelop::IBasicVersionControl* vcs = m_updater->vcs();
+    KUrl url = m_updater->url();
+
     QScopedPointer<VcsJob> statusJob(vcs->status(url));
     QVariant varlist;
 
@@ -57,52 +124,6 @@ VCSCommitDiffPatchSource::VCSCommitDiffPatchSource(VCSDiffUpdater* updater, cons
     }
     else
         kDebug() << "Couldn't get status for urls: " << url;
-
-    m_commitMessageWidget = new QWidget;
-    QVBoxLayout* layout = new QVBoxLayout(m_commitMessageWidget.data());
-
-    m_commitMessageEdit = new QTextEdit;
-    m_commitMessageEdit.data()->setFont( KGlobalSettings::fixedFont() );
-    m_commitMessageEdit.data()->setLineWrapMode(QTextEdit::NoWrap);
-    m_vcs->setupCommitMessageEditor(url, m_commitMessageEdit.data());
-    
-    QHBoxLayout* titleLayout = new QHBoxLayout;
-    titleLayout->addWidget(new QLabel(i18n("Commit Message:")));
-    
-    m_oldMessages = new KComboBox;
-    
-    m_oldMessages->addItem(i18n("Old Messages"));
-    foreach(QString message, oldMessages())
-        m_oldMessages->addItem(message, message);
-    m_oldMessages->setMaximumWidth(200);
-    
-    connect(m_oldMessages, SIGNAL(currentIndexChanged(QString)), this, SLOT(oldMessageChanged(QString)));
-    
-    titleLayout->addWidget(m_oldMessages);
-    
-    layout->addLayout(titleLayout);
-    layout->addWidget(m_commitMessageEdit.data());
-}
-
-QStringList VCSCommitDiffPatchSource::oldMessages() const
-{
-    KConfigGroup vcsGroup(ICore::self()->activeSession()->config(), "VCS");
-    return vcsGroup.readEntry("OldCommitMessages", QStringList());
-}
-
-void VCSCommitDiffPatchSource::oldMessageChanged(QString text)
-{
-    if(m_oldMessages->currentIndex() != 0)
-    {
-        m_oldMessages->setCurrentIndex(0);
-        m_commitMessageEdit.data()->setText(text);
-    }
-}
-
-VCSDiffPatchSource::VCSDiffPatchSource(VCSDiffUpdater* updater)
-    : m_updater(updater)
-{
-    update();
 }
 
 VCSDiffPatchSource::VCSDiffPatchSource(const KDevelop::VcsDiff& diff)
@@ -149,10 +170,11 @@ void VCSDiffPatchSource::updateFromDiff(VcsDiff vcsdiff)
         t2 << vcsdiff.diff();
     }
 
-    kDebug() << "using file" << m_file << vcsdiff.diff();
+    kDebug() << "using file" << m_file << vcsdiff.diff() << "base" << vcsdiff.baseDiff();
 
     m_name = "VCS Diff";
     m_base = vcsdiff.baseDiff();
+    m_base.addPath("/");
     
     emit patchChanged();
 }
@@ -171,7 +193,7 @@ bool VCSCommitDiffPatchSource::canSelectFiles() const {
     return true;
 }
 
-QMap< KUrl, KDevelop::VcsStatusInfo::State> VCSCommitDiffPatchSource::additionalSelectableFiles() const {
+QMap< KUrl, KDevelop::VcsStatusInfo::State> VCSDiffPatchSource::additionalSelectableFiles() const {
     return m_selectable;
 }
 
@@ -180,7 +202,7 @@ QWidget* VCSCommitDiffPatchSource::customWidget() const {
 }
 
 QString VCSCommitDiffPatchSource::finishReviewCustomText() const {
-    return i18n("Commit");
+    return i18nc("@action:button To make a commit", "Commit");
 }
 
 bool VCSCommitDiffPatchSource::canCancel() const {
@@ -207,13 +229,15 @@ bool VCSCommitDiffPatchSource::finishReview(QList< KUrl > selection) {
         message = m_commitMessageEdit.data()->toPlainText();
 
     kDebug() << "Finishing with selection" << selection;
-    QString text = i18n("Files will be committed:\n");
+    QString files;
     foreach(const KUrl& url, selection)
-        text += ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + '\n';
+        files += "<li>"+ICore::self()->projectController()->prettyFileName(url, KDevelop::IProjectController::FormatPlain) + "</li>";
 
-    text += i18n("\nWith message:\n %1", message);
+    QString text = i18n("<qt>Files will be committed:\n<ul>%1</ul>\nWith message:\n <pre>%2</pre></qt>", files, message);
 
-    int res = KMessageBox::warningContinueCancel(0, text, i18n("About to commit to repository"));
+    int res = KMessageBox::warningContinueCancel(0, text, i18n("About to commit to repository"),
+                                                 KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
+                                                 "ShouldAskConfirmCommit");
     if (res != KMessageBox::Continue) {
         return false;
     }
